@@ -1,5 +1,5 @@
 from http import HTTPStatus
-from typing import Any, Optional, Union
+from typing import Any
 from uuid import UUID
 
 import httpx
@@ -15,12 +15,12 @@ def _get_kwargs(
     project_id: str,
     file_id: UUID,
     *,
-    srid: Union[None, Unset, int] = UNSET,
-    swap_x_y: Union[Unset, bool] = False,
+    srid: int | None | Unset = UNSET,
+    swap_x_y: bool | Unset = False,
 ) -> dict[str, Any]:
     params: dict[str, Any] = {}
 
-    json_srid: Union[None, Unset, int]
+    json_srid: int | None | Unset
     if isinstance(srid, Unset):
         json_srid = UNSET
     else:
@@ -41,8 +41,8 @@ def _get_kwargs(
 
 
 def _parse_response(
-    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
-) -> Optional[Union[HTTPValidationError, list["Location"]]]:
+    *, client: AuthenticatedClient | Client, response: httpx.Response
+) -> HTTPValidationError | list[Location] | None:
     if response.status_code == 201:
         response_201 = []
         _response_201 = response.json()
@@ -65,8 +65,8 @@ def _parse_response(
 
 
 def _build_response(
-    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
-) -> Response[Union[HTTPValidationError, list["Location"]]]:
+    *, client: AuthenticatedClient | Client, response: httpx.Response
+) -> Response[HTTPValidationError | list[Location]]:
     return Response(
         status_code=HTTPStatus(response.status_code),
         content=response.content,
@@ -80,9 +80,9 @@ def sync_detailed(
     file_id: UUID,
     *,
     client: AuthenticatedClient,
-    srid: Union[None, Unset, int] = UNSET,
-    swap_x_y: Union[Unset, bool] = False,
-) -> Response[Union[HTTPValidationError, list["Location"]]]:
+    srid: int | None | Unset = UNSET,
+    swap_x_y: bool | Unset = False,
+) -> Response[HTTPValidationError | list[Location]]:
     """Parse Project File
 
      Parse an already queued location file.
@@ -90,15 +90,15 @@ def sync_detailed(
     Args:
         project_id (str):
         file_id (UUID):
-        srid (Union[None, Unset, int]):
-        swap_x_y (Union[Unset, bool]):  Default: False.
+        srid (int | None | Unset):
+        swap_x_y (bool | Unset):  Default: False.
 
     Raises:
         errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
         httpx.TimeoutException: If the request takes longer than Client.timeout.
 
     Returns:
-        Response[Union[HTTPValidationError, list['Location']]]
+        Response[HTTPValidationError | list[Location]]
     """
 
     kwargs = _get_kwargs(
@@ -120,9 +120,9 @@ def sync(
     file_id: UUID,
     *,
     client: AuthenticatedClient,
-    srid: Union[None, Unset, int] = UNSET,
-    swap_x_y: Union[Unset, bool] = False,
-) -> Optional[Union[HTTPValidationError, list["Location"]]]:
+    srid: int | None | Unset = UNSET,
+    swap_x_y: bool | Unset = False,
+) -> HTTPValidationError | list[Location] | None:
     """Parse Project File
 
      Parse an already queued location file.
@@ -130,15 +130,15 @@ def sync(
     Args:
         project_id (str):
         file_id (UUID):
-        srid (Union[None, Unset, int]):
-        swap_x_y (Union[Unset, bool]):  Default: False.
+        srid (int | None | Unset):
+        swap_x_y (bool | Unset):  Default: False.
 
     Raises:
         errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
         httpx.TimeoutException: If the request takes longer than Client.timeout.
 
     Returns:
-        Union[HTTPValidationError, list['Location']]
+        HTTPValidationError | list[Location]
     """
 
     return sync_detailed(
@@ -155,9 +155,9 @@ async def asyncio_detailed(
     file_id: UUID,
     *,
     client: AuthenticatedClient,
-    srid: Union[None, Unset, int] = UNSET,
-    swap_x_y: Union[Unset, bool] = False,
-) -> Response[Union[HTTPValidationError, list["Location"]]]:
+    srid: int | None | Unset = UNSET,
+    swap_x_y: bool | Unset = False,
+) -> Response[HTTPValidationError | list[Location]]:
     """Parse Project File
 
      Parse an already queued location file.
@@ -165,15 +165,15 @@ async def asyncio_detailed(
     Args:
         project_id (str):
         file_id (UUID):
-        srid (Union[None, Unset, int]):
-        swap_x_y (Union[Unset, bool]):  Default: False.
+        srid (int | None | Unset):
+        swap_x_y (bool | Unset):  Default: False.
 
     Raises:
         errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
         httpx.TimeoutException: If the request takes longer than Client.timeout.
 
     Returns:
-        Response[Union[HTTPValidationError, list['Location']]]
+        Response[HTTPValidationError | list[Location]]
     """
 
     kwargs = _get_kwargs(
@@ -193,9 +193,9 @@ async def asyncio(
     file_id: UUID,
     *,
     client: AuthenticatedClient,
-    srid: Union[None, Unset, int] = UNSET,
-    swap_x_y: Union[Unset, bool] = False,
-) -> Optional[Union[HTTPValidationError, list["Location"]]]:
+    srid: int | None | Unset = UNSET,
+    swap_x_y: bool | Unset = False,
+) -> HTTPValidationError | list[Location] | None:
     """Parse Project File
 
      Parse an already queued location file.
@@ -203,15 +203,15 @@ async def asyncio(
     Args:
         project_id (str):
         file_id (UUID):
-        srid (Union[None, Unset, int]):
-        swap_x_y (Union[Unset, bool]):  Default: False.
+        srid (int | None | Unset):
+        swap_x_y (bool | Unset):  Default: False.
 
     Raises:
         errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
         httpx.TimeoutException: If the request takes longer than Client.timeout.
 
     Returns:
-        Union[HTTPValidationError, list['Location']]
+        HTTPValidationError | list[Location]
     """
 
     return (
