@@ -1,5 +1,5 @@
 from http import HTTPStatus
-from typing import Any, Optional, Union
+from typing import Any
 
 import httpx
 
@@ -32,8 +32,8 @@ def _get_kwargs(
 
 
 def _parse_response(
-    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
-) -> Optional[Union[HTTPValidationError, Location]]:
+    *, client: AuthenticatedClient | Client, response: httpx.Response
+) -> HTTPValidationError | Location | None:
     if response.status_code == 201:
         response_201 = Location.from_dict(response.json())
 
@@ -51,8 +51,8 @@ def _parse_response(
 
 
 def _build_response(
-    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
-) -> Response[Union[HTTPValidationError, Location]]:
+    *, client: AuthenticatedClient | Client, response: httpx.Response
+) -> Response[HTTPValidationError | Location]:
     return Response(
         status_code=HTTPStatus(response.status_code),
         content=response.content,
@@ -66,7 +66,7 @@ def sync_detailed(
     *,
     client: AuthenticatedClient,
     body: LocationCreate,
-) -> Response[Union[HTTPValidationError, Location]]:
+) -> Response[HTTPValidationError | Location]:
     """Add Location To Project
 
      Add location to project.
@@ -82,7 +82,7 @@ def sync_detailed(
         httpx.TimeoutException: If the request takes longer than Client.timeout.
 
     Returns:
-        Response[Union[HTTPValidationError, Location]]
+        Response[HTTPValidationError | Location]
     """
 
     kwargs = _get_kwargs(
@@ -102,7 +102,7 @@ def sync(
     *,
     client: AuthenticatedClient,
     body: LocationCreate,
-) -> Optional[Union[HTTPValidationError, Location]]:
+) -> HTTPValidationError | Location | None:
     """Add Location To Project
 
      Add location to project.
@@ -118,7 +118,7 @@ def sync(
         httpx.TimeoutException: If the request takes longer than Client.timeout.
 
     Returns:
-        Union[HTTPValidationError, Location]
+        HTTPValidationError | Location
     """
 
     return sync_detailed(
@@ -133,7 +133,7 @@ async def asyncio_detailed(
     *,
     client: AuthenticatedClient,
     body: LocationCreate,
-) -> Response[Union[HTTPValidationError, Location]]:
+) -> Response[HTTPValidationError | Location]:
     """Add Location To Project
 
      Add location to project.
@@ -149,7 +149,7 @@ async def asyncio_detailed(
         httpx.TimeoutException: If the request takes longer than Client.timeout.
 
     Returns:
-        Response[Union[HTTPValidationError, Location]]
+        Response[HTTPValidationError | Location]
     """
 
     kwargs = _get_kwargs(
@@ -167,7 +167,7 @@ async def asyncio(
     *,
     client: AuthenticatedClient,
     body: LocationCreate,
-) -> Optional[Union[HTTPValidationError, Location]]:
+) -> HTTPValidationError | Location | None:
     """Add Location To Project
 
      Add location to project.
@@ -183,7 +183,7 @@ async def asyncio(
         httpx.TimeoutException: If the request takes longer than Client.timeout.
 
     Returns:
-        Union[HTTPValidationError, Location]
+        HTTPValidationError | Location
     """
 
     return (
