@@ -1,5 +1,5 @@
 from http import HTTPStatus
-from typing import Any, Optional, Union
+from typing import Any
 
 import httpx
 
@@ -14,7 +14,7 @@ from ...types import Response
 def _get_kwargs(
     project_id: str,
     *,
-    body: list["LocationUpdate"],
+    body: list[LocationUpdate],
 ) -> dict[str, Any]:
     headers: dict[str, Any] = {}
 
@@ -35,8 +35,8 @@ def _get_kwargs(
 
 
 def _parse_response(
-    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
-) -> Optional[Union[HTTPValidationError, list["Location"]]]:
+    *, client: AuthenticatedClient | Client, response: httpx.Response
+) -> HTTPValidationError | list[Location] | None:
     if response.status_code == 200:
         response_200 = []
         _response_200 = response.json()
@@ -59,8 +59,8 @@ def _parse_response(
 
 
 def _build_response(
-    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
-) -> Response[Union[HTTPValidationError, list["Location"]]]:
+    *, client: AuthenticatedClient | Client, response: httpx.Response
+) -> Response[HTTPValidationError | list[Location]]:
     return Response(
         status_code=HTTPStatus(response.status_code),
         content=response.content,
@@ -73,22 +73,22 @@ def sync_detailed(
     project_id: str,
     *,
     client: AuthenticatedClient,
-    body: list["LocationUpdate"],
-) -> Response[Union[HTTPValidationError, list["Location"]]]:
+    body: list[LocationUpdate],
+) -> Response[HTTPValidationError | list[Location]]:
     """Update Locations In Project
 
      Batch updates locations
 
     Args:
         project_id (str):
-        body (list['LocationUpdate']):
+        body (list[LocationUpdate]):
 
     Raises:
         errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
         httpx.TimeoutException: If the request takes longer than Client.timeout.
 
     Returns:
-        Response[Union[HTTPValidationError, list['Location']]]
+        Response[HTTPValidationError | list[Location]]
     """
 
     kwargs = _get_kwargs(
@@ -107,22 +107,22 @@ def sync(
     project_id: str,
     *,
     client: AuthenticatedClient,
-    body: list["LocationUpdate"],
-) -> Optional[Union[HTTPValidationError, list["Location"]]]:
+    body: list[LocationUpdate],
+) -> HTTPValidationError | list[Location] | None:
     """Update Locations In Project
 
      Batch updates locations
 
     Args:
         project_id (str):
-        body (list['LocationUpdate']):
+        body (list[LocationUpdate]):
 
     Raises:
         errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
         httpx.TimeoutException: If the request takes longer than Client.timeout.
 
     Returns:
-        Union[HTTPValidationError, list['Location']]
+        HTTPValidationError | list[Location]
     """
 
     return sync_detailed(
@@ -136,22 +136,22 @@ async def asyncio_detailed(
     project_id: str,
     *,
     client: AuthenticatedClient,
-    body: list["LocationUpdate"],
-) -> Response[Union[HTTPValidationError, list["Location"]]]:
+    body: list[LocationUpdate],
+) -> Response[HTTPValidationError | list[Location]]:
     """Update Locations In Project
 
      Batch updates locations
 
     Args:
         project_id (str):
-        body (list['LocationUpdate']):
+        body (list[LocationUpdate]):
 
     Raises:
         errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
         httpx.TimeoutException: If the request takes longer than Client.timeout.
 
     Returns:
-        Response[Union[HTTPValidationError, list['Location']]]
+        Response[HTTPValidationError | list[Location]]
     """
 
     kwargs = _get_kwargs(
@@ -168,22 +168,22 @@ async def asyncio(
     project_id: str,
     *,
     client: AuthenticatedClient,
-    body: list["LocationUpdate"],
-) -> Optional[Union[HTTPValidationError, list["Location"]]]:
+    body: list[LocationUpdate],
+) -> HTTPValidationError | list[Location] | None:
     """Update Locations In Project
 
      Batch updates locations
 
     Args:
         project_id (str):
-        body (list['LocationUpdate']):
+        body (list[LocationUpdate]):
 
     Raises:
         errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
         httpx.TimeoutException: If the request takes longer than Client.timeout.
 
     Returns:
-        Union[HTTPValidationError, list['Location']]
+        HTTPValidationError | list[Location]
     """
 
     return (
