@@ -1,5 +1,5 @@
 from http import HTTPStatus
-from typing import Any, Optional, Union
+from typing import Any
 from uuid import UUID
 
 import httpx
@@ -61,44 +61,41 @@ def _get_kwargs(
 
 
 def _parse_response(
-    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
-) -> Optional[
-    Union[
-        HTTPValidationError,
-        list[
-            Union[
-                "MethodAD",
-                "MethodCD",
-                "MethodCPT",
-                "MethodDEF",
-                "MethodDP",
-                "MethodDT",
-                "MethodESA",
-                "MethodINC",
-                "MethodIW",
-                "MethodOTHER",
-                "MethodPT",
-                "MethodPZ",
-                "MethodRCD",
-                "MethodRO",
-                "MethodRP",
-                "MethodRS",
-                "MethodRWS",
-                "MethodSA",
-                "MethodSLB",
-                "MethodSPT",
-                "MethodSRS",
-                "MethodSS",
-                "MethodSTI",
-                "MethodSVT",
-                "MethodTOT",
-                "MethodTP",
-                "MethodTR",
-                "MethodWST",
-            ]
-        ],
+    *, client: AuthenticatedClient | Client, response: httpx.Response
+) -> (
+    HTTPValidationError
+    | list[
+        MethodAD
+        | MethodCD
+        | MethodCPT
+        | MethodDEF
+        | MethodDP
+        | MethodDT
+        | MethodESA
+        | MethodINC
+        | MethodIW
+        | MethodOTHER
+        | MethodPT
+        | MethodPZ
+        | MethodRCD
+        | MethodRO
+        | MethodRP
+        | MethodRS
+        | MethodRWS
+        | MethodSA
+        | MethodSLB
+        | MethodSPT
+        | MethodSRS
+        | MethodSS
+        | MethodSTI
+        | MethodSVT
+        | MethodTOT
+        | MethodTP
+        | MethodTR
+        | MethodWST
     ]
-]:
+    | None
+):
     if response.status_code == 201:
         response_201 = []
         _response_201 = response.json()
@@ -106,43 +103,43 @@ def _parse_response(
 
             def _parse_response_201_item(
                 data: object,
-            ) -> Union[
-                "MethodAD",
-                "MethodCD",
-                "MethodCPT",
-                "MethodDEF",
-                "MethodDP",
-                "MethodDT",
-                "MethodESA",
-                "MethodINC",
-                "MethodIW",
-                "MethodOTHER",
-                "MethodPT",
-                "MethodPZ",
-                "MethodRCD",
-                "MethodRO",
-                "MethodRP",
-                "MethodRS",
-                "MethodRWS",
-                "MethodSA",
-                "MethodSLB",
-                "MethodSPT",
-                "MethodSRS",
-                "MethodSS",
-                "MethodSTI",
-                "MethodSVT",
-                "MethodTOT",
-                "MethodTP",
-                "MethodTR",
-                "MethodWST",
-            ]:
+            ) -> (
+                MethodAD
+                | MethodCD
+                | MethodCPT
+                | MethodDEF
+                | MethodDP
+                | MethodDT
+                | MethodESA
+                | MethodINC
+                | MethodIW
+                | MethodOTHER
+                | MethodPT
+                | MethodPZ
+                | MethodRCD
+                | MethodRO
+                | MethodRP
+                | MethodRS
+                | MethodRWS
+                | MethodSA
+                | MethodSLB
+                | MethodSPT
+                | MethodSRS
+                | MethodSS
+                | MethodSTI
+                | MethodSVT
+                | MethodTOT
+                | MethodTP
+                | MethodTR
+                | MethodWST
+            ):
                 try:
                     if not isinstance(data, dict):
                         raise TypeError()
                     response_201_item_type_0 = MethodCPT.from_dict(data)
 
                     return response_201_item_type_0
-                except:  # noqa: E722
+                except (TypeError, ValueError, AttributeError, KeyError):
                     pass
                 try:
                     if not isinstance(data, dict):
@@ -150,7 +147,7 @@ def _parse_response(
                     response_201_item_type_1 = MethodTOT.from_dict(data)
 
                     return response_201_item_type_1
-                except:  # noqa: E722
+                except (TypeError, ValueError, AttributeError, KeyError):
                     pass
                 try:
                     if not isinstance(data, dict):
@@ -158,7 +155,7 @@ def _parse_response(
                     response_201_item_type_2 = MethodRP.from_dict(data)
 
                     return response_201_item_type_2
-                except:  # noqa: E722
+                except (TypeError, ValueError, AttributeError, KeyError):
                     pass
                 try:
                     if not isinstance(data, dict):
@@ -166,7 +163,7 @@ def _parse_response(
                     response_201_item_type_3 = MethodSA.from_dict(data)
 
                     return response_201_item_type_3
-                except:  # noqa: E722
+                except (TypeError, ValueError, AttributeError, KeyError):
                     pass
                 try:
                     if not isinstance(data, dict):
@@ -174,7 +171,7 @@ def _parse_response(
                     response_201_item_type_4 = MethodPZ.from_dict(data)
 
                     return response_201_item_type_4
-                except:  # noqa: E722
+                except (TypeError, ValueError, AttributeError, KeyError):
                     pass
                 try:
                     if not isinstance(data, dict):
@@ -182,7 +179,7 @@ def _parse_response(
                     response_201_item_type_5 = MethodSS.from_dict(data)
 
                     return response_201_item_type_5
-                except:  # noqa: E722
+                except (TypeError, ValueError, AttributeError, KeyError):
                     pass
                 try:
                     if not isinstance(data, dict):
@@ -190,7 +187,7 @@ def _parse_response(
                     response_201_item_type_6 = MethodRWS.from_dict(data)
 
                     return response_201_item_type_6
-                except:  # noqa: E722
+                except (TypeError, ValueError, AttributeError, KeyError):
                     pass
                 try:
                     if not isinstance(data, dict):
@@ -198,7 +195,7 @@ def _parse_response(
                     response_201_item_type_7 = MethodRCD.from_dict(data)
 
                     return response_201_item_type_7
-                except:  # noqa: E722
+                except (TypeError, ValueError, AttributeError, KeyError):
                     pass
                 try:
                     if not isinstance(data, dict):
@@ -206,7 +203,7 @@ def _parse_response(
                     response_201_item_type_8 = MethodRS.from_dict(data)
 
                     return response_201_item_type_8
-                except:  # noqa: E722
+                except (TypeError, ValueError, AttributeError, KeyError):
                     pass
                 try:
                     if not isinstance(data, dict):
@@ -214,7 +211,7 @@ def _parse_response(
                     response_201_item_type_9 = MethodSVT.from_dict(data)
 
                     return response_201_item_type_9
-                except:  # noqa: E722
+                except (TypeError, ValueError, AttributeError, KeyError):
                     pass
                 try:
                     if not isinstance(data, dict):
@@ -222,7 +219,7 @@ def _parse_response(
                     response_201_item_type_10 = MethodSPT.from_dict(data)
 
                     return response_201_item_type_10
-                except:  # noqa: E722
+                except (TypeError, ValueError, AttributeError, KeyError):
                     pass
                 try:
                     if not isinstance(data, dict):
@@ -230,7 +227,7 @@ def _parse_response(
                     response_201_item_type_11 = MethodCD.from_dict(data)
 
                     return response_201_item_type_11
-                except:  # noqa: E722
+                except (TypeError, ValueError, AttributeError, KeyError):
                     pass
                 try:
                     if not isinstance(data, dict):
@@ -238,7 +235,7 @@ def _parse_response(
                     response_201_item_type_12 = MethodTP.from_dict(data)
 
                     return response_201_item_type_12
-                except:  # noqa: E722
+                except (TypeError, ValueError, AttributeError, KeyError):
                     pass
                 try:
                     if not isinstance(data, dict):
@@ -246,7 +243,7 @@ def _parse_response(
                     response_201_item_type_13 = MethodPT.from_dict(data)
 
                     return response_201_item_type_13
-                except:  # noqa: E722
+                except (TypeError, ValueError, AttributeError, KeyError):
                     pass
                 try:
                     if not isinstance(data, dict):
@@ -254,7 +251,7 @@ def _parse_response(
                     response_201_item_type_14 = MethodESA.from_dict(data)
 
                     return response_201_item_type_14
-                except:  # noqa: E722
+                except (TypeError, ValueError, AttributeError, KeyError):
                     pass
                 try:
                     if not isinstance(data, dict):
@@ -262,7 +259,7 @@ def _parse_response(
                     response_201_item_type_15 = MethodTR.from_dict(data)
 
                     return response_201_item_type_15
-                except:  # noqa: E722
+                except (TypeError, ValueError, AttributeError, KeyError):
                     pass
                 try:
                     if not isinstance(data, dict):
@@ -270,7 +267,7 @@ def _parse_response(
                     response_201_item_type_16 = MethodAD.from_dict(data)
 
                     return response_201_item_type_16
-                except:  # noqa: E722
+                except (TypeError, ValueError, AttributeError, KeyError):
                     pass
                 try:
                     if not isinstance(data, dict):
@@ -278,7 +275,7 @@ def _parse_response(
                     response_201_item_type_17 = MethodRO.from_dict(data)
 
                     return response_201_item_type_17
-                except:  # noqa: E722
+                except (TypeError, ValueError, AttributeError, KeyError):
                     pass
                 try:
                     if not isinstance(data, dict):
@@ -286,7 +283,7 @@ def _parse_response(
                     response_201_item_type_18 = MethodINC.from_dict(data)
 
                     return response_201_item_type_18
-                except:  # noqa: E722
+                except (TypeError, ValueError, AttributeError, KeyError):
                     pass
                 try:
                     if not isinstance(data, dict):
@@ -294,7 +291,7 @@ def _parse_response(
                     response_201_item_type_19 = MethodDEF.from_dict(data)
 
                     return response_201_item_type_19
-                except:  # noqa: E722
+                except (TypeError, ValueError, AttributeError, KeyError):
                     pass
                 try:
                     if not isinstance(data, dict):
@@ -302,7 +299,7 @@ def _parse_response(
                     response_201_item_type_20 = MethodIW.from_dict(data)
 
                     return response_201_item_type_20
-                except:  # noqa: E722
+                except (TypeError, ValueError, AttributeError, KeyError):
                     pass
                 try:
                     if not isinstance(data, dict):
@@ -310,7 +307,7 @@ def _parse_response(
                     response_201_item_type_21 = MethodDT.from_dict(data)
 
                     return response_201_item_type_21
-                except:  # noqa: E722
+                except (TypeError, ValueError, AttributeError, KeyError):
                     pass
                 try:
                     if not isinstance(data, dict):
@@ -318,7 +315,7 @@ def _parse_response(
                     response_201_item_type_22 = MethodOTHER.from_dict(data)
 
                     return response_201_item_type_22
-                except:  # noqa: E722
+                except (TypeError, ValueError, AttributeError, KeyError):
                     pass
                 try:
                     if not isinstance(data, dict):
@@ -326,7 +323,7 @@ def _parse_response(
                     response_201_item_type_23 = MethodSRS.from_dict(data)
 
                     return response_201_item_type_23
-                except:  # noqa: E722
+                except (TypeError, ValueError, AttributeError, KeyError):
                     pass
                 try:
                     if not isinstance(data, dict):
@@ -334,7 +331,7 @@ def _parse_response(
                     response_201_item_type_24 = MethodDP.from_dict(data)
 
                     return response_201_item_type_24
-                except:  # noqa: E722
+                except (TypeError, ValueError, AttributeError, KeyError):
                     pass
                 try:
                     if not isinstance(data, dict):
@@ -342,7 +339,7 @@ def _parse_response(
                     response_201_item_type_25 = MethodWST.from_dict(data)
 
                     return response_201_item_type_25
-                except:  # noqa: E722
+                except (TypeError, ValueError, AttributeError, KeyError):
                     pass
                 try:
                     if not isinstance(data, dict):
@@ -350,7 +347,7 @@ def _parse_response(
                     response_201_item_type_26 = MethodSLB.from_dict(data)
 
                     return response_201_item_type_26
-                except:  # noqa: E722
+                except (TypeError, ValueError, AttributeError, KeyError):
                     pass
                 if not isinstance(data, dict):
                     raise TypeError()
@@ -376,42 +373,38 @@ def _parse_response(
 
 
 def _build_response(
-    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
+    *, client: AuthenticatedClient | Client, response: httpx.Response
 ) -> Response[
-    Union[
-        HTTPValidationError,
-        list[
-            Union[
-                "MethodAD",
-                "MethodCD",
-                "MethodCPT",
-                "MethodDEF",
-                "MethodDP",
-                "MethodDT",
-                "MethodESA",
-                "MethodINC",
-                "MethodIW",
-                "MethodOTHER",
-                "MethodPT",
-                "MethodPZ",
-                "MethodRCD",
-                "MethodRO",
-                "MethodRP",
-                "MethodRS",
-                "MethodRWS",
-                "MethodSA",
-                "MethodSLB",
-                "MethodSPT",
-                "MethodSRS",
-                "MethodSS",
-                "MethodSTI",
-                "MethodSVT",
-                "MethodTOT",
-                "MethodTP",
-                "MethodTR",
-                "MethodWST",
-            ]
-        ],
+    HTTPValidationError
+    | list[
+        MethodAD
+        | MethodCD
+        | MethodCPT
+        | MethodDEF
+        | MethodDP
+        | MethodDT
+        | MethodESA
+        | MethodINC
+        | MethodIW
+        | MethodOTHER
+        | MethodPT
+        | MethodPZ
+        | MethodRCD
+        | MethodRO
+        | MethodRP
+        | MethodRS
+        | MethodRWS
+        | MethodSA
+        | MethodSLB
+        | MethodSPT
+        | MethodSRS
+        | MethodSS
+        | MethodSTI
+        | MethodSVT
+        | MethodTOT
+        | MethodTP
+        | MethodTR
+        | MethodWST
     ]
 ]:
     return Response(
@@ -429,40 +422,36 @@ def sync_detailed(
     client: AuthenticatedClient,
     body: BodyUploadFileToLocationProjectsProjectIdLocationsLocationIdUploadPost,
 ) -> Response[
-    Union[
-        HTTPValidationError,
-        list[
-            Union[
-                "MethodAD",
-                "MethodCD",
-                "MethodCPT",
-                "MethodDEF",
-                "MethodDP",
-                "MethodDT",
-                "MethodESA",
-                "MethodINC",
-                "MethodIW",
-                "MethodOTHER",
-                "MethodPT",
-                "MethodPZ",
-                "MethodRCD",
-                "MethodRO",
-                "MethodRP",
-                "MethodRS",
-                "MethodRWS",
-                "MethodSA",
-                "MethodSLB",
-                "MethodSPT",
-                "MethodSRS",
-                "MethodSS",
-                "MethodSTI",
-                "MethodSVT",
-                "MethodTOT",
-                "MethodTP",
-                "MethodTR",
-                "MethodWST",
-            ]
-        ],
+    HTTPValidationError
+    | list[
+        MethodAD
+        | MethodCD
+        | MethodCPT
+        | MethodDEF
+        | MethodDP
+        | MethodDT
+        | MethodESA
+        | MethodINC
+        | MethodIW
+        | MethodOTHER
+        | MethodPT
+        | MethodPZ
+        | MethodRCD
+        | MethodRO
+        | MethodRP
+        | MethodRS
+        | MethodRWS
+        | MethodSA
+        | MethodSLB
+        | MethodSPT
+        | MethodSRS
+        | MethodSS
+        | MethodSTI
+        | MethodSVT
+        | MethodTOT
+        | MethodTP
+        | MethodTR
+        | MethodWST
     ]
 ]:
     """Upload File To Location
@@ -482,7 +471,7 @@ def sync_detailed(
         httpx.TimeoutException: If the request takes longer than Client.timeout.
 
     Returns:
-        Response[Union[HTTPValidationError, list[Union['MethodAD', 'MethodCD', 'MethodCPT', 'MethodDEF', 'MethodDP', 'MethodDT', 'MethodESA', 'MethodINC', 'MethodIW', 'MethodOTHER', 'MethodPT', 'MethodPZ', 'MethodRCD', 'MethodRO', 'MethodRP', 'MethodRS', 'MethodRWS', 'MethodSA', 'MethodSLB', 'MethodSPT', 'MethodSRS', 'MethodSS', 'MethodSTI', 'MethodSVT', 'MethodTOT', 'MethodTP', 'MethodTR', 'MethodWST']]]]
+        Response[HTTPValidationError | list[MethodAD | MethodCD | MethodCPT | MethodDEF | MethodDP | MethodDT | MethodESA | MethodINC | MethodIW | MethodOTHER | MethodPT | MethodPZ | MethodRCD | MethodRO | MethodRP | MethodRS | MethodRWS | MethodSA | MethodSLB | MethodSPT | MethodSRS | MethodSS | MethodSTI | MethodSVT | MethodTOT | MethodTP | MethodTR | MethodWST]]
     """
 
     kwargs = _get_kwargs(
@@ -504,43 +493,40 @@ def sync(
     *,
     client: AuthenticatedClient,
     body: BodyUploadFileToLocationProjectsProjectIdLocationsLocationIdUploadPost,
-) -> Optional[
-    Union[
-        HTTPValidationError,
-        list[
-            Union[
-                "MethodAD",
-                "MethodCD",
-                "MethodCPT",
-                "MethodDEF",
-                "MethodDP",
-                "MethodDT",
-                "MethodESA",
-                "MethodINC",
-                "MethodIW",
-                "MethodOTHER",
-                "MethodPT",
-                "MethodPZ",
-                "MethodRCD",
-                "MethodRO",
-                "MethodRP",
-                "MethodRS",
-                "MethodRWS",
-                "MethodSA",
-                "MethodSLB",
-                "MethodSPT",
-                "MethodSRS",
-                "MethodSS",
-                "MethodSTI",
-                "MethodSVT",
-                "MethodTOT",
-                "MethodTP",
-                "MethodTR",
-                "MethodWST",
-            ]
-        ],
+) -> (
+    HTTPValidationError
+    | list[
+        MethodAD
+        | MethodCD
+        | MethodCPT
+        | MethodDEF
+        | MethodDP
+        | MethodDT
+        | MethodESA
+        | MethodINC
+        | MethodIW
+        | MethodOTHER
+        | MethodPT
+        | MethodPZ
+        | MethodRCD
+        | MethodRO
+        | MethodRP
+        | MethodRS
+        | MethodRWS
+        | MethodSA
+        | MethodSLB
+        | MethodSPT
+        | MethodSRS
+        | MethodSS
+        | MethodSTI
+        | MethodSVT
+        | MethodTOT
+        | MethodTP
+        | MethodTR
+        | MethodWST
     ]
-]:
+    | None
+):
     """Upload File To Location
 
      Upload a data file to location. Will create new methods and upload the submitted file data
@@ -558,7 +544,7 @@ def sync(
         httpx.TimeoutException: If the request takes longer than Client.timeout.
 
     Returns:
-        Union[HTTPValidationError, list[Union['MethodAD', 'MethodCD', 'MethodCPT', 'MethodDEF', 'MethodDP', 'MethodDT', 'MethodESA', 'MethodINC', 'MethodIW', 'MethodOTHER', 'MethodPT', 'MethodPZ', 'MethodRCD', 'MethodRO', 'MethodRP', 'MethodRS', 'MethodRWS', 'MethodSA', 'MethodSLB', 'MethodSPT', 'MethodSRS', 'MethodSS', 'MethodSTI', 'MethodSVT', 'MethodTOT', 'MethodTP', 'MethodTR', 'MethodWST']]]
+        HTTPValidationError | list[MethodAD | MethodCD | MethodCPT | MethodDEF | MethodDP | MethodDT | MethodESA | MethodINC | MethodIW | MethodOTHER | MethodPT | MethodPZ | MethodRCD | MethodRO | MethodRP | MethodRS | MethodRWS | MethodSA | MethodSLB | MethodSPT | MethodSRS | MethodSS | MethodSTI | MethodSVT | MethodTOT | MethodTP | MethodTR | MethodWST]
     """
 
     return sync_detailed(
@@ -576,40 +562,36 @@ async def asyncio_detailed(
     client: AuthenticatedClient,
     body: BodyUploadFileToLocationProjectsProjectIdLocationsLocationIdUploadPost,
 ) -> Response[
-    Union[
-        HTTPValidationError,
-        list[
-            Union[
-                "MethodAD",
-                "MethodCD",
-                "MethodCPT",
-                "MethodDEF",
-                "MethodDP",
-                "MethodDT",
-                "MethodESA",
-                "MethodINC",
-                "MethodIW",
-                "MethodOTHER",
-                "MethodPT",
-                "MethodPZ",
-                "MethodRCD",
-                "MethodRO",
-                "MethodRP",
-                "MethodRS",
-                "MethodRWS",
-                "MethodSA",
-                "MethodSLB",
-                "MethodSPT",
-                "MethodSRS",
-                "MethodSS",
-                "MethodSTI",
-                "MethodSVT",
-                "MethodTOT",
-                "MethodTP",
-                "MethodTR",
-                "MethodWST",
-            ]
-        ],
+    HTTPValidationError
+    | list[
+        MethodAD
+        | MethodCD
+        | MethodCPT
+        | MethodDEF
+        | MethodDP
+        | MethodDT
+        | MethodESA
+        | MethodINC
+        | MethodIW
+        | MethodOTHER
+        | MethodPT
+        | MethodPZ
+        | MethodRCD
+        | MethodRO
+        | MethodRP
+        | MethodRS
+        | MethodRWS
+        | MethodSA
+        | MethodSLB
+        | MethodSPT
+        | MethodSRS
+        | MethodSS
+        | MethodSTI
+        | MethodSVT
+        | MethodTOT
+        | MethodTP
+        | MethodTR
+        | MethodWST
     ]
 ]:
     """Upload File To Location
@@ -629,7 +611,7 @@ async def asyncio_detailed(
         httpx.TimeoutException: If the request takes longer than Client.timeout.
 
     Returns:
-        Response[Union[HTTPValidationError, list[Union['MethodAD', 'MethodCD', 'MethodCPT', 'MethodDEF', 'MethodDP', 'MethodDT', 'MethodESA', 'MethodINC', 'MethodIW', 'MethodOTHER', 'MethodPT', 'MethodPZ', 'MethodRCD', 'MethodRO', 'MethodRP', 'MethodRS', 'MethodRWS', 'MethodSA', 'MethodSLB', 'MethodSPT', 'MethodSRS', 'MethodSS', 'MethodSTI', 'MethodSVT', 'MethodTOT', 'MethodTP', 'MethodTR', 'MethodWST']]]]
+        Response[HTTPValidationError | list[MethodAD | MethodCD | MethodCPT | MethodDEF | MethodDP | MethodDT | MethodESA | MethodINC | MethodIW | MethodOTHER | MethodPT | MethodPZ | MethodRCD | MethodRO | MethodRP | MethodRS | MethodRWS | MethodSA | MethodSLB | MethodSPT | MethodSRS | MethodSS | MethodSTI | MethodSVT | MethodTOT | MethodTP | MethodTR | MethodWST]]
     """
 
     kwargs = _get_kwargs(
@@ -649,43 +631,40 @@ async def asyncio(
     *,
     client: AuthenticatedClient,
     body: BodyUploadFileToLocationProjectsProjectIdLocationsLocationIdUploadPost,
-) -> Optional[
-    Union[
-        HTTPValidationError,
-        list[
-            Union[
-                "MethodAD",
-                "MethodCD",
-                "MethodCPT",
-                "MethodDEF",
-                "MethodDP",
-                "MethodDT",
-                "MethodESA",
-                "MethodINC",
-                "MethodIW",
-                "MethodOTHER",
-                "MethodPT",
-                "MethodPZ",
-                "MethodRCD",
-                "MethodRO",
-                "MethodRP",
-                "MethodRS",
-                "MethodRWS",
-                "MethodSA",
-                "MethodSLB",
-                "MethodSPT",
-                "MethodSRS",
-                "MethodSS",
-                "MethodSTI",
-                "MethodSVT",
-                "MethodTOT",
-                "MethodTP",
-                "MethodTR",
-                "MethodWST",
-            ]
-        ],
+) -> (
+    HTTPValidationError
+    | list[
+        MethodAD
+        | MethodCD
+        | MethodCPT
+        | MethodDEF
+        | MethodDP
+        | MethodDT
+        | MethodESA
+        | MethodINC
+        | MethodIW
+        | MethodOTHER
+        | MethodPT
+        | MethodPZ
+        | MethodRCD
+        | MethodRO
+        | MethodRP
+        | MethodRS
+        | MethodRWS
+        | MethodSA
+        | MethodSLB
+        | MethodSPT
+        | MethodSRS
+        | MethodSS
+        | MethodSTI
+        | MethodSVT
+        | MethodTOT
+        | MethodTP
+        | MethodTR
+        | MethodWST
     ]
-]:
+    | None
+):
     """Upload File To Location
 
      Upload a data file to location. Will create new methods and upload the submitted file data
@@ -703,7 +682,7 @@ async def asyncio(
         httpx.TimeoutException: If the request takes longer than Client.timeout.
 
     Returns:
-        Union[HTTPValidationError, list[Union['MethodAD', 'MethodCD', 'MethodCPT', 'MethodDEF', 'MethodDP', 'MethodDT', 'MethodESA', 'MethodINC', 'MethodIW', 'MethodOTHER', 'MethodPT', 'MethodPZ', 'MethodRCD', 'MethodRO', 'MethodRP', 'MethodRS', 'MethodRWS', 'MethodSA', 'MethodSLB', 'MethodSPT', 'MethodSRS', 'MethodSS', 'MethodSTI', 'MethodSVT', 'MethodTOT', 'MethodTP', 'MethodTR', 'MethodWST']]]
+        HTTPValidationError | list[MethodAD | MethodCD | MethodCPT | MethodDEF | MethodDP | MethodDT | MethodESA | MethodINC | MethodIW | MethodOTHER | MethodPT | MethodPZ | MethodRCD | MethodRO | MethodRP | MethodRS | MethodRWS | MethodSA | MethodSLB | MethodSPT | MethodSRS | MethodSS | MethodSTI | MethodSVT | MethodTOT | MethodTP | MethodTR | MethodWST]
     """
 
     return (
