@@ -1,5 +1,5 @@
 from http import HTTPStatus
-from typing import Any, Optional, Union
+from typing import Any
 
 import httpx
 
@@ -32,16 +32,18 @@ def _get_kwargs(
 
 
 def _parse_response(
-    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
-) -> Optional[Union[HTTPValidationError, MapLayout]]:
+    *, client: AuthenticatedClient | Client, response: httpx.Response
+) -> HTTPValidationError | MapLayout | None:
     if response.status_code == 201:
         response_201 = MapLayout.from_dict(response.json())
 
         return response_201
+
     if response.status_code == 422:
         response_422 = HTTPValidationError.from_dict(response.json())
 
         return response_422
+
     if client.raise_on_unexpected_status:
         raise errors.UnexpectedStatus(response.status_code, response.content)
     else:
@@ -49,8 +51,8 @@ def _parse_response(
 
 
 def _build_response(
-    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
-) -> Response[Union[HTTPValidationError, MapLayout]]:
+    *, client: AuthenticatedClient | Client, response: httpx.Response
+) -> Response[HTTPValidationError | MapLayout]:
     return Response(
         status_code=HTTPStatus(response.status_code),
         content=response.content,
@@ -64,7 +66,7 @@ def sync_detailed(
     *,
     client: AuthenticatedClient,
     body: MapLayoutCreate,
-) -> Response[Union[HTTPValidationError, MapLayout]]:
+) -> Response[HTTPValidationError | MapLayout]:
     """Add Map Layout To Project
 
      Add map layout to project.
@@ -78,7 +80,7 @@ def sync_detailed(
         httpx.TimeoutException: If the request takes longer than Client.timeout.
 
     Returns:
-        Response[Union[HTTPValidationError, MapLayout]]
+        Response[HTTPValidationError | MapLayout]
     """
 
     kwargs = _get_kwargs(
@@ -98,7 +100,7 @@ def sync(
     *,
     client: AuthenticatedClient,
     body: MapLayoutCreate,
-) -> Optional[Union[HTTPValidationError, MapLayout]]:
+) -> HTTPValidationError | MapLayout | None:
     """Add Map Layout To Project
 
      Add map layout to project.
@@ -112,7 +114,7 @@ def sync(
         httpx.TimeoutException: If the request takes longer than Client.timeout.
 
     Returns:
-        Union[HTTPValidationError, MapLayout]
+        HTTPValidationError | MapLayout
     """
 
     return sync_detailed(
@@ -127,7 +129,7 @@ async def asyncio_detailed(
     *,
     client: AuthenticatedClient,
     body: MapLayoutCreate,
-) -> Response[Union[HTTPValidationError, MapLayout]]:
+) -> Response[HTTPValidationError | MapLayout]:
     """Add Map Layout To Project
 
      Add map layout to project.
@@ -141,7 +143,7 @@ async def asyncio_detailed(
         httpx.TimeoutException: If the request takes longer than Client.timeout.
 
     Returns:
-        Response[Union[HTTPValidationError, MapLayout]]
+        Response[HTTPValidationError | MapLayout]
     """
 
     kwargs = _get_kwargs(
@@ -159,7 +161,7 @@ async def asyncio(
     *,
     client: AuthenticatedClient,
     body: MapLayoutCreate,
-) -> Optional[Union[HTTPValidationError, MapLayout]]:
+) -> HTTPValidationError | MapLayout | None:
     """Add Map Layout To Project
 
      Add map layout to project.
@@ -173,7 +175,7 @@ async def asyncio(
         httpx.TimeoutException: If the request takes longer than Client.timeout.
 
     Returns:
-        Union[HTTPValidationError, MapLayout]
+        HTTPValidationError | MapLayout
     """
 
     return (
