@@ -1,5 +1,5 @@
 from http import HTTPStatus
-from typing import Any, Optional, Union
+from typing import Any
 from uuid import UUID
 
 import httpx
@@ -70,36 +70,34 @@ def _get_kwargs(
     project_id: str,
     location_id: UUID,
     *,
-    body: Union[
-        "MethodADCreate",
-        "MethodCDCreate",
-        "MethodCPTCreate",
-        "MethodDEFCreate",
-        "MethodDPCreate",
-        "MethodDTCreate",
-        "MethodESACreate",
-        "MethodINCCreate",
-        "MethodIWCreate",
-        "MethodOTHERCreate",
-        "MethodPTCreate",
-        "MethodPZCreate",
-        "MethodRCDCreate",
-        "MethodROCreate",
-        "MethodRPCreate",
-        "MethodRSCreate",
-        "MethodRWSCreate",
-        "MethodSACreate",
-        "MethodSLBCreate",
-        "MethodSPTCreate",
-        "MethodSRSCreate",
-        "MethodSSCreate",
-        "MethodSTICreate",
-        "MethodSVTCreate",
-        "MethodTOTCreate",
-        "MethodTPCreate",
-        "MethodTRCreate",
-        "MethodWSTCreate",
-    ],
+    body: MethodADCreate
+    | MethodCDCreate
+    | MethodCPTCreate
+    | MethodDEFCreate
+    | MethodDPCreate
+    | MethodDTCreate
+    | MethodESACreate
+    | MethodINCCreate
+    | MethodIWCreate
+    | MethodOTHERCreate
+    | MethodPTCreate
+    | MethodPZCreate
+    | MethodRCDCreate
+    | MethodROCreate
+    | MethodRPCreate
+    | MethodRSCreate
+    | MethodRWSCreate
+    | MethodSACreate
+    | MethodSLBCreate
+    | MethodSPTCreate
+    | MethodSRSCreate
+    | MethodSSCreate
+    | MethodSTICreate
+    | MethodSVTCreate
+    | MethodTOTCreate
+    | MethodTPCreate
+    | MethodTRCreate
+    | MethodWSTCreate,
 ) -> dict[str, Any]:
     headers: dict[str, Any] = {}
 
@@ -173,83 +171,80 @@ def _get_kwargs(
 
 
 def _parse_response(
-    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
-) -> Optional[
-    Union[
-        HTTPValidationError,
-        Union[
-            "MethodAD",
-            "MethodCD",
-            "MethodCPT",
-            "MethodDEF",
-            "MethodDP",
-            "MethodDT",
-            "MethodESA",
-            "MethodINC",
-            "MethodIW",
-            "MethodOTHER",
-            "MethodPT",
-            "MethodPZ",
-            "MethodRCD",
-            "MethodRO",
-            "MethodRP",
-            "MethodRS",
-            "MethodRWS",
-            "MethodSA",
-            "MethodSLB",
-            "MethodSPT",
-            "MethodSRS",
-            "MethodSS",
-            "MethodSTI",
-            "MethodSVT",
-            "MethodTOT",
-            "MethodTP",
-            "MethodTR",
-            "MethodWST",
-        ],
-    ]
-]:
+    *, client: AuthenticatedClient | Client, response: httpx.Response
+) -> (
+    HTTPValidationError
+    | MethodAD
+    | MethodCD
+    | MethodCPT
+    | MethodDEF
+    | MethodDP
+    | MethodDT
+    | MethodESA
+    | MethodINC
+    | MethodIW
+    | MethodOTHER
+    | MethodPT
+    | MethodPZ
+    | MethodRCD
+    | MethodRO
+    | MethodRP
+    | MethodRS
+    | MethodRWS
+    | MethodSA
+    | MethodSLB
+    | MethodSPT
+    | MethodSRS
+    | MethodSS
+    | MethodSTI
+    | MethodSVT
+    | MethodTOT
+    | MethodTP
+    | MethodTR
+    | MethodWST
+    | None
+):
     if response.status_code == 201:
 
         def _parse_response_201(
             data: object,
-        ) -> Union[
-            "MethodAD",
-            "MethodCD",
-            "MethodCPT",
-            "MethodDEF",
-            "MethodDP",
-            "MethodDT",
-            "MethodESA",
-            "MethodINC",
-            "MethodIW",
-            "MethodOTHER",
-            "MethodPT",
-            "MethodPZ",
-            "MethodRCD",
-            "MethodRO",
-            "MethodRP",
-            "MethodRS",
-            "MethodRWS",
-            "MethodSA",
-            "MethodSLB",
-            "MethodSPT",
-            "MethodSRS",
-            "MethodSS",
-            "MethodSTI",
-            "MethodSVT",
-            "MethodTOT",
-            "MethodTP",
-            "MethodTR",
-            "MethodWST",
-        ]:
+        ) -> (
+            MethodAD
+            | MethodCD
+            | MethodCPT
+            | MethodDEF
+            | MethodDP
+            | MethodDT
+            | MethodESA
+            | MethodINC
+            | MethodIW
+            | MethodOTHER
+            | MethodPT
+            | MethodPZ
+            | MethodRCD
+            | MethodRO
+            | MethodRP
+            | MethodRS
+            | MethodRWS
+            | MethodSA
+            | MethodSLB
+            | MethodSPT
+            | MethodSRS
+            | MethodSS
+            | MethodSTI
+            | MethodSVT
+            | MethodTOT
+            | MethodTP
+            | MethodTR
+            | MethodWST
+        ):
             try:
                 if not isinstance(data, dict):
                     raise TypeError()
                 response_201_type_0 = MethodCPT.from_dict(data)
 
                 return response_201_type_0
-            except:  # noqa: E722
+            except (TypeError, ValueError, AttributeError, KeyError):
                 pass
             try:
                 if not isinstance(data, dict):
@@ -257,7 +252,7 @@ def _parse_response(
                 response_201_type_1 = MethodTOT.from_dict(data)
 
                 return response_201_type_1
-            except:  # noqa: E722
+            except (TypeError, ValueError, AttributeError, KeyError):
                 pass
             try:
                 if not isinstance(data, dict):
@@ -265,7 +260,7 @@ def _parse_response(
                 response_201_type_2 = MethodRP.from_dict(data)
 
                 return response_201_type_2
-            except:  # noqa: E722
+            except (TypeError, ValueError, AttributeError, KeyError):
                 pass
             try:
                 if not isinstance(data, dict):
@@ -273,7 +268,7 @@ def _parse_response(
                 response_201_type_3 = MethodSA.from_dict(data)
 
                 return response_201_type_3
-            except:  # noqa: E722
+            except (TypeError, ValueError, AttributeError, KeyError):
                 pass
             try:
                 if not isinstance(data, dict):
@@ -281,7 +276,7 @@ def _parse_response(
                 response_201_type_4 = MethodPZ.from_dict(data)
 
                 return response_201_type_4
-            except:  # noqa: E722
+            except (TypeError, ValueError, AttributeError, KeyError):
                 pass
             try:
                 if not isinstance(data, dict):
@@ -289,7 +284,7 @@ def _parse_response(
                 response_201_type_5 = MethodSS.from_dict(data)
 
                 return response_201_type_5
-            except:  # noqa: E722
+            except (TypeError, ValueError, AttributeError, KeyError):
                 pass
             try:
                 if not isinstance(data, dict):
@@ -297,7 +292,7 @@ def _parse_response(
                 response_201_type_6 = MethodRWS.from_dict(data)
 
                 return response_201_type_6
-            except:  # noqa: E722
+            except (TypeError, ValueError, AttributeError, KeyError):
                 pass
             try:
                 if not isinstance(data, dict):
@@ -305,7 +300,7 @@ def _parse_response(
                 response_201_type_7 = MethodRCD.from_dict(data)
 
                 return response_201_type_7
-            except:  # noqa: E722
+            except (TypeError, ValueError, AttributeError, KeyError):
                 pass
             try:
                 if not isinstance(data, dict):
@@ -313,7 +308,7 @@ def _parse_response(
                 response_201_type_8 = MethodRS.from_dict(data)
 
                 return response_201_type_8
-            except:  # noqa: E722
+            except (TypeError, ValueError, AttributeError, KeyError):
                 pass
             try:
                 if not isinstance(data, dict):
@@ -321,7 +316,7 @@ def _parse_response(
                 response_201_type_9 = MethodSVT.from_dict(data)
 
                 return response_201_type_9
-            except:  # noqa: E722
+            except (TypeError, ValueError, AttributeError, KeyError):
                 pass
             try:
                 if not isinstance(data, dict):
@@ -329,7 +324,7 @@ def _parse_response(
                 response_201_type_10 = MethodSPT.from_dict(data)
 
                 return response_201_type_10
-            except:  # noqa: E722
+            except (TypeError, ValueError, AttributeError, KeyError):
                 pass
             try:
                 if not isinstance(data, dict):
@@ -337,7 +332,7 @@ def _parse_response(
                 response_201_type_11 = MethodCD.from_dict(data)
 
                 return response_201_type_11
-            except:  # noqa: E722
+            except (TypeError, ValueError, AttributeError, KeyError):
                 pass
             try:
                 if not isinstance(data, dict):
@@ -345,7 +340,7 @@ def _parse_response(
                 response_201_type_12 = MethodTP.from_dict(data)
 
                 return response_201_type_12
-            except:  # noqa: E722
+            except (TypeError, ValueError, AttributeError, KeyError):
                 pass
             try:
                 if not isinstance(data, dict):
@@ -353,7 +348,7 @@ def _parse_response(
                 response_201_type_13 = MethodPT.from_dict(data)
 
                 return response_201_type_13
-            except:  # noqa: E722
+            except (TypeError, ValueError, AttributeError, KeyError):
                 pass
             try:
                 if not isinstance(data, dict):
@@ -361,7 +356,7 @@ def _parse_response(
                 response_201_type_14 = MethodESA.from_dict(data)
 
                 return response_201_type_14
-            except:  # noqa: E722
+            except (TypeError, ValueError, AttributeError, KeyError):
                 pass
             try:
                 if not isinstance(data, dict):
@@ -369,7 +364,7 @@ def _parse_response(
                 response_201_type_15 = MethodTR.from_dict(data)
 
                 return response_201_type_15
-            except:  # noqa: E722
+            except (TypeError, ValueError, AttributeError, KeyError):
                 pass
             try:
                 if not isinstance(data, dict):
@@ -377,7 +372,7 @@ def _parse_response(
                 response_201_type_16 = MethodAD.from_dict(data)
 
                 return response_201_type_16
-            except:  # noqa: E722
+            except (TypeError, ValueError, AttributeError, KeyError):
                 pass
             try:
                 if not isinstance(data, dict):
@@ -385,7 +380,7 @@ def _parse_response(
                 response_201_type_17 = MethodRO.from_dict(data)
 
                 return response_201_type_17
-            except:  # noqa: E722
+            except (TypeError, ValueError, AttributeError, KeyError):
                 pass
             try:
                 if not isinstance(data, dict):
@@ -393,7 +388,7 @@ def _parse_response(
                 response_201_type_18 = MethodINC.from_dict(data)
 
                 return response_201_type_18
-            except:  # noqa: E722
+            except (TypeError, ValueError, AttributeError, KeyError):
                 pass
             try:
                 if not isinstance(data, dict):
@@ -401,7 +396,7 @@ def _parse_response(
                 response_201_type_19 = MethodDEF.from_dict(data)
 
                 return response_201_type_19
-            except:  # noqa: E722
+            except (TypeError, ValueError, AttributeError, KeyError):
                 pass
             try:
                 if not isinstance(data, dict):
@@ -409,7 +404,7 @@ def _parse_response(
                 response_201_type_20 = MethodIW.from_dict(data)
 
                 return response_201_type_20
-            except:  # noqa: E722
+            except (TypeError, ValueError, AttributeError, KeyError):
                 pass
             try:
                 if not isinstance(data, dict):
@@ -417,7 +412,7 @@ def _parse_response(
                 response_201_type_21 = MethodDT.from_dict(data)
 
                 return response_201_type_21
-            except:  # noqa: E722
+            except (TypeError, ValueError, AttributeError, KeyError):
                 pass
             try:
                 if not isinstance(data, dict):
@@ -425,7 +420,7 @@ def _parse_response(
                 response_201_type_22 = MethodOTHER.from_dict(data)
 
                 return response_201_type_22
-            except:  # noqa: E722
+            except (TypeError, ValueError, AttributeError, KeyError):
                 pass
             try:
                 if not isinstance(data, dict):
@@ -433,7 +428,7 @@ def _parse_response(
                 response_201_type_23 = MethodSRS.from_dict(data)
 
                 return response_201_type_23
-            except:  # noqa: E722
+            except (TypeError, ValueError, AttributeError, KeyError):
                 pass
             try:
                 if not isinstance(data, dict):
@@ -441,7 +436,7 @@ def _parse_response(
                 response_201_type_24 = MethodDP.from_dict(data)
 
                 return response_201_type_24
-            except:  # noqa: E722
+            except (TypeError, ValueError, AttributeError, KeyError):
                 pass
             try:
                 if not isinstance(data, dict):
@@ -449,7 +444,7 @@ def _parse_response(
                 response_201_type_25 = MethodWST.from_dict(data)
 
                 return response_201_type_25
-            except:  # noqa: E722
+            except (TypeError, ValueError, AttributeError, KeyError):
                 pass
             try:
                 if not isinstance(data, dict):
@@ -457,7 +452,7 @@ def _parse_response(
                 response_201_type_26 = MethodSLB.from_dict(data)
 
                 return response_201_type_26
-            except:  # noqa: E722
+            except (TypeError, ValueError, AttributeError, KeyError):
                 pass
             if not isinstance(data, dict):
                 raise TypeError()
@@ -481,41 +476,37 @@ def _parse_response(
 
 
 def _build_response(
-    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
+    *, client: AuthenticatedClient | Client, response: httpx.Response
 ) -> Response[
-    Union[
-        HTTPValidationError,
-        Union[
-            "MethodAD",
-            "MethodCD",
-            "MethodCPT",
-            "MethodDEF",
-            "MethodDP",
-            "MethodDT",
-            "MethodESA",
-            "MethodINC",
-            "MethodIW",
-            "MethodOTHER",
-            "MethodPT",
-            "MethodPZ",
-            "MethodRCD",
-            "MethodRO",
-            "MethodRP",
-            "MethodRS",
-            "MethodRWS",
-            "MethodSA",
-            "MethodSLB",
-            "MethodSPT",
-            "MethodSRS",
-            "MethodSS",
-            "MethodSTI",
-            "MethodSVT",
-            "MethodTOT",
-            "MethodTP",
-            "MethodTR",
-            "MethodWST",
-        ],
-    ]
+    HTTPValidationError
+    | MethodAD
+    | MethodCD
+    | MethodCPT
+    | MethodDEF
+    | MethodDP
+    | MethodDT
+    | MethodESA
+    | MethodINC
+    | MethodIW
+    | MethodOTHER
+    | MethodPT
+    | MethodPZ
+    | MethodRCD
+    | MethodRO
+    | MethodRP
+    | MethodRS
+    | MethodRWS
+    | MethodSA
+    | MethodSLB
+    | MethodSPT
+    | MethodSRS
+    | MethodSS
+    | MethodSTI
+    | MethodSVT
+    | MethodTOT
+    | MethodTP
+    | MethodTR
+    | MethodWST
 ]:
     return Response(
         status_code=HTTPStatus(response.status_code),
@@ -530,70 +521,64 @@ def sync_detailed(
     location_id: UUID,
     *,
     client: AuthenticatedClient,
-    body: Union[
-        "MethodADCreate",
-        "MethodCDCreate",
-        "MethodCPTCreate",
-        "MethodDEFCreate",
-        "MethodDPCreate",
-        "MethodDTCreate",
-        "MethodESACreate",
-        "MethodINCCreate",
-        "MethodIWCreate",
-        "MethodOTHERCreate",
-        "MethodPTCreate",
-        "MethodPZCreate",
-        "MethodRCDCreate",
-        "MethodROCreate",
-        "MethodRPCreate",
-        "MethodRSCreate",
-        "MethodRWSCreate",
-        "MethodSACreate",
-        "MethodSLBCreate",
-        "MethodSPTCreate",
-        "MethodSRSCreate",
-        "MethodSSCreate",
-        "MethodSTICreate",
-        "MethodSVTCreate",
-        "MethodTOTCreate",
-        "MethodTPCreate",
-        "MethodTRCreate",
-        "MethodWSTCreate",
-    ],
+    body: MethodADCreate
+    | MethodCDCreate
+    | MethodCPTCreate
+    | MethodDEFCreate
+    | MethodDPCreate
+    | MethodDTCreate
+    | MethodESACreate
+    | MethodINCCreate
+    | MethodIWCreate
+    | MethodOTHERCreate
+    | MethodPTCreate
+    | MethodPZCreate
+    | MethodRCDCreate
+    | MethodROCreate
+    | MethodRPCreate
+    | MethodRSCreate
+    | MethodRWSCreate
+    | MethodSACreate
+    | MethodSLBCreate
+    | MethodSPTCreate
+    | MethodSRSCreate
+    | MethodSSCreate
+    | MethodSTICreate
+    | MethodSVTCreate
+    | MethodTOTCreate
+    | MethodTPCreate
+    | MethodTRCreate
+    | MethodWSTCreate,
 ) -> Response[
-    Union[
-        HTTPValidationError,
-        Union[
-            "MethodAD",
-            "MethodCD",
-            "MethodCPT",
-            "MethodDEF",
-            "MethodDP",
-            "MethodDT",
-            "MethodESA",
-            "MethodINC",
-            "MethodIW",
-            "MethodOTHER",
-            "MethodPT",
-            "MethodPZ",
-            "MethodRCD",
-            "MethodRO",
-            "MethodRP",
-            "MethodRS",
-            "MethodRWS",
-            "MethodSA",
-            "MethodSLB",
-            "MethodSPT",
-            "MethodSRS",
-            "MethodSS",
-            "MethodSTI",
-            "MethodSVT",
-            "MethodTOT",
-            "MethodTP",
-            "MethodTR",
-            "MethodWST",
-        ],
-    ]
+    HTTPValidationError
+    | MethodAD
+    | MethodCD
+    | MethodCPT
+    | MethodDEF
+    | MethodDP
+    | MethodDT
+    | MethodESA
+    | MethodINC
+    | MethodIW
+    | MethodOTHER
+    | MethodPT
+    | MethodPZ
+    | MethodRCD
+    | MethodRO
+    | MethodRP
+    | MethodRS
+    | MethodRWS
+    | MethodSA
+    | MethodSLB
+    | MethodSPT
+    | MethodSRS
+    | MethodSS
+    | MethodSTI
+    | MethodSVT
+    | MethodTOT
+    | MethodTP
+    | MethodTR
+    | MethodWST
 ]:
     """Add Method To Location
 
@@ -602,20 +587,19 @@ def sync_detailed(
     Args:
         project_id (str):
         location_id (UUID):
-        body (Union['MethodADCreate', 'MethodCDCreate', 'MethodCPTCreate', 'MethodDEFCreate',
-            'MethodDPCreate', 'MethodDTCreate', 'MethodESACreate', 'MethodINCCreate',
-            'MethodIWCreate', 'MethodOTHERCreate', 'MethodPTCreate', 'MethodPZCreate',
-            'MethodRCDCreate', 'MethodROCreate', 'MethodRPCreate', 'MethodRSCreate',
-            'MethodRWSCreate', 'MethodSACreate', 'MethodSLBCreate', 'MethodSPTCreate',
-            'MethodSRSCreate', 'MethodSSCreate', 'MethodSTICreate', 'MethodSVTCreate',
-            'MethodTOTCreate', 'MethodTPCreate', 'MethodTRCreate', 'MethodWSTCreate']):
+        body (MethodADCreate | MethodCDCreate | MethodCPTCreate | MethodDEFCreate | MethodDPCreate
+            | MethodDTCreate | MethodESACreate | MethodINCCreate | MethodIWCreate | MethodOTHERCreate
+            | MethodPTCreate | MethodPZCreate | MethodRCDCreate | MethodROCreate | MethodRPCreate |
+            MethodRSCreate | MethodRWSCreate | MethodSACreate | MethodSLBCreate | MethodSPTCreate |
+            MethodSRSCreate | MethodSSCreate | MethodSTICreate | MethodSVTCreate | MethodTOTCreate |
+            MethodTPCreate | MethodTRCreate | MethodWSTCreate):
 
     Raises:
         errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
         httpx.TimeoutException: If the request takes longer than Client.timeout.
 
     Returns:
-        Response[Union[HTTPValidationError, Union['MethodAD', 'MethodCD', 'MethodCPT', 'MethodDEF', 'MethodDP', 'MethodDT', 'MethodESA', 'MethodINC', 'MethodIW', 'MethodOTHER', 'MethodPT', 'MethodPZ', 'MethodRCD', 'MethodRO', 'MethodRP', 'MethodRS', 'MethodRWS', 'MethodSA', 'MethodSLB', 'MethodSPT', 'MethodSRS', 'MethodSS', 'MethodSTI', 'MethodSVT', 'MethodTOT', 'MethodTP', 'MethodTR', 'MethodWST']]]
+        Response[HTTPValidationError | MethodAD | MethodCD | MethodCPT | MethodDEF | MethodDP | MethodDT | MethodESA | MethodINC | MethodIW | MethodOTHER | MethodPT | MethodPZ | MethodRCD | MethodRO | MethodRP | MethodRS | MethodRWS | MethodSA | MethodSLB | MethodSPT | MethodSRS | MethodSS | MethodSTI | MethodSVT | MethodTOT | MethodTP | MethodTR | MethodWST]
     """
 
     kwargs = _get_kwargs(
@@ -636,71 +620,66 @@ def sync(
     location_id: UUID,
     *,
     client: AuthenticatedClient,
-    body: Union[
-        "MethodADCreate",
-        "MethodCDCreate",
-        "MethodCPTCreate",
-        "MethodDEFCreate",
-        "MethodDPCreate",
-        "MethodDTCreate",
-        "MethodESACreate",
-        "MethodINCCreate",
-        "MethodIWCreate",
-        "MethodOTHERCreate",
-        "MethodPTCreate",
-        "MethodPZCreate",
-        "MethodRCDCreate",
-        "MethodROCreate",
-        "MethodRPCreate",
-        "MethodRSCreate",
-        "MethodRWSCreate",
-        "MethodSACreate",
-        "MethodSLBCreate",
-        "MethodSPTCreate",
-        "MethodSRSCreate",
-        "MethodSSCreate",
-        "MethodSTICreate",
-        "MethodSVTCreate",
-        "MethodTOTCreate",
-        "MethodTPCreate",
-        "MethodTRCreate",
-        "MethodWSTCreate",
-    ],
-) -> Optional[
-    Union[
-        HTTPValidationError,
-        Union[
-            "MethodAD",
-            "MethodCD",
-            "MethodCPT",
-            "MethodDEF",
-            "MethodDP",
-            "MethodDT",
-            "MethodESA",
-            "MethodINC",
-            "MethodIW",
-            "MethodOTHER",
-            "MethodPT",
-            "MethodPZ",
-            "MethodRCD",
-            "MethodRO",
-            "MethodRP",
-            "MethodRS",
-            "MethodRWS",
-            "MethodSA",
-            "MethodSLB",
-            "MethodSPT",
-            "MethodSRS",
-            "MethodSS",
-            "MethodSTI",
-            "MethodSVT",
-            "MethodTOT",
-            "MethodTP",
-            "MethodTR",
-            "MethodWST",
-        ],
-    ]
-]:
+    body: MethodADCreate
+    | MethodCDCreate
+    | MethodCPTCreate
+    | MethodDEFCreate
+    | MethodDPCreate
+    | MethodDTCreate
+    | MethodESACreate
+    | MethodINCCreate
+    | MethodIWCreate
+    | MethodOTHERCreate
+    | MethodPTCreate
+    | MethodPZCreate
+    | MethodRCDCreate
+    | MethodROCreate
+    | MethodRPCreate
+    | MethodRSCreate
+    | MethodRWSCreate
+    | MethodSACreate
+    | MethodSLBCreate
+    | MethodSPTCreate
+    | MethodSRSCreate
+    | MethodSSCreate
+    | MethodSTICreate
+    | MethodSVTCreate
+    | MethodTOTCreate
+    | MethodTPCreate
+    | MethodTRCreate
+    | MethodWSTCreate,
+) -> (
+    HTTPValidationError
+    | MethodAD
+    | MethodCD
+    | MethodCPT
+    | MethodDEF
+    | MethodDP
+    | MethodDT
+    | MethodESA
+    | MethodINC
+    | MethodIW
+    | MethodOTHER
+    | MethodPT
+    | MethodPZ
+    | MethodRCD
+    | MethodRO
+    | MethodRP
+    | MethodRS
+    | MethodRWS
+    | MethodSA
+    | MethodSLB
+    | MethodSPT
+    | MethodSRS
+    | MethodSS
+    | MethodSTI
+    | MethodSVT
+    | MethodTOT
+    | MethodTP
+    | MethodTR
+    | MethodWST
+    | None
+):
     """Add Method To Location
 
      Add method to location
@@ -708,20 +687,19 @@ def sync(
     Args:
         project_id (str):
         location_id (UUID):
-        body (Union['MethodADCreate', 'MethodCDCreate', 'MethodCPTCreate', 'MethodDEFCreate',
-            'MethodDPCreate', 'MethodDTCreate', 'MethodESACreate', 'MethodINCCreate',
-            'MethodIWCreate', 'MethodOTHERCreate', 'MethodPTCreate', 'MethodPZCreate',
-            'MethodRCDCreate', 'MethodROCreate', 'MethodRPCreate', 'MethodRSCreate',
-            'MethodRWSCreate', 'MethodSACreate', 'MethodSLBCreate', 'MethodSPTCreate',
-            'MethodSRSCreate', 'MethodSSCreate', 'MethodSTICreate', 'MethodSVTCreate',
-            'MethodTOTCreate', 'MethodTPCreate', 'MethodTRCreate', 'MethodWSTCreate']):
+        body (MethodADCreate | MethodCDCreate | MethodCPTCreate | MethodDEFCreate | MethodDPCreate
+            | MethodDTCreate | MethodESACreate | MethodINCCreate | MethodIWCreate | MethodOTHERCreate
+            | MethodPTCreate | MethodPZCreate | MethodRCDCreate | MethodROCreate | MethodRPCreate |
+            MethodRSCreate | MethodRWSCreate | MethodSACreate | MethodSLBCreate | MethodSPTCreate |
+            MethodSRSCreate | MethodSSCreate | MethodSTICreate | MethodSVTCreate | MethodTOTCreate |
+            MethodTPCreate | MethodTRCreate | MethodWSTCreate):
 
     Raises:
         errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
         httpx.TimeoutException: If the request takes longer than Client.timeout.
 
     Returns:
-        Union[HTTPValidationError, Union['MethodAD', 'MethodCD', 'MethodCPT', 'MethodDEF', 'MethodDP', 'MethodDT', 'MethodESA', 'MethodINC', 'MethodIW', 'MethodOTHER', 'MethodPT', 'MethodPZ', 'MethodRCD', 'MethodRO', 'MethodRP', 'MethodRS', 'MethodRWS', 'MethodSA', 'MethodSLB', 'MethodSPT', 'MethodSRS', 'MethodSS', 'MethodSTI', 'MethodSVT', 'MethodTOT', 'MethodTP', 'MethodTR', 'MethodWST']]
+        HTTPValidationError | MethodAD | MethodCD | MethodCPT | MethodDEF | MethodDP | MethodDT | MethodESA | MethodINC | MethodIW | MethodOTHER | MethodPT | MethodPZ | MethodRCD | MethodRO | MethodRP | MethodRS | MethodRWS | MethodSA | MethodSLB | MethodSPT | MethodSRS | MethodSS | MethodSTI | MethodSVT | MethodTOT | MethodTP | MethodTR | MethodWST
     """
 
     return sync_detailed(
@@ -737,70 +715,64 @@ async def asyncio_detailed(
     location_id: UUID,
     *,
     client: AuthenticatedClient,
-    body: Union[
-        "MethodADCreate",
-        "MethodCDCreate",
-        "MethodCPTCreate",
-        "MethodDEFCreate",
-        "MethodDPCreate",
-        "MethodDTCreate",
-        "MethodESACreate",
-        "MethodINCCreate",
-        "MethodIWCreate",
-        "MethodOTHERCreate",
-        "MethodPTCreate",
-        "MethodPZCreate",
-        "MethodRCDCreate",
-        "MethodROCreate",
-        "MethodRPCreate",
-        "MethodRSCreate",
-        "MethodRWSCreate",
-        "MethodSACreate",
-        "MethodSLBCreate",
-        "MethodSPTCreate",
-        "MethodSRSCreate",
-        "MethodSSCreate",
-        "MethodSTICreate",
-        "MethodSVTCreate",
-        "MethodTOTCreate",
-        "MethodTPCreate",
-        "MethodTRCreate",
-        "MethodWSTCreate",
-    ],
+    body: MethodADCreate
+    | MethodCDCreate
+    | MethodCPTCreate
+    | MethodDEFCreate
+    | MethodDPCreate
+    | MethodDTCreate
+    | MethodESACreate
+    | MethodINCCreate
+    | MethodIWCreate
+    | MethodOTHERCreate
+    | MethodPTCreate
+    | MethodPZCreate
+    | MethodRCDCreate
+    | MethodROCreate
+    | MethodRPCreate
+    | MethodRSCreate
+    | MethodRWSCreate
+    | MethodSACreate
+    | MethodSLBCreate
+    | MethodSPTCreate
+    | MethodSRSCreate
+    | MethodSSCreate
+    | MethodSTICreate
+    | MethodSVTCreate
+    | MethodTOTCreate
+    | MethodTPCreate
+    | MethodTRCreate
+    | MethodWSTCreate,
 ) -> Response[
-    Union[
-        HTTPValidationError,
-        Union[
-            "MethodAD",
-            "MethodCD",
-            "MethodCPT",
-            "MethodDEF",
-            "MethodDP",
-            "MethodDT",
-            "MethodESA",
-            "MethodINC",
-            "MethodIW",
-            "MethodOTHER",
-            "MethodPT",
-            "MethodPZ",
-            "MethodRCD",
-            "MethodRO",
-            "MethodRP",
-            "MethodRS",
-            "MethodRWS",
-            "MethodSA",
-            "MethodSLB",
-            "MethodSPT",
-            "MethodSRS",
-            "MethodSS",
-            "MethodSTI",
-            "MethodSVT",
-            "MethodTOT",
-            "MethodTP",
-            "MethodTR",
-            "MethodWST",
-        ],
-    ]
+    HTTPValidationError
+    | MethodAD
+    | MethodCD
+    | MethodCPT
+    | MethodDEF
+    | MethodDP
+    | MethodDT
+    | MethodESA
+    | MethodINC
+    | MethodIW
+    | MethodOTHER
+    | MethodPT
+    | MethodPZ
+    | MethodRCD
+    | MethodRO
+    | MethodRP
+    | MethodRS
+    | MethodRWS
+    | MethodSA
+    | MethodSLB
+    | MethodSPT
+    | MethodSRS
+    | MethodSS
+    | MethodSTI
+    | MethodSVT
+    | MethodTOT
+    | MethodTP
+    | MethodTR
+    | MethodWST
 ]:
     """Add Method To Location
 
@@ -809,20 +781,19 @@ async def asyncio_detailed(
     Args:
         project_id (str):
         location_id (UUID):
-        body (Union['MethodADCreate', 'MethodCDCreate', 'MethodCPTCreate', 'MethodDEFCreate',
-            'MethodDPCreate', 'MethodDTCreate', 'MethodESACreate', 'MethodINCCreate',
-            'MethodIWCreate', 'MethodOTHERCreate', 'MethodPTCreate', 'MethodPZCreate',
-            'MethodRCDCreate', 'MethodROCreate', 'MethodRPCreate', 'MethodRSCreate',
-            'MethodRWSCreate', 'MethodSACreate', 'MethodSLBCreate', 'MethodSPTCreate',
-            'MethodSRSCreate', 'MethodSSCreate', 'MethodSTICreate', 'MethodSVTCreate',
-            'MethodTOTCreate', 'MethodTPCreate', 'MethodTRCreate', 'MethodWSTCreate']):
+        body (MethodADCreate | MethodCDCreate | MethodCPTCreate | MethodDEFCreate | MethodDPCreate
+            | MethodDTCreate | MethodESACreate | MethodINCCreate | MethodIWCreate | MethodOTHERCreate
+            | MethodPTCreate | MethodPZCreate | MethodRCDCreate | MethodROCreate | MethodRPCreate |
+            MethodRSCreate | MethodRWSCreate | MethodSACreate | MethodSLBCreate | MethodSPTCreate |
+            MethodSRSCreate | MethodSSCreate | MethodSTICreate | MethodSVTCreate | MethodTOTCreate |
+            MethodTPCreate | MethodTRCreate | MethodWSTCreate):
 
     Raises:
         errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
         httpx.TimeoutException: If the request takes longer than Client.timeout.
 
     Returns:
-        Response[Union[HTTPValidationError, Union['MethodAD', 'MethodCD', 'MethodCPT', 'MethodDEF', 'MethodDP', 'MethodDT', 'MethodESA', 'MethodINC', 'MethodIW', 'MethodOTHER', 'MethodPT', 'MethodPZ', 'MethodRCD', 'MethodRO', 'MethodRP', 'MethodRS', 'MethodRWS', 'MethodSA', 'MethodSLB', 'MethodSPT', 'MethodSRS', 'MethodSS', 'MethodSTI', 'MethodSVT', 'MethodTOT', 'MethodTP', 'MethodTR', 'MethodWST']]]
+        Response[HTTPValidationError | MethodAD | MethodCD | MethodCPT | MethodDEF | MethodDP | MethodDT | MethodESA | MethodINC | MethodIW | MethodOTHER | MethodPT | MethodPZ | MethodRCD | MethodRO | MethodRP | MethodRS | MethodRWS | MethodSA | MethodSLB | MethodSPT | MethodSRS | MethodSS | MethodSTI | MethodSVT | MethodTOT | MethodTP | MethodTR | MethodWST]
     """
 
     kwargs = _get_kwargs(
@@ -841,71 +812,66 @@ async def asyncio(
     location_id: UUID,
     *,
     client: AuthenticatedClient,
-    body: Union[
-        "MethodADCreate",
-        "MethodCDCreate",
-        "MethodCPTCreate",
-        "MethodDEFCreate",
-        "MethodDPCreate",
-        "MethodDTCreate",
-        "MethodESACreate",
-        "MethodINCCreate",
-        "MethodIWCreate",
-        "MethodOTHERCreate",
-        "MethodPTCreate",
-        "MethodPZCreate",
-        "MethodRCDCreate",
-        "MethodROCreate",
-        "MethodRPCreate",
-        "MethodRSCreate",
-        "MethodRWSCreate",
-        "MethodSACreate",
-        "MethodSLBCreate",
-        "MethodSPTCreate",
-        "MethodSRSCreate",
-        "MethodSSCreate",
-        "MethodSTICreate",
-        "MethodSVTCreate",
-        "MethodTOTCreate",
-        "MethodTPCreate",
-        "MethodTRCreate",
-        "MethodWSTCreate",
-    ],
-) -> Optional[
-    Union[
-        HTTPValidationError,
-        Union[
-            "MethodAD",
-            "MethodCD",
-            "MethodCPT",
-            "MethodDEF",
-            "MethodDP",
-            "MethodDT",
-            "MethodESA",
-            "MethodINC",
-            "MethodIW",
-            "MethodOTHER",
-            "MethodPT",
-            "MethodPZ",
-            "MethodRCD",
-            "MethodRO",
-            "MethodRP",
-            "MethodRS",
-            "MethodRWS",
-            "MethodSA",
-            "MethodSLB",
-            "MethodSPT",
-            "MethodSRS",
-            "MethodSS",
-            "MethodSTI",
-            "MethodSVT",
-            "MethodTOT",
-            "MethodTP",
-            "MethodTR",
-            "MethodWST",
-        ],
-    ]
-]:
+    body: MethodADCreate
+    | MethodCDCreate
+    | MethodCPTCreate
+    | MethodDEFCreate
+    | MethodDPCreate
+    | MethodDTCreate
+    | MethodESACreate
+    | MethodINCCreate
+    | MethodIWCreate
+    | MethodOTHERCreate
+    | MethodPTCreate
+    | MethodPZCreate
+    | MethodRCDCreate
+    | MethodROCreate
+    | MethodRPCreate
+    | MethodRSCreate
+    | MethodRWSCreate
+    | MethodSACreate
+    | MethodSLBCreate
+    | MethodSPTCreate
+    | MethodSRSCreate
+    | MethodSSCreate
+    | MethodSTICreate
+    | MethodSVTCreate
+    | MethodTOTCreate
+    | MethodTPCreate
+    | MethodTRCreate
+    | MethodWSTCreate,
+) -> (
+    HTTPValidationError
+    | MethodAD
+    | MethodCD
+    | MethodCPT
+    | MethodDEF
+    | MethodDP
+    | MethodDT
+    | MethodESA
+    | MethodINC
+    | MethodIW
+    | MethodOTHER
+    | MethodPT
+    | MethodPZ
+    | MethodRCD
+    | MethodRO
+    | MethodRP
+    | MethodRS
+    | MethodRWS
+    | MethodSA
+    | MethodSLB
+    | MethodSPT
+    | MethodSRS
+    | MethodSS
+    | MethodSTI
+    | MethodSVT
+    | MethodTOT
+    | MethodTP
+    | MethodTR
+    | MethodWST
+    | None
+):
     """Add Method To Location
 
      Add method to location
@@ -913,20 +879,19 @@ async def asyncio(
     Args:
         project_id (str):
         location_id (UUID):
-        body (Union['MethodADCreate', 'MethodCDCreate', 'MethodCPTCreate', 'MethodDEFCreate',
-            'MethodDPCreate', 'MethodDTCreate', 'MethodESACreate', 'MethodINCCreate',
-            'MethodIWCreate', 'MethodOTHERCreate', 'MethodPTCreate', 'MethodPZCreate',
-            'MethodRCDCreate', 'MethodROCreate', 'MethodRPCreate', 'MethodRSCreate',
-            'MethodRWSCreate', 'MethodSACreate', 'MethodSLBCreate', 'MethodSPTCreate',
-            'MethodSRSCreate', 'MethodSSCreate', 'MethodSTICreate', 'MethodSVTCreate',
-            'MethodTOTCreate', 'MethodTPCreate', 'MethodTRCreate', 'MethodWSTCreate']):
+        body (MethodADCreate | MethodCDCreate | MethodCPTCreate | MethodDEFCreate | MethodDPCreate
+            | MethodDTCreate | MethodESACreate | MethodINCCreate | MethodIWCreate | MethodOTHERCreate
+            | MethodPTCreate | MethodPZCreate | MethodRCDCreate | MethodROCreate | MethodRPCreate |
+            MethodRSCreate | MethodRWSCreate | MethodSACreate | MethodSLBCreate | MethodSPTCreate |
+            MethodSRSCreate | MethodSSCreate | MethodSTICreate | MethodSVTCreate | MethodTOTCreate |
+            MethodTPCreate | MethodTRCreate | MethodWSTCreate):
 
     Raises:
         errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
         httpx.TimeoutException: If the request takes longer than Client.timeout.
 
     Returns:
-        Union[HTTPValidationError, Union['MethodAD', 'MethodCD', 'MethodCPT', 'MethodDEF', 'MethodDP', 'MethodDT', 'MethodESA', 'MethodINC', 'MethodIW', 'MethodOTHER', 'MethodPT', 'MethodPZ', 'MethodRCD', 'MethodRO', 'MethodRP', 'MethodRS', 'MethodRWS', 'MethodSA', 'MethodSLB', 'MethodSPT', 'MethodSRS', 'MethodSS', 'MethodSTI', 'MethodSVT', 'MethodTOT', 'MethodTP', 'MethodTR', 'MethodWST']]
+        HTTPValidationError | MethodAD | MethodCD | MethodCPT | MethodDEF | MethodDP | MethodDT | MethodESA | MethodINC | MethodIW | MethodOTHER | MethodPT | MethodPZ | MethodRCD | MethodRO | MethodRP | MethodRS | MethodRWS | MethodSA | MethodSLB | MethodSPT | MethodSRS | MethodSS | MethodSTI | MethodSVT | MethodTOT | MethodTP | MethodTR | MethodWST
     """
 
     return (
