@@ -143,7 +143,7 @@ def _parse_response(
                     response_200_item_type_0 = MethodCPT.from_dict(data)
 
                     return response_200_item_type_0
-                except:  # noqa: E722
+                except (TypeError, ValueError, AttributeError, KeyError):
                     pass
                 try:
                     if not isinstance(data, dict):
@@ -151,7 +151,7 @@ def _parse_response(
                     response_200_item_type_1 = MethodTOT.from_dict(data)
 
                     return response_200_item_type_1
-                except:  # noqa: E722
+                except (TypeError, ValueError, AttributeError, KeyError):
                     pass
                 try:
                     if not isinstance(data, dict):
@@ -159,7 +159,7 @@ def _parse_response(
                     response_200_item_type_2 = MethodRP.from_dict(data)
 
                     return response_200_item_type_2
-                except:  # noqa: E722
+                except (TypeError, ValueError, AttributeError, KeyError):
                     pass
                 try:
                     if not isinstance(data, dict):
@@ -167,7 +167,7 @@ def _parse_response(
                     response_200_item_type_3 = MethodSA.from_dict(data)
 
                     return response_200_item_type_3
-                except:  # noqa: E722
+                except (TypeError, ValueError, AttributeError, KeyError):
                     pass
                 try:
                     if not isinstance(data, dict):
@@ -175,7 +175,7 @@ def _parse_response(
                     response_200_item_type_4 = MethodPZ.from_dict(data)
 
                     return response_200_item_type_4
-                except:  # noqa: E722
+                except (TypeError, ValueError, AttributeError, KeyError):
                     pass
                 try:
                     if not isinstance(data, dict):
@@ -183,7 +183,7 @@ def _parse_response(
                     response_200_item_type_5 = MethodSS.from_dict(data)
 
                     return response_200_item_type_5
-                except:  # noqa: E722
+                except (TypeError, ValueError, AttributeError, KeyError):
                     pass
                 try:
                     if not isinstance(data, dict):
@@ -191,7 +191,7 @@ def _parse_response(
                     response_200_item_type_6 = MethodRWS.from_dict(data)
 
                     return response_200_item_type_6
-                except:  # noqa: E722
+                except (TypeError, ValueError, AttributeError, KeyError):
                     pass
                 try:
                     if not isinstance(data, dict):
@@ -199,7 +199,7 @@ def _parse_response(
                     response_200_item_type_7 = MethodRCD.from_dict(data)
 
                     return response_200_item_type_7
-                except:  # noqa: E722
+                except (TypeError, ValueError, AttributeError, KeyError):
                     pass
                 try:
                     if not isinstance(data, dict):
@@ -207,7 +207,7 @@ def _parse_response(
                     response_200_item_type_8 = MethodRS.from_dict(data)
 
                     return response_200_item_type_8
-                except:  # noqa: E722
+                except (TypeError, ValueError, AttributeError, KeyError):
                     pass
                 try:
                     if not isinstance(data, dict):
@@ -215,7 +215,7 @@ def _parse_response(
                     response_200_item_type_9 = MethodSVT.from_dict(data)
 
                     return response_200_item_type_9
-                except:  # noqa: E722
+                except (TypeError, ValueError, AttributeError, KeyError):
                     pass
                 try:
                     if not isinstance(data, dict):
@@ -223,7 +223,7 @@ def _parse_response(
                     response_200_item_type_10 = MethodSPT.from_dict(data)
 
                     return response_200_item_type_10
-                except:  # noqa: E722
+                except (TypeError, ValueError, AttributeError, KeyError):
                     pass
                 try:
                     if not isinstance(data, dict):
@@ -231,7 +231,7 @@ def _parse_response(
                     response_200_item_type_11 = MethodCD.from_dict(data)
 
                     return response_200_item_type_11
-                except:  # noqa: E722
+                except (TypeError, ValueError, AttributeError, KeyError):
                     pass
                 try:
                     if not isinstance(data, dict):
@@ -239,7 +239,7 @@ def _parse_response(
                     response_200_item_type_12 = MethodTP.from_dict(data)
 
                     return response_200_item_type_12
-                except:  # noqa: E722
+                except (TypeError, ValueError, AttributeError, KeyError):
                     pass
                 try:
                     if not isinstance(data, dict):
@@ -247,7 +247,7 @@ def _parse_response(
                     response_200_item_type_13 = MethodPT.from_dict(data)
 
                     return response_200_item_type_13
-                except:  # noqa: E722
+                except (TypeError, ValueError, AttributeError, KeyError):
                     pass
                 try:
                     if not isinstance(data, dict):
@@ -255,7 +255,7 @@ def _parse_response(
                     response_200_item_type_14 = MethodESA.from_dict(data)
 
                     return response_200_item_type_14
-                except:  # noqa: E722
+                except (TypeError, ValueError, AttributeError, KeyError):
                     pass
                 try:
                     if not isinstance(data, dict):
@@ -263,7 +263,7 @@ def _parse_response(
                     response_200_item_type_15 = MethodTR.from_dict(data)
 
                     return response_200_item_type_15
-                except:  # noqa: E722
+                except (TypeError, ValueError, AttributeError, KeyError):
                     pass
                 try:
                     if not isinstance(data, dict):
@@ -271,7 +271,7 @@ def _parse_response(
                     response_200_item_type_16 = MethodAD.from_dict(data)
 
                     return response_200_item_type_16
-                except:  # noqa: E722
+                except (TypeError, ValueError, AttributeError, KeyError):
                     pass
                 try:
                     if not isinstance(data, dict):
@@ -279,7 +279,7 @@ def _parse_response(
                     response_200_item_type_17 = MethodRO.from_dict(data)
 
                     return response_200_item_type_17
-                except:  # noqa: E722
+                except (TypeError, ValueError, AttributeError, KeyError):
                     pass
                 try:
                     if not isinstance(data, dict):
@@ -287,7 +287,7 @@ def _parse_response(
                     response_200_item_type_18 = MethodINC.from_dict(data)
 
                     return response_200_item_type_18
-                except:  # noqa: E722
+                except (TypeError, ValueError, AttributeError, KeyError):
                     pass
                 try:
                     if not isinstance(data, dict):
@@ -295,7 +295,7 @@ def _parse_response(
                     response_200_item_type_19 = MethodDEF.from_dict(data)
 
                     return response_200_item_type_19
-                except:  # noqa: E722
+                except (TypeError, ValueError, AttributeError, KeyError):
                     pass
                 try:
                     if not isinstance(data, dict):
@@ -303,7 +303,7 @@ def _parse_response(
                     response_200_item_type_20 = MethodIW.from_dict(data)
 
                     return response_200_item_type_20
-                except:  # noqa: E722
+                except (TypeError, ValueError, AttributeError, KeyError):
                     pass
                 try:
                     if not isinstance(data, dict):
@@ -311,7 +311,7 @@ def _parse_response(
                     response_200_item_type_21 = MethodDT.from_dict(data)
 
                     return response_200_item_type_21
-                except:  # noqa: E722
+                except (TypeError, ValueError, AttributeError, KeyError):
                     pass
                 try:
                     if not isinstance(data, dict):
@@ -319,7 +319,7 @@ def _parse_response(
                     response_200_item_type_22 = MethodOTHER.from_dict(data)
 
                     return response_200_item_type_22
-                except:  # noqa: E722
+                except (TypeError, ValueError, AttributeError, KeyError):
                     pass
                 try:
                     if not isinstance(data, dict):
@@ -327,7 +327,7 @@ def _parse_response(
                     response_200_item_type_23 = MethodSRS.from_dict(data)
 
                     return response_200_item_type_23
-                except:  # noqa: E722
+                except (TypeError, ValueError, AttributeError, KeyError):
                     pass
                 try:
                     if not isinstance(data, dict):
@@ -335,7 +335,7 @@ def _parse_response(
                     response_200_item_type_24 = MethodDP.from_dict(data)
 
                     return response_200_item_type_24
-                except:  # noqa: E722
+                except (TypeError, ValueError, AttributeError, KeyError):
                     pass
                 try:
                     if not isinstance(data, dict):
@@ -343,7 +343,7 @@ def _parse_response(
                     response_200_item_type_25 = MethodWST.from_dict(data)
 
                     return response_200_item_type_25
-                except:  # noqa: E722
+                except (TypeError, ValueError, AttributeError, KeyError):
                     pass
                 try:
                     if not isinstance(data, dict):
@@ -351,7 +351,7 @@ def _parse_response(
                     response_200_item_type_26 = MethodSLB.from_dict(data)
 
                     return response_200_item_type_26
-                except:  # noqa: E722
+                except (TypeError, ValueError, AttributeError, KeyError):
                     pass
                 if not isinstance(data, dict):
                     raise TypeError()
