@@ -1,5 +1,5 @@
 from http import HTTPStatus
-from typing import Any, Optional, Union
+from typing import Any
 from uuid import UUID
 
 import httpx
@@ -39,19 +39,17 @@ def _get_kwargs(
     method_id: UUID,
     method_data_id: UUID,
     *,
-    body: Union[
-        "MethodCPTDataUpdate",
-        "MethodDTDataUpdate",
-        "MethodPZDataUpdate",
-        "MethodRCDDataUpdate",
-        "MethodRPDataUpdate",
-        "MethodSRSDataUpdate",
-        "MethodSSDataUpdate",
-        "MethodSVTDataUpdate",
-        "MethodTOTDataUpdate",
-        "MethodTRDataUpdate",
-        "MethodWSTDataUpdate",
-    ],
+    body: MethodCPTDataUpdate
+    | MethodDTDataUpdate
+    | MethodPZDataUpdate
+    | MethodRCDDataUpdate
+    | MethodRPDataUpdate
+    | MethodSRSDataUpdate
+    | MethodSSDataUpdate
+    | MethodSVTDataUpdate
+    | MethodTOTDataUpdate
+    | MethodTRDataUpdate
+    | MethodWSTDataUpdate,
 ) -> dict[str, Any]:
     headers: dict[str, Any] = {}
 
@@ -91,51 +89,48 @@ def _get_kwargs(
 
 
 def _parse_response(
-    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
-) -> Optional[
-    Union[
-        HTTPValidationError,
-        Union[
-            "MethodCPTData",
-            "MethodDPData",
-            "MethodDTData",
-            "MethodPZData",
-            "MethodRCDData",
-            "MethodRPData",
-            "MethodSRSData",
-            "MethodSSData",
-            "MethodSVTData",
-            "MethodTOTData",
-            "MethodTRData",
-            "MethodWSTData",
-        ],
-    ]
-]:
+    *, client: AuthenticatedClient | Client, response: httpx.Response
+) -> (
+    HTTPValidationError
+    | MethodCPTData
+    | MethodDPData
+    | MethodDTData
+    | MethodPZData
+    | MethodRCDData
+    | MethodRPData
+    | MethodSRSData
+    | MethodSSData
+    | MethodSVTData
+    | MethodTOTData
+    | MethodTRData
+    | MethodWSTData
+    | None
+):
     if response.status_code == 200:
 
         def _parse_response_200(
             data: object,
-        ) -> Union[
-            "MethodCPTData",
-            "MethodDPData",
-            "MethodDTData",
-            "MethodPZData",
-            "MethodRCDData",
-            "MethodRPData",
-            "MethodSRSData",
-            "MethodSSData",
-            "MethodSVTData",
-            "MethodTOTData",
-            "MethodTRData",
-            "MethodWSTData",
-        ]:
+        ) -> (
+            MethodCPTData
+            | MethodDPData
+            | MethodDTData
+            | MethodPZData
+            | MethodRCDData
+            | MethodRPData
+            | MethodSRSData
+            | MethodSSData
+            | MethodSVTData
+            | MethodTOTData
+            | MethodTRData
+            | MethodWSTData
+        ):
             try:
                 if not isinstance(data, dict):
                     raise TypeError()
                 response_200_type_0 = MethodCPTData.from_dict(data)
 
                 return response_200_type_0
-            except:  # noqa: E722
+            except (TypeError, ValueError, AttributeError, KeyError):
                 pass
             try:
                 if not isinstance(data, dict):
@@ -143,7 +138,7 @@ def _parse_response(
                 response_200_type_1 = MethodDPData.from_dict(data)
 
                 return response_200_type_1
-            except:  # noqa: E722
+            except (TypeError, ValueError, AttributeError, KeyError):
                 pass
             try:
                 if not isinstance(data, dict):
@@ -151,7 +146,7 @@ def _parse_response(
                 response_200_type_2 = MethodDTData.from_dict(data)
 
                 return response_200_type_2
-            except:  # noqa: E722
+            except (TypeError, ValueError, AttributeError, KeyError):
                 pass
             try:
                 if not isinstance(data, dict):
@@ -159,7 +154,7 @@ def _parse_response(
                 response_200_type_3 = MethodPZData.from_dict(data)
 
                 return response_200_type_3
-            except:  # noqa: E722
+            except (TypeError, ValueError, AttributeError, KeyError):
                 pass
             try:
                 if not isinstance(data, dict):
@@ -167,7 +162,7 @@ def _parse_response(
                 response_200_type_4 = MethodRCDData.from_dict(data)
 
                 return response_200_type_4
-            except:  # noqa: E722
+            except (TypeError, ValueError, AttributeError, KeyError):
                 pass
             try:
                 if not isinstance(data, dict):
@@ -175,7 +170,7 @@ def _parse_response(
                 response_200_type_5 = MethodRPData.from_dict(data)
 
                 return response_200_type_5
-            except:  # noqa: E722
+            except (TypeError, ValueError, AttributeError, KeyError):
                 pass
             try:
                 if not isinstance(data, dict):
@@ -183,7 +178,7 @@ def _parse_response(
                 response_200_type_6 = MethodSSData.from_dict(data)
 
                 return response_200_type_6
-            except:  # noqa: E722
+            except (TypeError, ValueError, AttributeError, KeyError):
                 pass
             try:
                 if not isinstance(data, dict):
@@ -191,7 +186,7 @@ def _parse_response(
                 response_200_type_7 = MethodSRSData.from_dict(data)
 
                 return response_200_type_7
-            except:  # noqa: E722
+            except (TypeError, ValueError, AttributeError, KeyError):
                 pass
             try:
                 if not isinstance(data, dict):
@@ -199,7 +194,7 @@ def _parse_response(
                 response_200_type_8 = MethodSVTData.from_dict(data)
 
                 return response_200_type_8
-            except:  # noqa: E722
+            except (TypeError, ValueError, AttributeError, KeyError):
                 pass
             try:
                 if not isinstance(data, dict):
@@ -207,7 +202,7 @@ def _parse_response(
                 response_200_type_9 = MethodTOTData.from_dict(data)
 
                 return response_200_type_9
-            except:  # noqa: E722
+            except (TypeError, ValueError, AttributeError, KeyError):
                 pass
             try:
                 if not isinstance(data, dict):
@@ -215,7 +210,7 @@ def _parse_response(
                 response_200_type_10 = MethodTRData.from_dict(data)
 
                 return response_200_type_10
-            except:  # noqa: E722
+            except (TypeError, ValueError, AttributeError, KeyError):
                 pass
             if not isinstance(data, dict):
                 raise TypeError()
@@ -239,25 +234,21 @@ def _parse_response(
 
 
 def _build_response(
-    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
+    *, client: AuthenticatedClient | Client, response: httpx.Response
 ) -> Response[
-    Union[
-        HTTPValidationError,
-        Union[
-            "MethodCPTData",
-            "MethodDPData",
-            "MethodDTData",
-            "MethodPZData",
-            "MethodRCDData",
-            "MethodRPData",
-            "MethodSRSData",
-            "MethodSSData",
-            "MethodSVTData",
-            "MethodTOTData",
-            "MethodTRData",
-            "MethodWSTData",
-        ],
-    ]
+    HTTPValidationError
+    | MethodCPTData
+    | MethodDPData
+    | MethodDTData
+    | MethodPZData
+    | MethodRCDData
+    | MethodRPData
+    | MethodSRSData
+    | MethodSSData
+    | MethodSVTData
+    | MethodTOTData
+    | MethodTRData
+    | MethodWSTData
 ]:
     return Response(
         status_code=HTTPStatus(response.status_code),
@@ -274,37 +265,31 @@ def sync_detailed(
     method_data_id: UUID,
     *,
     client: AuthenticatedClient,
-    body: Union[
-        "MethodCPTDataUpdate",
-        "MethodDTDataUpdate",
-        "MethodPZDataUpdate",
-        "MethodRCDDataUpdate",
-        "MethodRPDataUpdate",
-        "MethodSRSDataUpdate",
-        "MethodSSDataUpdate",
-        "MethodSVTDataUpdate",
-        "MethodTOTDataUpdate",
-        "MethodTRDataUpdate",
-        "MethodWSTDataUpdate",
-    ],
+    body: MethodCPTDataUpdate
+    | MethodDTDataUpdate
+    | MethodPZDataUpdate
+    | MethodRCDDataUpdate
+    | MethodRPDataUpdate
+    | MethodSRSDataUpdate
+    | MethodSSDataUpdate
+    | MethodSVTDataUpdate
+    | MethodTOTDataUpdate
+    | MethodTRDataUpdate
+    | MethodWSTDataUpdate,
 ) -> Response[
-    Union[
-        HTTPValidationError,
-        Union[
-            "MethodCPTData",
-            "MethodDPData",
-            "MethodDTData",
-            "MethodPZData",
-            "MethodRCDData",
-            "MethodRPData",
-            "MethodSRSData",
-            "MethodSSData",
-            "MethodSVTData",
-            "MethodTOTData",
-            "MethodTRData",
-            "MethodWSTData",
-        ],
-    ]
+    HTTPValidationError
+    | MethodCPTData
+    | MethodDPData
+    | MethodDTData
+    | MethodPZData
+    | MethodRCDData
+    | MethodRPData
+    | MethodSRSData
+    | MethodSSData
+    | MethodSVTData
+    | MethodTOTData
+    | MethodTRData
+    | MethodWSTData
 ]:
     """Update Data Row
 
@@ -315,17 +300,16 @@ def sync_detailed(
         location_id (UUID):
         method_id (UUID):
         method_data_id (UUID):
-        body (Union['MethodCPTDataUpdate', 'MethodDTDataUpdate', 'MethodPZDataUpdate',
-            'MethodRCDDataUpdate', 'MethodRPDataUpdate', 'MethodSRSDataUpdate', 'MethodSSDataUpdate',
-            'MethodSVTDataUpdate', 'MethodTOTDataUpdate', 'MethodTRDataUpdate',
-            'MethodWSTDataUpdate']):
+        body (MethodCPTDataUpdate | MethodDTDataUpdate | MethodPZDataUpdate | MethodRCDDataUpdate
+            | MethodRPDataUpdate | MethodSRSDataUpdate | MethodSSDataUpdate | MethodSVTDataUpdate |
+            MethodTOTDataUpdate | MethodTRDataUpdate | MethodWSTDataUpdate):
 
     Raises:
         errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
         httpx.TimeoutException: If the request takes longer than Client.timeout.
 
     Returns:
-        Response[Union[HTTPValidationError, Union['MethodCPTData', 'MethodDPData', 'MethodDTData', 'MethodPZData', 'MethodRCDData', 'MethodRPData', 'MethodSRSData', 'MethodSSData', 'MethodSVTData', 'MethodTOTData', 'MethodTRData', 'MethodWSTData']]]
+        Response[HTTPValidationError | MethodCPTData | MethodDPData | MethodDTData | MethodPZData | MethodRCDData | MethodRPData | MethodSRSData | MethodSSData | MethodSVTData | MethodTOTData | MethodTRData | MethodWSTData]
     """
 
     kwargs = _get_kwargs(
@@ -350,38 +334,33 @@ def sync(
     method_data_id: UUID,
     *,
     client: AuthenticatedClient,
-    body: Union[
-        "MethodCPTDataUpdate",
-        "MethodDTDataUpdate",
-        "MethodPZDataUpdate",
-        "MethodRCDDataUpdate",
-        "MethodRPDataUpdate",
-        "MethodSRSDataUpdate",
-        "MethodSSDataUpdate",
-        "MethodSVTDataUpdate",
-        "MethodTOTDataUpdate",
-        "MethodTRDataUpdate",
-        "MethodWSTDataUpdate",
-    ],
-) -> Optional[
-    Union[
-        HTTPValidationError,
-        Union[
-            "MethodCPTData",
-            "MethodDPData",
-            "MethodDTData",
-            "MethodPZData",
-            "MethodRCDData",
-            "MethodRPData",
-            "MethodSRSData",
-            "MethodSSData",
-            "MethodSVTData",
-            "MethodTOTData",
-            "MethodTRData",
-            "MethodWSTData",
-        ],
-    ]
-]:
+    body: MethodCPTDataUpdate
+    | MethodDTDataUpdate
+    | MethodPZDataUpdate
+    | MethodRCDDataUpdate
+    | MethodRPDataUpdate
+    | MethodSRSDataUpdate
+    | MethodSSDataUpdate
+    | MethodSVTDataUpdate
+    | MethodTOTDataUpdate
+    | MethodTRDataUpdate
+    | MethodWSTDataUpdate,
+) -> (
+    HTTPValidationError
+    | MethodCPTData
+    | MethodDPData
+    | MethodDTData
+    | MethodPZData
+    | MethodRCDData
+    | MethodRPData
+    | MethodSRSData
+    | MethodSSData
+    | MethodSVTData
+    | MethodTOTData
+    | MethodTRData
+    | MethodWSTData
+    | None
+):
     """Update Data Row
 
      Update a method's single data line
@@ -391,17 +370,16 @@ def sync(
         location_id (UUID):
         method_id (UUID):
         method_data_id (UUID):
-        body (Union['MethodCPTDataUpdate', 'MethodDTDataUpdate', 'MethodPZDataUpdate',
-            'MethodRCDDataUpdate', 'MethodRPDataUpdate', 'MethodSRSDataUpdate', 'MethodSSDataUpdate',
-            'MethodSVTDataUpdate', 'MethodTOTDataUpdate', 'MethodTRDataUpdate',
-            'MethodWSTDataUpdate']):
+        body (MethodCPTDataUpdate | MethodDTDataUpdate | MethodPZDataUpdate | MethodRCDDataUpdate
+            | MethodRPDataUpdate | MethodSRSDataUpdate | MethodSSDataUpdate | MethodSVTDataUpdate |
+            MethodTOTDataUpdate | MethodTRDataUpdate | MethodWSTDataUpdate):
 
     Raises:
         errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
         httpx.TimeoutException: If the request takes longer than Client.timeout.
 
     Returns:
-        Union[HTTPValidationError, Union['MethodCPTData', 'MethodDPData', 'MethodDTData', 'MethodPZData', 'MethodRCDData', 'MethodRPData', 'MethodSRSData', 'MethodSSData', 'MethodSVTData', 'MethodTOTData', 'MethodTRData', 'MethodWSTData']]
+        HTTPValidationError | MethodCPTData | MethodDPData | MethodDTData | MethodPZData | MethodRCDData | MethodRPData | MethodSRSData | MethodSSData | MethodSVTData | MethodTOTData | MethodTRData | MethodWSTData
     """
 
     return sync_detailed(
@@ -421,37 +399,31 @@ async def asyncio_detailed(
     method_data_id: UUID,
     *,
     client: AuthenticatedClient,
-    body: Union[
-        "MethodCPTDataUpdate",
-        "MethodDTDataUpdate",
-        "MethodPZDataUpdate",
-        "MethodRCDDataUpdate",
-        "MethodRPDataUpdate",
-        "MethodSRSDataUpdate",
-        "MethodSSDataUpdate",
-        "MethodSVTDataUpdate",
-        "MethodTOTDataUpdate",
-        "MethodTRDataUpdate",
-        "MethodWSTDataUpdate",
-    ],
+    body: MethodCPTDataUpdate
+    | MethodDTDataUpdate
+    | MethodPZDataUpdate
+    | MethodRCDDataUpdate
+    | MethodRPDataUpdate
+    | MethodSRSDataUpdate
+    | MethodSSDataUpdate
+    | MethodSVTDataUpdate
+    | MethodTOTDataUpdate
+    | MethodTRDataUpdate
+    | MethodWSTDataUpdate,
 ) -> Response[
-    Union[
-        HTTPValidationError,
-        Union[
-            "MethodCPTData",
-            "MethodDPData",
-            "MethodDTData",
-            "MethodPZData",
-            "MethodRCDData",
-            "MethodRPData",
-            "MethodSRSData",
-            "MethodSSData",
-            "MethodSVTData",
-            "MethodTOTData",
-            "MethodTRData",
-            "MethodWSTData",
-        ],
-    ]
+    HTTPValidationError
+    | MethodCPTData
+    | MethodDPData
+    | MethodDTData
+    | MethodPZData
+    | MethodRCDData
+    | MethodRPData
+    | MethodSRSData
+    | MethodSSData
+    | MethodSVTData
+    | MethodTOTData
+    | MethodTRData
+    | MethodWSTData
 ]:
     """Update Data Row
 
@@ -462,17 +434,16 @@ async def asyncio_detailed(
         location_id (UUID):
         method_id (UUID):
         method_data_id (UUID):
-        body (Union['MethodCPTDataUpdate', 'MethodDTDataUpdate', 'MethodPZDataUpdate',
-            'MethodRCDDataUpdate', 'MethodRPDataUpdate', 'MethodSRSDataUpdate', 'MethodSSDataUpdate',
-            'MethodSVTDataUpdate', 'MethodTOTDataUpdate', 'MethodTRDataUpdate',
-            'MethodWSTDataUpdate']):
+        body (MethodCPTDataUpdate | MethodDTDataUpdate | MethodPZDataUpdate | MethodRCDDataUpdate
+            | MethodRPDataUpdate | MethodSRSDataUpdate | MethodSSDataUpdate | MethodSVTDataUpdate |
+            MethodTOTDataUpdate | MethodTRDataUpdate | MethodWSTDataUpdate):
 
     Raises:
         errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
         httpx.TimeoutException: If the request takes longer than Client.timeout.
 
     Returns:
-        Response[Union[HTTPValidationError, Union['MethodCPTData', 'MethodDPData', 'MethodDTData', 'MethodPZData', 'MethodRCDData', 'MethodRPData', 'MethodSRSData', 'MethodSSData', 'MethodSVTData', 'MethodTOTData', 'MethodTRData', 'MethodWSTData']]]
+        Response[HTTPValidationError | MethodCPTData | MethodDPData | MethodDTData | MethodPZData | MethodRCDData | MethodRPData | MethodSRSData | MethodSSData | MethodSVTData | MethodTOTData | MethodTRData | MethodWSTData]
     """
 
     kwargs = _get_kwargs(
@@ -495,38 +466,33 @@ async def asyncio(
     method_data_id: UUID,
     *,
     client: AuthenticatedClient,
-    body: Union[
-        "MethodCPTDataUpdate",
-        "MethodDTDataUpdate",
-        "MethodPZDataUpdate",
-        "MethodRCDDataUpdate",
-        "MethodRPDataUpdate",
-        "MethodSRSDataUpdate",
-        "MethodSSDataUpdate",
-        "MethodSVTDataUpdate",
-        "MethodTOTDataUpdate",
-        "MethodTRDataUpdate",
-        "MethodWSTDataUpdate",
-    ],
-) -> Optional[
-    Union[
-        HTTPValidationError,
-        Union[
-            "MethodCPTData",
-            "MethodDPData",
-            "MethodDTData",
-            "MethodPZData",
-            "MethodRCDData",
-            "MethodRPData",
-            "MethodSRSData",
-            "MethodSSData",
-            "MethodSVTData",
-            "MethodTOTData",
-            "MethodTRData",
-            "MethodWSTData",
-        ],
-    ]
-]:
+    body: MethodCPTDataUpdate
+    | MethodDTDataUpdate
+    | MethodPZDataUpdate
+    | MethodRCDDataUpdate
+    | MethodRPDataUpdate
+    | MethodSRSDataUpdate
+    | MethodSSDataUpdate
+    | MethodSVTDataUpdate
+    | MethodTOTDataUpdate
+    | MethodTRDataUpdate
+    | MethodWSTDataUpdate,
+) -> (
+    HTTPValidationError
+    | MethodCPTData
+    | MethodDPData
+    | MethodDTData
+    | MethodPZData
+    | MethodRCDData
+    | MethodRPData
+    | MethodSRSData
+    | MethodSSData
+    | MethodSVTData
+    | MethodTOTData
+    | MethodTRData
+    | MethodWSTData
+    | None
+):
     """Update Data Row
 
      Update a method's single data line
@@ -536,17 +502,16 @@ async def asyncio(
         location_id (UUID):
         method_id (UUID):
         method_data_id (UUID):
-        body (Union['MethodCPTDataUpdate', 'MethodDTDataUpdate', 'MethodPZDataUpdate',
-            'MethodRCDDataUpdate', 'MethodRPDataUpdate', 'MethodSRSDataUpdate', 'MethodSSDataUpdate',
-            'MethodSVTDataUpdate', 'MethodTOTDataUpdate', 'MethodTRDataUpdate',
-            'MethodWSTDataUpdate']):
+        body (MethodCPTDataUpdate | MethodDTDataUpdate | MethodPZDataUpdate | MethodRCDDataUpdate
+            | MethodRPDataUpdate | MethodSRSDataUpdate | MethodSSDataUpdate | MethodSVTDataUpdate |
+            MethodTOTDataUpdate | MethodTRDataUpdate | MethodWSTDataUpdate):
 
     Raises:
         errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
         httpx.TimeoutException: If the request takes longer than Client.timeout.
 
     Returns:
-        Union[HTTPValidationError, Union['MethodCPTData', 'MethodDPData', 'MethodDTData', 'MethodPZData', 'MethodRCDData', 'MethodRPData', 'MethodSRSData', 'MethodSSData', 'MethodSVTData', 'MethodTOTData', 'MethodTRData', 'MethodWSTData']]
+        HTTPValidationError | MethodCPTData | MethodDPData | MethodDTData | MethodPZData | MethodRCDData | MethodRPData | MethodSRSData | MethodSSData | MethodSVTData | MethodTOTData | MethodTRData | MethodWSTData
     """
 
     return (
