@@ -139,7 +139,7 @@ def _parse_response(
                 response_201_type_0_type_0 = MethodCPT.from_dict(data)
 
                 return response_201_type_0_type_0
-            except:  # noqa: E722
+            except (TypeError, ValueError, AttributeError, KeyError):
                 pass
             try:
                 if not isinstance(data, dict):
@@ -147,7 +147,7 @@ def _parse_response(
                 response_201_type_0_type_1 = MethodTOT.from_dict(data)
 
                 return response_201_type_0_type_1
-            except:  # noqa: E722
+            except (TypeError, ValueError, AttributeError, KeyError):
                 pass
             try:
                 if not isinstance(data, dict):
@@ -155,7 +155,7 @@ def _parse_response(
                 response_201_type_0_type_2 = MethodRP.from_dict(data)
 
                 return response_201_type_0_type_2
-            except:  # noqa: E722
+            except (TypeError, ValueError, AttributeError, KeyError):
                 pass
             try:
                 if not isinstance(data, dict):
@@ -163,7 +163,7 @@ def _parse_response(
                 response_201_type_0_type_3 = MethodSA.from_dict(data)
 
                 return response_201_type_0_type_3
-            except:  # noqa: E722
+            except (TypeError, ValueError, AttributeError, KeyError):
                 pass
             try:
                 if not isinstance(data, dict):
@@ -171,7 +171,7 @@ def _parse_response(
                 response_201_type_0_type_4 = MethodPZ.from_dict(data)
 
                 return response_201_type_0_type_4
-            except:  # noqa: E722
+            except (TypeError, ValueError, AttributeError, KeyError):
                 pass
             try:
                 if not isinstance(data, dict):
@@ -179,7 +179,7 @@ def _parse_response(
                 response_201_type_0_type_5 = MethodSS.from_dict(data)
 
                 return response_201_type_0_type_5
-            except:  # noqa: E722
+            except (TypeError, ValueError, AttributeError, KeyError):
                 pass
             try:
                 if not isinstance(data, dict):
@@ -187,7 +187,7 @@ def _parse_response(
                 response_201_type_0_type_6 = MethodRWS.from_dict(data)
 
                 return response_201_type_0_type_6
-            except:  # noqa: E722
+            except (TypeError, ValueError, AttributeError, KeyError):
                 pass
             try:
                 if not isinstance(data, dict):
@@ -195,7 +195,7 @@ def _parse_response(
                 response_201_type_0_type_7 = MethodRCD.from_dict(data)
 
                 return response_201_type_0_type_7
-            except:  # noqa: E722
+            except (TypeError, ValueError, AttributeError, KeyError):
                 pass
             try:
                 if not isinstance(data, dict):
@@ -203,7 +203,7 @@ def _parse_response(
                 response_201_type_0_type_8 = MethodRS.from_dict(data)
 
                 return response_201_type_0_type_8
-            except:  # noqa: E722
+            except (TypeError, ValueError, AttributeError, KeyError):
                 pass
             try:
                 if not isinstance(data, dict):
@@ -211,7 +211,7 @@ def _parse_response(
                 response_201_type_0_type_9 = MethodSVT.from_dict(data)
 
                 return response_201_type_0_type_9
-            except:  # noqa: E722
+            except (TypeError, ValueError, AttributeError, KeyError):
                 pass
             try:
                 if not isinstance(data, dict):
@@ -219,7 +219,7 @@ def _parse_response(
                 response_201_type_0_type_10 = MethodSPT.from_dict(data)
 
                 return response_201_type_0_type_10
-            except:  # noqa: E722
+            except (TypeError, ValueError, AttributeError, KeyError):
                 pass
             try:
                 if not isinstance(data, dict):
@@ -227,7 +227,7 @@ def _parse_response(
                 response_201_type_0_type_11 = MethodCD.from_dict(data)
 
                 return response_201_type_0_type_11
-            except:  # noqa: E722
+            except (TypeError, ValueError, AttributeError, KeyError):
                 pass
             try:
                 if not isinstance(data, dict):
@@ -235,7 +235,7 @@ def _parse_response(
                 response_201_type_0_type_12 = MethodTP.from_dict(data)
 
                 return response_201_type_0_type_12
-            except:  # noqa: E722
+            except (TypeError, ValueError, AttributeError, KeyError):
                 pass
             try:
                 if not isinstance(data, dict):
@@ -243,7 +243,7 @@ def _parse_response(
                 response_201_type_0_type_13 = MethodPT.from_dict(data)
 
                 return response_201_type_0_type_13
-            except:  # noqa: E722
+            except (TypeError, ValueError, AttributeError, KeyError):
                 pass
             try:
                 if not isinstance(data, dict):
@@ -251,7 +251,7 @@ def _parse_response(
                 response_201_type_0_type_14 = MethodESA.from_dict(data)
 
                 return response_201_type_0_type_14
-            except:  # noqa: E722
+            except (TypeError, ValueError, AttributeError, KeyError):
                 pass
             try:
                 if not isinstance(data, dict):
@@ -259,7 +259,7 @@ def _parse_response(
                 response_201_type_0_type_15 = MethodTR.from_dict(data)
 
                 return response_201_type_0_type_15
-            except:  # noqa: E722
+            except (TypeError, ValueError, AttributeError, KeyError):
                 pass
             try:
                 if not isinstance(data, dict):
@@ -267,7 +267,7 @@ def _parse_response(
                 response_201_type_0_type_16 = MethodAD.from_dict(data)
 
                 return response_201_type_0_type_16
-            except:  # noqa: E722
+            except (TypeError, ValueError, AttributeError, KeyError):
                 pass
             try:
                 if not isinstance(data, dict):
@@ -275,7 +275,7 @@ def _parse_response(
                 response_201_type_0_type_17 = MethodRO.from_dict(data)
 
                 return response_201_type_0_type_17
-            except:  # noqa: E722
+            except (TypeError, ValueError, AttributeError, KeyError):
                 pass
             try:
                 if not isinstance(data, dict):
@@ -283,7 +283,7 @@ def _parse_response(
                 response_201_type_0_type_18 = MethodINC.from_dict(data)
 
                 return response_201_type_0_type_18
-            except:  # noqa: E722
+            except (TypeError, ValueError, AttributeError, KeyError):
                 pass
             try:
                 if not isinstance(data, dict):
@@ -291,7 +291,7 @@ def _parse_response(
                 response_201_type_0_type_19 = MethodDEF.from_dict(data)
 
                 return response_201_type_0_type_19
-            except:  # noqa: E722
+            except (TypeError, ValueError, AttributeError, KeyError):
                 pass
             try:
                 if not isinstance(data, dict):
@@ -299,7 +299,7 @@ def _parse_response(
                 response_201_type_0_type_20 = MethodIW.from_dict(data)
 
                 return response_201_type_0_type_20
-            except:  # noqa: E722
+            except (TypeError, ValueError, AttributeError, KeyError):
                 pass
             try:
                 if not isinstance(data, dict):
@@ -307,7 +307,7 @@ def _parse_response(
                 response_201_type_0_type_21 = MethodDT.from_dict(data)
 
                 return response_201_type_0_type_21
-            except:  # noqa: E722
+            except (TypeError, ValueError, AttributeError, KeyError):
                 pass
             try:
                 if not isinstance(data, dict):
@@ -315,7 +315,7 @@ def _parse_response(
                 response_201_type_0_type_22 = MethodOTHER.from_dict(data)
 
                 return response_201_type_0_type_22
-            except:  # noqa: E722
+            except (TypeError, ValueError, AttributeError, KeyError):
                 pass
             try:
                 if not isinstance(data, dict):
@@ -323,7 +323,7 @@ def _parse_response(
                 response_201_type_0_type_23 = MethodSRS.from_dict(data)
 
                 return response_201_type_0_type_23
-            except:  # noqa: E722
+            except (TypeError, ValueError, AttributeError, KeyError):
                 pass
             try:
                 if not isinstance(data, dict):
@@ -331,7 +331,7 @@ def _parse_response(
                 response_201_type_0_type_24 = MethodDP.from_dict(data)
 
                 return response_201_type_0_type_24
-            except:  # noqa: E722
+            except (TypeError, ValueError, AttributeError, KeyError):
                 pass
             try:
                 if not isinstance(data, dict):
@@ -339,7 +339,7 @@ def _parse_response(
                 response_201_type_0_type_25 = MethodWST.from_dict(data)
 
                 return response_201_type_0_type_25
-            except:  # noqa: E722
+            except (TypeError, ValueError, AttributeError, KeyError):
                 pass
             try:
                 if not isinstance(data, dict):
@@ -347,7 +347,7 @@ def _parse_response(
                 response_201_type_0_type_26 = MethodSLB.from_dict(data)
 
                 return response_201_type_0_type_26
-            except:  # noqa: E722
+            except (TypeError, ValueError, AttributeError, KeyError):
                 pass
             try:
                 if not isinstance(data, dict):
@@ -355,7 +355,7 @@ def _parse_response(
                 response_201_type_0_type_27 = MethodSTI.from_dict(data)
 
                 return response_201_type_0_type_27
-            except:  # noqa: E722
+            except (TypeError, ValueError, AttributeError, KeyError):
                 pass
             return cast(
                 MethodAD
