@@ -1,5 +1,5 @@
 from http import HTTPStatus
-from typing import Any, Optional, Union
+from typing import Any
 
 import httpx
 
@@ -22,8 +22,8 @@ def _get_kwargs(
 
 
 def _parse_response(
-    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
-) -> Optional[Union[HTTPValidationError, list["PiezometerVendor"]]]:
+    *, client: AuthenticatedClient | Client, response: httpx.Response
+) -> HTTPValidationError | list[PiezometerVendor] | None:
     if response.status_code == 200:
         response_200 = []
         _response_200 = response.json()
@@ -33,10 +33,12 @@ def _parse_response(
             response_200.append(response_200_item)
 
         return response_200
+
     if response.status_code == 422:
         response_422 = HTTPValidationError.from_dict(response.json())
 
         return response_422
+
     if client.raise_on_unexpected_status:
         raise errors.UnexpectedStatus(response.status_code, response.content)
     else:
@@ -44,8 +46,8 @@ def _parse_response(
 
 
 def _build_response(
-    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
-) -> Response[Union[HTTPValidationError, list["PiezometerVendor"]]]:
+    *, client: AuthenticatedClient | Client, response: httpx.Response
+) -> Response[HTTPValidationError | list[PiezometerVendor]]:
     return Response(
         status_code=HTTPStatus(response.status_code),
         content=response.content,
@@ -58,7 +60,7 @@ def sync_detailed(
     project_id: str,
     *,
     client: AuthenticatedClient,
-) -> Response[Union[HTTPValidationError, list["PiezometerVendor"]]]:
+) -> Response[HTTPValidationError | list[PiezometerVendor]]:
     """Get Piezometer Vendors
 
     Args:
@@ -69,7 +71,7 @@ def sync_detailed(
         httpx.TimeoutException: If the request takes longer than Client.timeout.
 
     Returns:
-        Response[Union[HTTPValidationError, list['PiezometerVendor']]]
+        Response[HTTPValidationError | list[PiezometerVendor]]
     """
 
     kwargs = _get_kwargs(
@@ -87,7 +89,7 @@ def sync(
     project_id: str,
     *,
     client: AuthenticatedClient,
-) -> Optional[Union[HTTPValidationError, list["PiezometerVendor"]]]:
+) -> HTTPValidationError | list[PiezometerVendor] | None:
     """Get Piezometer Vendors
 
     Args:
@@ -98,7 +100,7 @@ def sync(
         httpx.TimeoutException: If the request takes longer than Client.timeout.
 
     Returns:
-        Union[HTTPValidationError, list['PiezometerVendor']]
+        HTTPValidationError | list[PiezometerVendor]
     """
 
     return sync_detailed(
@@ -111,7 +113,7 @@ async def asyncio_detailed(
     project_id: str,
     *,
     client: AuthenticatedClient,
-) -> Response[Union[HTTPValidationError, list["PiezometerVendor"]]]:
+) -> Response[HTTPValidationError | list[PiezometerVendor]]:
     """Get Piezometer Vendors
 
     Args:
@@ -122,7 +124,7 @@ async def asyncio_detailed(
         httpx.TimeoutException: If the request takes longer than Client.timeout.
 
     Returns:
-        Response[Union[HTTPValidationError, list['PiezometerVendor']]]
+        Response[HTTPValidationError | list[PiezometerVendor]]
     """
 
     kwargs = _get_kwargs(
@@ -138,7 +140,7 @@ async def asyncio(
     project_id: str,
     *,
     client: AuthenticatedClient,
-) -> Optional[Union[HTTPValidationError, list["PiezometerVendor"]]]:
+) -> HTTPValidationError | list[PiezometerVendor] | None:
     """Get Piezometer Vendors
 
     Args:
@@ -149,7 +151,7 @@ async def asyncio(
         httpx.TimeoutException: If the request takes longer than Client.timeout.
 
     Returns:
-        Union[HTTPValidationError, list['PiezometerVendor']]
+        HTTPValidationError | list[PiezometerVendor]
     """
 
     return (
