@@ -1,5 +1,5 @@
 from http import HTTPStatus
-from typing import Any, Optional, Union
+from typing import Any, cast
 from uuid import UUID
 
 import httpx
@@ -34,10 +34,24 @@ def _get_kwargs(
 
 
 def _parse_response(
-    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
-) -> Optional[Union[HTTPValidationError, PiezometerModel]]:
+    *, client: AuthenticatedClient | Client, response: httpx.Response
+) -> HTTPValidationError | None | PiezometerModel | None:
     if response.status_code == 200:
-        response_200 = PiezometerModel.from_dict(response.json())
+
+        def _parse_response_200(data: object) -> None | PiezometerModel:
+            if data is None:
+                return data
+            try:
+                if not isinstance(data, dict):
+                    raise TypeError()
+                response_200_type_0 = PiezometerModel.from_dict(data)
+
+                return response_200_type_0
+            except (TypeError, ValueError, AttributeError, KeyError):
+                pass
+            return cast(None | PiezometerModel, data)
+
+        response_200 = _parse_response_200(response.json())
 
         return response_200
 
@@ -53,8 +67,8 @@ def _parse_response(
 
 
 def _build_response(
-    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
-) -> Response[Union[HTTPValidationError, PiezometerModel]]:
+    *, client: AuthenticatedClient | Client, response: httpx.Response
+) -> Response[HTTPValidationError | None | PiezometerModel]:
     return Response(
         status_code=HTTPStatus(response.status_code),
         content=response.content,
@@ -69,7 +83,7 @@ def sync_detailed(
     *,
     client: AuthenticatedClient,
     body: PiezometerModelUpdate,
-) -> Response[Union[HTTPValidationError, PiezometerModel]]:
+) -> Response[HTTPValidationError | None | PiezometerModel]:
     """Update Piezometer Model
 
      Update piezometer model
@@ -84,7 +98,7 @@ def sync_detailed(
         httpx.TimeoutException: If the request takes longer than Client.timeout.
 
     Returns:
-        Response[Union[HTTPValidationError, PiezometerModel]]
+        Response[HTTPValidationError | None | PiezometerModel]
     """
 
     kwargs = _get_kwargs(
@@ -106,7 +120,7 @@ def sync(
     *,
     client: AuthenticatedClient,
     body: PiezometerModelUpdate,
-) -> Optional[Union[HTTPValidationError, PiezometerModel]]:
+) -> HTTPValidationError | None | PiezometerModel | None:
     """Update Piezometer Model
 
      Update piezometer model
@@ -121,7 +135,7 @@ def sync(
         httpx.TimeoutException: If the request takes longer than Client.timeout.
 
     Returns:
-        Union[HTTPValidationError, PiezometerModel]
+        HTTPValidationError | None | PiezometerModel
     """
 
     return sync_detailed(
@@ -138,7 +152,7 @@ async def asyncio_detailed(
     *,
     client: AuthenticatedClient,
     body: PiezometerModelUpdate,
-) -> Response[Union[HTTPValidationError, PiezometerModel]]:
+) -> Response[HTTPValidationError | None | PiezometerModel]:
     """Update Piezometer Model
 
      Update piezometer model
@@ -153,7 +167,7 @@ async def asyncio_detailed(
         httpx.TimeoutException: If the request takes longer than Client.timeout.
 
     Returns:
-        Response[Union[HTTPValidationError, PiezometerModel]]
+        Response[HTTPValidationError | None | PiezometerModel]
     """
 
     kwargs = _get_kwargs(
@@ -173,7 +187,7 @@ async def asyncio(
     *,
     client: AuthenticatedClient,
     body: PiezometerModelUpdate,
-) -> Optional[Union[HTTPValidationError, PiezometerModel]]:
+) -> HTTPValidationError | None | PiezometerModel | None:
     """Update Piezometer Model
 
      Update piezometer model
@@ -188,7 +202,7 @@ async def asyncio(
         httpx.TimeoutException: If the request takes longer than Client.timeout.
 
     Returns:
-        Union[HTTPValidationError, PiezometerModel]
+        HTTPValidationError | None | PiezometerModel
     """
 
     return (
