@@ -1,5 +1,5 @@
 from http import HTTPStatus
-from typing import Any, Optional, Union
+from typing import Any
 from uuid import UUID
 
 import httpx
@@ -24,16 +24,18 @@ def _get_kwargs(
 
 
 def _parse_response(
-    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
-) -> Optional[Union[HTTPValidationError, Project]]:
+    *, client: AuthenticatedClient | Client, response: httpx.Response
+) -> HTTPValidationError | Project | None:
     if response.status_code == 200:
         response_200 = Project.from_dict(response.json())
 
         return response_200
+
     if response.status_code == 422:
         response_422 = HTTPValidationError.from_dict(response.json())
 
         return response_422
+
     if client.raise_on_unexpected_status:
         raise errors.UnexpectedStatus(response.status_code, response.content)
     else:
@@ -41,8 +43,8 @@ def _parse_response(
 
 
 def _build_response(
-    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
-) -> Response[Union[HTTPValidationError, Project]]:
+    *, client: AuthenticatedClient | Client, response: httpx.Response
+) -> Response[HTTPValidationError | Project]:
     return Response(
         status_code=HTTPStatus(response.status_code),
         content=response.content,
@@ -56,7 +58,7 @@ def sync_detailed(
     linked_project_id: UUID,
     *,
     client: AuthenticatedClient,
-) -> Response[Union[HTTPValidationError, Project]]:
+) -> Response[HTTPValidationError | Project]:
     """Link Linked Project
 
      Link another project to a project by project_id.
@@ -70,7 +72,7 @@ def sync_detailed(
         httpx.TimeoutException: If the request takes longer than Client.timeout.
 
     Returns:
-        Response[Union[HTTPValidationError, Project]]
+        Response[HTTPValidationError | Project]
     """
 
     kwargs = _get_kwargs(
@@ -90,7 +92,7 @@ def sync(
     linked_project_id: UUID,
     *,
     client: AuthenticatedClient,
-) -> Optional[Union[HTTPValidationError, Project]]:
+) -> HTTPValidationError | Project | None:
     """Link Linked Project
 
      Link another project to a project by project_id.
@@ -104,7 +106,7 @@ def sync(
         httpx.TimeoutException: If the request takes longer than Client.timeout.
 
     Returns:
-        Union[HTTPValidationError, Project]
+        HTTPValidationError | Project
     """
 
     return sync_detailed(
@@ -119,7 +121,7 @@ async def asyncio_detailed(
     linked_project_id: UUID,
     *,
     client: AuthenticatedClient,
-) -> Response[Union[HTTPValidationError, Project]]:
+) -> Response[HTTPValidationError | Project]:
     """Link Linked Project
 
      Link another project to a project by project_id.
@@ -133,7 +135,7 @@ async def asyncio_detailed(
         httpx.TimeoutException: If the request takes longer than Client.timeout.
 
     Returns:
-        Response[Union[HTTPValidationError, Project]]
+        Response[HTTPValidationError | Project]
     """
 
     kwargs = _get_kwargs(
@@ -151,7 +153,7 @@ async def asyncio(
     linked_project_id: UUID,
     *,
     client: AuthenticatedClient,
-) -> Optional[Union[HTTPValidationError, Project]]:
+) -> HTTPValidationError | Project | None:
     """Link Linked Project
 
      Link another project to a project by project_id.
@@ -165,7 +167,7 @@ async def asyncio(
         httpx.TimeoutException: If the request takes longer than Client.timeout.
 
     Returns:
-        Union[HTTPValidationError, Project]
+        HTTPValidationError | Project
     """
 
     return (
