@@ -1,5 +1,5 @@
 from http import HTTPStatus
-from typing import Any, Optional, Union
+from typing import Any
 
 import httpx
 
@@ -22,8 +22,8 @@ def _get_kwargs(
 
 
 def _parse_response(
-    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
-) -> Optional[Union[HTTPValidationError, SamplerType]]:
+    *, client: AuthenticatedClient | Client, response: httpx.Response
+) -> HTTPValidationError | SamplerType | None:
     if response.status_code == 200:
         response_200 = SamplerType.from_dict(response.json())
 
@@ -41,8 +41,8 @@ def _parse_response(
 
 
 def _build_response(
-    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
-) -> Response[Union[HTTPValidationError, SamplerType]]:
+    *, client: AuthenticatedClient | Client, response: httpx.Response
+) -> Response[HTTPValidationError | SamplerType]:
     return Response(
         status_code=HTTPStatus(response.status_code),
         content=response.content,
@@ -54,8 +54,8 @@ def _build_response(
 def sync_detailed(
     sampler_type_id: int,
     *,
-    client: Union[AuthenticatedClient, Client],
-) -> Response[Union[HTTPValidationError, SamplerType]]:
+    client: AuthenticatedClient | Client,
+) -> Response[HTTPValidationError | SamplerType]:
     """Get Sampler Type
 
     Args:
@@ -66,7 +66,7 @@ def sync_detailed(
         httpx.TimeoutException: If the request takes longer than Client.timeout.
 
     Returns:
-        Response[Union[HTTPValidationError, SamplerType]]
+        Response[HTTPValidationError | SamplerType]
     """
 
     kwargs = _get_kwargs(
@@ -83,8 +83,8 @@ def sync_detailed(
 def sync(
     sampler_type_id: int,
     *,
-    client: Union[AuthenticatedClient, Client],
-) -> Optional[Union[HTTPValidationError, SamplerType]]:
+    client: AuthenticatedClient | Client,
+) -> HTTPValidationError | SamplerType | None:
     """Get Sampler Type
 
     Args:
@@ -95,7 +95,7 @@ def sync(
         httpx.TimeoutException: If the request takes longer than Client.timeout.
 
     Returns:
-        Union[HTTPValidationError, SamplerType]
+        HTTPValidationError | SamplerType
     """
 
     return sync_detailed(
@@ -107,8 +107,8 @@ def sync(
 async def asyncio_detailed(
     sampler_type_id: int,
     *,
-    client: Union[AuthenticatedClient, Client],
-) -> Response[Union[HTTPValidationError, SamplerType]]:
+    client: AuthenticatedClient | Client,
+) -> Response[HTTPValidationError | SamplerType]:
     """Get Sampler Type
 
     Args:
@@ -119,7 +119,7 @@ async def asyncio_detailed(
         httpx.TimeoutException: If the request takes longer than Client.timeout.
 
     Returns:
-        Response[Union[HTTPValidationError, SamplerType]]
+        Response[HTTPValidationError | SamplerType]
     """
 
     kwargs = _get_kwargs(
@@ -134,8 +134,8 @@ async def asyncio_detailed(
 async def asyncio(
     sampler_type_id: int,
     *,
-    client: Union[AuthenticatedClient, Client],
-) -> Optional[Union[HTTPValidationError, SamplerType]]:
+    client: AuthenticatedClient | Client,
+) -> HTTPValidationError | SamplerType | None:
     """Get Sampler Type
 
     Args:
@@ -146,7 +146,7 @@ async def asyncio(
         httpx.TimeoutException: If the request takes longer than Client.timeout.
 
     Returns:
-        Union[HTTPValidationError, SamplerType]
+        HTTPValidationError | SamplerType
     """
 
     return (
