@@ -1,5 +1,7 @@
+from __future__ import annotations
+
 from collections.abc import Mapping
-from typing import Any, TypeVar, Union, cast
+from typing import Any, TypeVar, cast
 
 from attrs import define as _attrs_define
 from attrs import field as _attrs_field
@@ -14,30 +16,30 @@ T = TypeVar("T", bound="FileUpdate")
 class FileUpdate:
     """
     Attributes:
-        name (Union[None, Unset, str]):
-        comment (Union[None, Unset, str]):
-        file_type (Union[FileType, None, Unset]):
+        name (None | str | Unset):
+        comment (None | str | Unset):
+        file_type (FileType | None | Unset):
     """
 
-    name: Union[None, Unset, str] = UNSET
-    comment: Union[None, Unset, str] = UNSET
-    file_type: Union[FileType, None, Unset] = UNSET
+    name: None | str | Unset = UNSET
+    comment: None | str | Unset = UNSET
+    file_type: FileType | None | Unset = UNSET
     additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)
 
     def to_dict(self) -> dict[str, Any]:
-        name: Union[None, Unset, str]
+        name: None | str | Unset
         if isinstance(self.name, Unset):
             name = UNSET
         else:
             name = self.name
 
-        comment: Union[None, Unset, str]
+        comment: None | str | Unset
         if isinstance(self.comment, Unset):
             comment = UNSET
         else:
             comment = self.comment
 
-        file_type: Union[None, Unset, str]
+        file_type: None | str | Unset
         if isinstance(self.file_type, Unset):
             file_type = UNSET
         elif isinstance(self.file_type, FileType):
@@ -61,25 +63,25 @@ class FileUpdate:
     def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
         d = dict(src_dict)
 
-        def _parse_name(data: object) -> Union[None, Unset, str]:
+        def _parse_name(data: object) -> None | str | Unset:
             if data is None:
                 return data
             if isinstance(data, Unset):
                 return data
-            return cast(Union[None, Unset, str], data)
+            return cast(None | str | Unset, data)
 
         name = _parse_name(d.pop("name", UNSET))
 
-        def _parse_comment(data: object) -> Union[None, Unset, str]:
+        def _parse_comment(data: object) -> None | str | Unset:
             if data is None:
                 return data
             if isinstance(data, Unset):
                 return data
-            return cast(Union[None, Unset, str], data)
+            return cast(None | str | Unset, data)
 
         comment = _parse_comment(d.pop("comment", UNSET))
 
-        def _parse_file_type(data: object) -> Union[FileType, None, Unset]:
+        def _parse_file_type(data: object) -> FileType | None | Unset:
             if data is None:
                 return data
             if isinstance(data, Unset):
@@ -90,9 +92,9 @@ class FileUpdate:
                 file_type_type_0 = FileType(data)
 
                 return file_type_type_0
-            except:  # noqa: E722
+            except (TypeError, ValueError, AttributeError, KeyError):
                 pass
-            return cast(Union[FileType, None, Unset], data)
+            return cast(FileType | None | Unset, data)
 
         file_type = _parse_file_type(d.pop("file_type", UNSET))
 
