@@ -1,6 +1,8 @@
+from __future__ import annotations
+
 import datetime
 from collections.abc import Mapping
-from typing import TYPE_CHECKING, Any, TypeVar, Union, cast
+from typing import TYPE_CHECKING, Any, TypeVar, cast
 from uuid import UUID
 
 from attrs import define as _attrs_define
@@ -60,23 +62,23 @@ class Location:
         project_id (UUID):
         is_deleted (bool):
         last_updated (datetime.datetime):
-        iogp_type_id (Union[Unset, IOGPTypeEnum]): For offshore locations, an IOGP type is required
-        created_by (Union[None, Unset, str]):
-        updated_by (Union[None, Unset, str]):
-        point_easting (Union[None, Unset, float]):
-        point_northing (Union[None, Unset, float]):
-        point_z (Union[None, Unset, float]):
-        srid (Union[None, Unset, int]):
-        point_x_wgs84_pseudo (Union[None, Unset, float]):
-        point_y_wgs84_pseudo (Union[None, Unset, float]):
-        point_x_wgs84_web (Union[None, Unset, float]):
-        point_y_wgs84_web (Union[None, Unset, float]):
-        tags (Union[None, Unset, list[str]]):
-        methods (Union[Unset, list[Union['MethodAD', 'MethodCD', 'MethodCPT', 'MethodDEF', 'MethodDP', 'MethodDT',
-            'MethodESA', 'MethodINC', 'MethodIW', 'MethodOTHER', 'MethodPT', 'MethodPZ', 'MethodRCD', 'MethodRO',
-            'MethodRP', 'MethodRS', 'MethodRWS', 'MethodSA', 'MethodSLB', 'MethodSPT', 'MethodSRS', 'MethodSS', 'MethodSTI',
-            'MethodSVT', 'MethodTOT', 'MethodTP', 'MethodTR', 'MethodWST']]]):
-        files (Union[Unset, list['File']]):
+        iogp_type_id (IOGPTypeEnum | Unset): For offshore locations, an IOGP type is required
+        created_by (None | str | Unset):
+        updated_by (None | str | Unset):
+        point_easting (float | None | Unset):
+        point_northing (float | None | Unset):
+        point_z (float | None | Unset):
+        srid (int | None | Unset):
+        point_x_wgs84_pseudo (float | None | Unset):
+        point_y_wgs84_pseudo (float | None | Unset):
+        point_x_wgs84_web (float | None | Unset):
+        point_y_wgs84_web (float | None | Unset):
+        tags (list[str] | None | Unset):
+        methods (list[MethodAD | MethodCD | MethodCPT | MethodDEF | MethodDP | MethodDT | MethodESA | MethodINC |
+            MethodIW | MethodOTHER | MethodPT | MethodPZ | MethodRCD | MethodRO | MethodRP | MethodRS | MethodRWS | MethodSA
+            | MethodSLB | MethodSPT | MethodSRS | MethodSS | MethodSTI | MethodSVT | MethodTOT | MethodTP | MethodTR |
+            MethodWST] | Unset):
+        files (list[File] | Unset):
     """
 
     name: str
@@ -86,54 +88,52 @@ class Location:
     project_id: UUID
     is_deleted: bool
     last_updated: datetime.datetime
-    iogp_type_id: Union[Unset, IOGPTypeEnum] = UNSET
-    created_by: Union[None, Unset, str] = UNSET
-    updated_by: Union[None, Unset, str] = UNSET
-    point_easting: Union[None, Unset, float] = UNSET
-    point_northing: Union[None, Unset, float] = UNSET
-    point_z: Union[None, Unset, float] = UNSET
-    srid: Union[None, Unset, int] = UNSET
-    point_x_wgs84_pseudo: Union[None, Unset, float] = UNSET
-    point_y_wgs84_pseudo: Union[None, Unset, float] = UNSET
-    point_x_wgs84_web: Union[None, Unset, float] = UNSET
-    point_y_wgs84_web: Union[None, Unset, float] = UNSET
-    tags: Union[None, Unset, list[str]] = UNSET
-    methods: Union[
-        Unset,
+    iogp_type_id: IOGPTypeEnum | Unset = UNSET
+    created_by: None | str | Unset = UNSET
+    updated_by: None | str | Unset = UNSET
+    point_easting: float | None | Unset = UNSET
+    point_northing: float | None | Unset = UNSET
+    point_z: float | None | Unset = UNSET
+    srid: int | None | Unset = UNSET
+    point_x_wgs84_pseudo: float | None | Unset = UNSET
+    point_y_wgs84_pseudo: float | None | Unset = UNSET
+    point_x_wgs84_web: float | None | Unset = UNSET
+    point_y_wgs84_web: float | None | Unset = UNSET
+    tags: list[str] | None | Unset = UNSET
+    methods: (
         list[
-            Union[
-                "MethodAD",
-                "MethodCD",
-                "MethodCPT",
-                "MethodDEF",
-                "MethodDP",
-                "MethodDT",
-                "MethodESA",
-                "MethodINC",
-                "MethodIW",
-                "MethodOTHER",
-                "MethodPT",
-                "MethodPZ",
-                "MethodRCD",
-                "MethodRO",
-                "MethodRP",
-                "MethodRS",
-                "MethodRWS",
-                "MethodSA",
-                "MethodSLB",
-                "MethodSPT",
-                "MethodSRS",
-                "MethodSS",
-                "MethodSTI",
-                "MethodSVT",
-                "MethodTOT",
-                "MethodTP",
-                "MethodTR",
-                "MethodWST",
-            ]
-        ],
-    ] = UNSET
-    files: Union[Unset, list["File"]] = UNSET
+            MethodAD
+            | MethodCD
+            | MethodCPT
+            | MethodDEF
+            | MethodDP
+            | MethodDT
+            | MethodESA
+            | MethodINC
+            | MethodIW
+            | MethodOTHER
+            | MethodPT
+            | MethodPZ
+            | MethodRCD
+            | MethodRO
+            | MethodRP
+            | MethodRS
+            | MethodRWS
+            | MethodSA
+            | MethodSLB
+            | MethodSPT
+            | MethodSRS
+            | MethodSS
+            | MethodSTI
+            | MethodSVT
+            | MethodTOT
+            | MethodTP
+            | MethodTR
+            | MethodWST
+        ]
+        | Unset
+    ) = UNSET
+    files: list[File] | Unset = UNSET
     additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)
 
     def to_dict(self) -> dict[str, Any]:
@@ -179,71 +179,71 @@ class Location:
 
         last_updated = self.last_updated.isoformat()
 
-        iogp_type_id: Union[Unset, str] = UNSET
+        iogp_type_id: str | Unset = UNSET
         if not isinstance(self.iogp_type_id, Unset):
             iogp_type_id = self.iogp_type_id.value
 
-        created_by: Union[None, Unset, str]
+        created_by: None | str | Unset
         if isinstance(self.created_by, Unset):
             created_by = UNSET
         else:
             created_by = self.created_by
 
-        updated_by: Union[None, Unset, str]
+        updated_by: None | str | Unset
         if isinstance(self.updated_by, Unset):
             updated_by = UNSET
         else:
             updated_by = self.updated_by
 
-        point_easting: Union[None, Unset, float]
+        point_easting: float | None | Unset
         if isinstance(self.point_easting, Unset):
             point_easting = UNSET
         else:
             point_easting = self.point_easting
 
-        point_northing: Union[None, Unset, float]
+        point_northing: float | None | Unset
         if isinstance(self.point_northing, Unset):
             point_northing = UNSET
         else:
             point_northing = self.point_northing
 
-        point_z: Union[None, Unset, float]
+        point_z: float | None | Unset
         if isinstance(self.point_z, Unset):
             point_z = UNSET
         else:
             point_z = self.point_z
 
-        srid: Union[None, Unset, int]
+        srid: int | None | Unset
         if isinstance(self.srid, Unset):
             srid = UNSET
         else:
             srid = self.srid
 
-        point_x_wgs84_pseudo: Union[None, Unset, float]
+        point_x_wgs84_pseudo: float | None | Unset
         if isinstance(self.point_x_wgs84_pseudo, Unset):
             point_x_wgs84_pseudo = UNSET
         else:
             point_x_wgs84_pseudo = self.point_x_wgs84_pseudo
 
-        point_y_wgs84_pseudo: Union[None, Unset, float]
+        point_y_wgs84_pseudo: float | None | Unset
         if isinstance(self.point_y_wgs84_pseudo, Unset):
             point_y_wgs84_pseudo = UNSET
         else:
             point_y_wgs84_pseudo = self.point_y_wgs84_pseudo
 
-        point_x_wgs84_web: Union[None, Unset, float]
+        point_x_wgs84_web: float | None | Unset
         if isinstance(self.point_x_wgs84_web, Unset):
             point_x_wgs84_web = UNSET
         else:
             point_x_wgs84_web = self.point_x_wgs84_web
 
-        point_y_wgs84_web: Union[None, Unset, float]
+        point_y_wgs84_web: float | None | Unset
         if isinstance(self.point_y_wgs84_web, Unset):
             point_y_wgs84_web = UNSET
         else:
             point_y_wgs84_web = self.point_y_wgs84_web
 
-        tags: Union[None, Unset, list[str]]
+        tags: list[str] | None | Unset
         if isinstance(self.tags, Unset):
             tags = UNSET
         elif isinstance(self.tags, list):
@@ -252,7 +252,7 @@ class Location:
         else:
             tags = self.tags
 
-        methods: Union[Unset, list[dict[str, Any]]] = UNSET
+        methods: list[dict[str, Any]] | Unset = UNSET
         if not isinstance(self.methods, Unset):
             methods = []
             for methods_item_data in self.methods:
@@ -316,7 +316,7 @@ class Location:
 
                 methods.append(methods_item)
 
-        files: Union[Unset, list[dict[str, Any]]] = UNSET
+        files: list[dict[str, Any]] | Unset = UNSET
         if not isinstance(self.files, Unset):
             files = []
             for files_item_data in self.files:
@@ -415,103 +415,103 @@ class Location:
         last_updated = isoparse(d.pop("last_updated"))
 
         _iogp_type_id = d.pop("iogp_type_id", UNSET)
-        iogp_type_id: Union[Unset, IOGPTypeEnum]
+        iogp_type_id: IOGPTypeEnum | Unset
         if isinstance(_iogp_type_id, Unset):
             iogp_type_id = UNSET
         else:
             iogp_type_id = IOGPTypeEnum(_iogp_type_id)
 
-        def _parse_created_by(data: object) -> Union[None, Unset, str]:
+        def _parse_created_by(data: object) -> None | str | Unset:
             if data is None:
                 return data
             if isinstance(data, Unset):
                 return data
-            return cast(Union[None, Unset, str], data)
+            return cast(None | str | Unset, data)
 
         created_by = _parse_created_by(d.pop("created_by", UNSET))
 
-        def _parse_updated_by(data: object) -> Union[None, Unset, str]:
+        def _parse_updated_by(data: object) -> None | str | Unset:
             if data is None:
                 return data
             if isinstance(data, Unset):
                 return data
-            return cast(Union[None, Unset, str], data)
+            return cast(None | str | Unset, data)
 
         updated_by = _parse_updated_by(d.pop("updated_by", UNSET))
 
-        def _parse_point_easting(data: object) -> Union[None, Unset, float]:
+        def _parse_point_easting(data: object) -> float | None | Unset:
             if data is None:
                 return data
             if isinstance(data, Unset):
                 return data
-            return cast(Union[None, Unset, float], data)
+            return cast(float | None | Unset, data)
 
         point_easting = _parse_point_easting(d.pop("point_easting", UNSET))
 
-        def _parse_point_northing(data: object) -> Union[None, Unset, float]:
+        def _parse_point_northing(data: object) -> float | None | Unset:
             if data is None:
                 return data
             if isinstance(data, Unset):
                 return data
-            return cast(Union[None, Unset, float], data)
+            return cast(float | None | Unset, data)
 
         point_northing = _parse_point_northing(d.pop("point_northing", UNSET))
 
-        def _parse_point_z(data: object) -> Union[None, Unset, float]:
+        def _parse_point_z(data: object) -> float | None | Unset:
             if data is None:
                 return data
             if isinstance(data, Unset):
                 return data
-            return cast(Union[None, Unset, float], data)
+            return cast(float | None | Unset, data)
 
         point_z = _parse_point_z(d.pop("point_z", UNSET))
 
-        def _parse_srid(data: object) -> Union[None, Unset, int]:
+        def _parse_srid(data: object) -> int | None | Unset:
             if data is None:
                 return data
             if isinstance(data, Unset):
                 return data
-            return cast(Union[None, Unset, int], data)
+            return cast(int | None | Unset, data)
 
         srid = _parse_srid(d.pop("srid", UNSET))
 
-        def _parse_point_x_wgs84_pseudo(data: object) -> Union[None, Unset, float]:
+        def _parse_point_x_wgs84_pseudo(data: object) -> float | None | Unset:
             if data is None:
                 return data
             if isinstance(data, Unset):
                 return data
-            return cast(Union[None, Unset, float], data)
+            return cast(float | None | Unset, data)
 
         point_x_wgs84_pseudo = _parse_point_x_wgs84_pseudo(d.pop("point_x_wgs84_pseudo", UNSET))
 
-        def _parse_point_y_wgs84_pseudo(data: object) -> Union[None, Unset, float]:
+        def _parse_point_y_wgs84_pseudo(data: object) -> float | None | Unset:
             if data is None:
                 return data
             if isinstance(data, Unset):
                 return data
-            return cast(Union[None, Unset, float], data)
+            return cast(float | None | Unset, data)
 
         point_y_wgs84_pseudo = _parse_point_y_wgs84_pseudo(d.pop("point_y_wgs84_pseudo", UNSET))
 
-        def _parse_point_x_wgs84_web(data: object) -> Union[None, Unset, float]:
+        def _parse_point_x_wgs84_web(data: object) -> float | None | Unset:
             if data is None:
                 return data
             if isinstance(data, Unset):
                 return data
-            return cast(Union[None, Unset, float], data)
+            return cast(float | None | Unset, data)
 
         point_x_wgs84_web = _parse_point_x_wgs84_web(d.pop("point_x_wgs84_web", UNSET))
 
-        def _parse_point_y_wgs84_web(data: object) -> Union[None, Unset, float]:
+        def _parse_point_y_wgs84_web(data: object) -> float | None | Unset:
             if data is None:
                 return data
             if isinstance(data, Unset):
                 return data
-            return cast(Union[None, Unset, float], data)
+            return cast(float | None | Unset, data)
 
         point_y_wgs84_web = _parse_point_y_wgs84_web(d.pop("point_y_wgs84_web", UNSET))
 
-        def _parse_tags(data: object) -> Union[None, Unset, list[str]]:
+        def _parse_tags(data: object) -> list[str] | None | Unset:
             if data is None:
                 return data
             if isinstance(data, Unset):
@@ -522,280 +522,316 @@ class Location:
                 tags_type_0 = cast(list[str], data)
 
                 return tags_type_0
-            except:  # noqa: E722
+            except (TypeError, ValueError, AttributeError, KeyError):
                 pass
-            return cast(Union[None, Unset, list[str]], data)
+            return cast(list[str] | None | Unset, data)
 
         tags = _parse_tags(d.pop("tags", UNSET))
 
-        methods = []
         _methods = d.pop("methods", UNSET)
-        for methods_item_data in _methods or []:
+        methods: (
+            list[
+                MethodAD
+                | MethodCD
+                | MethodCPT
+                | MethodDEF
+                | MethodDP
+                | MethodDT
+                | MethodESA
+                | MethodINC
+                | MethodIW
+                | MethodOTHER
+                | MethodPT
+                | MethodPZ
+                | MethodRCD
+                | MethodRO
+                | MethodRP
+                | MethodRS
+                | MethodRWS
+                | MethodSA
+                | MethodSLB
+                | MethodSPT
+                | MethodSRS
+                | MethodSS
+                | MethodSTI
+                | MethodSVT
+                | MethodTOT
+                | MethodTP
+                | MethodTR
+                | MethodWST
+            ]
+            | Unset
+        ) = UNSET
+        if _methods is not UNSET:
+            methods = []
+            for methods_item_data in _methods:
 
-            def _parse_methods_item(
-                data: object,
-            ) -> Union[
-                "MethodAD",
-                "MethodCD",
-                "MethodCPT",
-                "MethodDEF",
-                "MethodDP",
-                "MethodDT",
-                "MethodESA",
-                "MethodINC",
-                "MethodIW",
-                "MethodOTHER",
-                "MethodPT",
-                "MethodPZ",
-                "MethodRCD",
-                "MethodRO",
-                "MethodRP",
-                "MethodRS",
-                "MethodRWS",
-                "MethodSA",
-                "MethodSLB",
-                "MethodSPT",
-                "MethodSRS",
-                "MethodSS",
-                "MethodSTI",
-                "MethodSVT",
-                "MethodTOT",
-                "MethodTP",
-                "MethodTR",
-                "MethodWST",
-            ]:
-                try:
+                def _parse_methods_item(
+                    data: object,
+                ) -> (
+                    MethodAD
+                    | MethodCD
+                    | MethodCPT
+                    | MethodDEF
+                    | MethodDP
+                    | MethodDT
+                    | MethodESA
+                    | MethodINC
+                    | MethodIW
+                    | MethodOTHER
+                    | MethodPT
+                    | MethodPZ
+                    | MethodRCD
+                    | MethodRO
+                    | MethodRP
+                    | MethodRS
+                    | MethodRWS
+                    | MethodSA
+                    | MethodSLB
+                    | MethodSPT
+                    | MethodSRS
+                    | MethodSS
+                    | MethodSTI
+                    | MethodSVT
+                    | MethodTOT
+                    | MethodTP
+                    | MethodTR
+                    | MethodWST
+                ):
+                    try:
+                        if not isinstance(data, dict):
+                            raise TypeError()
+                        methods_item_type_0 = MethodCPT.from_dict(data)
+
+                        return methods_item_type_0
+                    except (TypeError, ValueError, AttributeError, KeyError):
+                        pass
+                    try:
+                        if not isinstance(data, dict):
+                            raise TypeError()
+                        methods_item_type_1 = MethodTOT.from_dict(data)
+
+                        return methods_item_type_1
+                    except (TypeError, ValueError, AttributeError, KeyError):
+                        pass
+                    try:
+                        if not isinstance(data, dict):
+                            raise TypeError()
+                        methods_item_type_2 = MethodRP.from_dict(data)
+
+                        return methods_item_type_2
+                    except (TypeError, ValueError, AttributeError, KeyError):
+                        pass
+                    try:
+                        if not isinstance(data, dict):
+                            raise TypeError()
+                        methods_item_type_3 = MethodSA.from_dict(data)
+
+                        return methods_item_type_3
+                    except (TypeError, ValueError, AttributeError, KeyError):
+                        pass
+                    try:
+                        if not isinstance(data, dict):
+                            raise TypeError()
+                        methods_item_type_4 = MethodPZ.from_dict(data)
+
+                        return methods_item_type_4
+                    except (TypeError, ValueError, AttributeError, KeyError):
+                        pass
+                    try:
+                        if not isinstance(data, dict):
+                            raise TypeError()
+                        methods_item_type_5 = MethodSS.from_dict(data)
+
+                        return methods_item_type_5
+                    except (TypeError, ValueError, AttributeError, KeyError):
+                        pass
+                    try:
+                        if not isinstance(data, dict):
+                            raise TypeError()
+                        methods_item_type_6 = MethodRWS.from_dict(data)
+
+                        return methods_item_type_6
+                    except (TypeError, ValueError, AttributeError, KeyError):
+                        pass
+                    try:
+                        if not isinstance(data, dict):
+                            raise TypeError()
+                        methods_item_type_7 = MethodRCD.from_dict(data)
+
+                        return methods_item_type_7
+                    except (TypeError, ValueError, AttributeError, KeyError):
+                        pass
+                    try:
+                        if not isinstance(data, dict):
+                            raise TypeError()
+                        methods_item_type_8 = MethodRS.from_dict(data)
+
+                        return methods_item_type_8
+                    except (TypeError, ValueError, AttributeError, KeyError):
+                        pass
+                    try:
+                        if not isinstance(data, dict):
+                            raise TypeError()
+                        methods_item_type_9 = MethodSVT.from_dict(data)
+
+                        return methods_item_type_9
+                    except (TypeError, ValueError, AttributeError, KeyError):
+                        pass
+                    try:
+                        if not isinstance(data, dict):
+                            raise TypeError()
+                        methods_item_type_10 = MethodSPT.from_dict(data)
+
+                        return methods_item_type_10
+                    except (TypeError, ValueError, AttributeError, KeyError):
+                        pass
+                    try:
+                        if not isinstance(data, dict):
+                            raise TypeError()
+                        methods_item_type_11 = MethodCD.from_dict(data)
+
+                        return methods_item_type_11
+                    except (TypeError, ValueError, AttributeError, KeyError):
+                        pass
+                    try:
+                        if not isinstance(data, dict):
+                            raise TypeError()
+                        methods_item_type_12 = MethodTP.from_dict(data)
+
+                        return methods_item_type_12
+                    except (TypeError, ValueError, AttributeError, KeyError):
+                        pass
+                    try:
+                        if not isinstance(data, dict):
+                            raise TypeError()
+                        methods_item_type_13 = MethodPT.from_dict(data)
+
+                        return methods_item_type_13
+                    except (TypeError, ValueError, AttributeError, KeyError):
+                        pass
+                    try:
+                        if not isinstance(data, dict):
+                            raise TypeError()
+                        methods_item_type_14 = MethodESA.from_dict(data)
+
+                        return methods_item_type_14
+                    except (TypeError, ValueError, AttributeError, KeyError):
+                        pass
+                    try:
+                        if not isinstance(data, dict):
+                            raise TypeError()
+                        methods_item_type_15 = MethodTR.from_dict(data)
+
+                        return methods_item_type_15
+                    except (TypeError, ValueError, AttributeError, KeyError):
+                        pass
+                    try:
+                        if not isinstance(data, dict):
+                            raise TypeError()
+                        methods_item_type_16 = MethodAD.from_dict(data)
+
+                        return methods_item_type_16
+                    except (TypeError, ValueError, AttributeError, KeyError):
+                        pass
+                    try:
+                        if not isinstance(data, dict):
+                            raise TypeError()
+                        methods_item_type_17 = MethodRO.from_dict(data)
+
+                        return methods_item_type_17
+                    except (TypeError, ValueError, AttributeError, KeyError):
+                        pass
+                    try:
+                        if not isinstance(data, dict):
+                            raise TypeError()
+                        methods_item_type_18 = MethodINC.from_dict(data)
+
+                        return methods_item_type_18
+                    except (TypeError, ValueError, AttributeError, KeyError):
+                        pass
+                    try:
+                        if not isinstance(data, dict):
+                            raise TypeError()
+                        methods_item_type_19 = MethodDEF.from_dict(data)
+
+                        return methods_item_type_19
+                    except (TypeError, ValueError, AttributeError, KeyError):
+                        pass
+                    try:
+                        if not isinstance(data, dict):
+                            raise TypeError()
+                        methods_item_type_20 = MethodIW.from_dict(data)
+
+                        return methods_item_type_20
+                    except (TypeError, ValueError, AttributeError, KeyError):
+                        pass
+                    try:
+                        if not isinstance(data, dict):
+                            raise TypeError()
+                        methods_item_type_21 = MethodDT.from_dict(data)
+
+                        return methods_item_type_21
+                    except (TypeError, ValueError, AttributeError, KeyError):
+                        pass
+                    try:
+                        if not isinstance(data, dict):
+                            raise TypeError()
+                        methods_item_type_22 = MethodOTHER.from_dict(data)
+
+                        return methods_item_type_22
+                    except (TypeError, ValueError, AttributeError, KeyError):
+                        pass
+                    try:
+                        if not isinstance(data, dict):
+                            raise TypeError()
+                        methods_item_type_23 = MethodSRS.from_dict(data)
+
+                        return methods_item_type_23
+                    except (TypeError, ValueError, AttributeError, KeyError):
+                        pass
+                    try:
+                        if not isinstance(data, dict):
+                            raise TypeError()
+                        methods_item_type_24 = MethodDP.from_dict(data)
+
+                        return methods_item_type_24
+                    except (TypeError, ValueError, AttributeError, KeyError):
+                        pass
+                    try:
+                        if not isinstance(data, dict):
+                            raise TypeError()
+                        methods_item_type_25 = MethodWST.from_dict(data)
+
+                        return methods_item_type_25
+                    except (TypeError, ValueError, AttributeError, KeyError):
+                        pass
+                    try:
+                        if not isinstance(data, dict):
+                            raise TypeError()
+                        methods_item_type_26 = MethodSLB.from_dict(data)
+
+                        return methods_item_type_26
+                    except (TypeError, ValueError, AttributeError, KeyError):
+                        pass
                     if not isinstance(data, dict):
                         raise TypeError()
-                    methods_item_type_0 = MethodCPT.from_dict(data)
+                    methods_item_type_27 = MethodSTI.from_dict(data)
 
-                    return methods_item_type_0
-                except:  # noqa: E722
-                    pass
-                try:
-                    if not isinstance(data, dict):
-                        raise TypeError()
-                    methods_item_type_1 = MethodTOT.from_dict(data)
+                    return methods_item_type_27
 
-                    return methods_item_type_1
-                except:  # noqa: E722
-                    pass
-                try:
-                    if not isinstance(data, dict):
-                        raise TypeError()
-                    methods_item_type_2 = MethodRP.from_dict(data)
+                methods_item = _parse_methods_item(methods_item_data)
 
-                    return methods_item_type_2
-                except:  # noqa: E722
-                    pass
-                try:
-                    if not isinstance(data, dict):
-                        raise TypeError()
-                    methods_item_type_3 = MethodSA.from_dict(data)
+                methods.append(methods_item)
 
-                    return methods_item_type_3
-                except:  # noqa: E722
-                    pass
-                try:
-                    if not isinstance(data, dict):
-                        raise TypeError()
-                    methods_item_type_4 = MethodPZ.from_dict(data)
-
-                    return methods_item_type_4
-                except:  # noqa: E722
-                    pass
-                try:
-                    if not isinstance(data, dict):
-                        raise TypeError()
-                    methods_item_type_5 = MethodSS.from_dict(data)
-
-                    return methods_item_type_5
-                except:  # noqa: E722
-                    pass
-                try:
-                    if not isinstance(data, dict):
-                        raise TypeError()
-                    methods_item_type_6 = MethodRWS.from_dict(data)
-
-                    return methods_item_type_6
-                except:  # noqa: E722
-                    pass
-                try:
-                    if not isinstance(data, dict):
-                        raise TypeError()
-                    methods_item_type_7 = MethodRCD.from_dict(data)
-
-                    return methods_item_type_7
-                except:  # noqa: E722
-                    pass
-                try:
-                    if not isinstance(data, dict):
-                        raise TypeError()
-                    methods_item_type_8 = MethodRS.from_dict(data)
-
-                    return methods_item_type_8
-                except:  # noqa: E722
-                    pass
-                try:
-                    if not isinstance(data, dict):
-                        raise TypeError()
-                    methods_item_type_9 = MethodSVT.from_dict(data)
-
-                    return methods_item_type_9
-                except:  # noqa: E722
-                    pass
-                try:
-                    if not isinstance(data, dict):
-                        raise TypeError()
-                    methods_item_type_10 = MethodSPT.from_dict(data)
-
-                    return methods_item_type_10
-                except:  # noqa: E722
-                    pass
-                try:
-                    if not isinstance(data, dict):
-                        raise TypeError()
-                    methods_item_type_11 = MethodCD.from_dict(data)
-
-                    return methods_item_type_11
-                except:  # noqa: E722
-                    pass
-                try:
-                    if not isinstance(data, dict):
-                        raise TypeError()
-                    methods_item_type_12 = MethodTP.from_dict(data)
-
-                    return methods_item_type_12
-                except:  # noqa: E722
-                    pass
-                try:
-                    if not isinstance(data, dict):
-                        raise TypeError()
-                    methods_item_type_13 = MethodPT.from_dict(data)
-
-                    return methods_item_type_13
-                except:  # noqa: E722
-                    pass
-                try:
-                    if not isinstance(data, dict):
-                        raise TypeError()
-                    methods_item_type_14 = MethodESA.from_dict(data)
-
-                    return methods_item_type_14
-                except:  # noqa: E722
-                    pass
-                try:
-                    if not isinstance(data, dict):
-                        raise TypeError()
-                    methods_item_type_15 = MethodTR.from_dict(data)
-
-                    return methods_item_type_15
-                except:  # noqa: E722
-                    pass
-                try:
-                    if not isinstance(data, dict):
-                        raise TypeError()
-                    methods_item_type_16 = MethodAD.from_dict(data)
-
-                    return methods_item_type_16
-                except:  # noqa: E722
-                    pass
-                try:
-                    if not isinstance(data, dict):
-                        raise TypeError()
-                    methods_item_type_17 = MethodRO.from_dict(data)
-
-                    return methods_item_type_17
-                except:  # noqa: E722
-                    pass
-                try:
-                    if not isinstance(data, dict):
-                        raise TypeError()
-                    methods_item_type_18 = MethodINC.from_dict(data)
-
-                    return methods_item_type_18
-                except:  # noqa: E722
-                    pass
-                try:
-                    if not isinstance(data, dict):
-                        raise TypeError()
-                    methods_item_type_19 = MethodDEF.from_dict(data)
-
-                    return methods_item_type_19
-                except:  # noqa: E722
-                    pass
-                try:
-                    if not isinstance(data, dict):
-                        raise TypeError()
-                    methods_item_type_20 = MethodIW.from_dict(data)
-
-                    return methods_item_type_20
-                except:  # noqa: E722
-                    pass
-                try:
-                    if not isinstance(data, dict):
-                        raise TypeError()
-                    methods_item_type_21 = MethodDT.from_dict(data)
-
-                    return methods_item_type_21
-                except:  # noqa: E722
-                    pass
-                try:
-                    if not isinstance(data, dict):
-                        raise TypeError()
-                    methods_item_type_22 = MethodOTHER.from_dict(data)
-
-                    return methods_item_type_22
-                except:  # noqa: E722
-                    pass
-                try:
-                    if not isinstance(data, dict):
-                        raise TypeError()
-                    methods_item_type_23 = MethodSRS.from_dict(data)
-
-                    return methods_item_type_23
-                except:  # noqa: E722
-                    pass
-                try:
-                    if not isinstance(data, dict):
-                        raise TypeError()
-                    methods_item_type_24 = MethodDP.from_dict(data)
-
-                    return methods_item_type_24
-                except:  # noqa: E722
-                    pass
-                try:
-                    if not isinstance(data, dict):
-                        raise TypeError()
-                    methods_item_type_25 = MethodWST.from_dict(data)
-
-                    return methods_item_type_25
-                except:  # noqa: E722
-                    pass
-                try:
-                    if not isinstance(data, dict):
-                        raise TypeError()
-                    methods_item_type_26 = MethodSLB.from_dict(data)
-
-                    return methods_item_type_26
-                except:  # noqa: E722
-                    pass
-                if not isinstance(data, dict):
-                    raise TypeError()
-                methods_item_type_27 = MethodSTI.from_dict(data)
-
-                return methods_item_type_27
-
-            methods_item = _parse_methods_item(methods_item_data)
-
-            methods.append(methods_item)
-
-        files = []
         _files = d.pop("files", UNSET)
-        for files_item_data in _files or []:
-            files_item = File.from_dict(files_item_data)
+        files: list[File] | Unset = UNSET
+        if _files is not UNSET:
+            files = []
+            for files_item_data in _files:
+                files_item = File.from_dict(files_item_data)
 
-            files.append(files_item)
+                files.append(files_item)
 
         location = cls(
             name=name,
