@@ -1,5 +1,8 @@
+from __future__ import annotations
+
 import datetime
-from typing import Any, Literal, TypeVar, Union, cast
+from collections.abc import Mapping
+from typing import Any, Literal, TypeVar, cast
 from uuid import UUID
 
 from attrs import define as _attrs_define
@@ -15,53 +18,53 @@ T = TypeVar("T", bound="MethodCPTDataCreate")
 class MethodCPTDataCreate:
     """
     Attributes:
-        depth (Union[float, str]): Depth (m). SGF code D.
-        method_data_id (Union[None, UUID, Unset]):
-        method_id (Union[None, UUID, Unset]):
-        method_type_id (Union[Literal[1], Unset]):  Default: 1.
-        created_at (Union[None, Unset, datetime.datetime]):
-        updated_at (Union[None, Unset, datetime.datetime]):
-        penetration_rate (Union[None, Unset, float, str]):
-        penetration_force (Union[None, Unset, float, str]):
-        fs (Union[None, Unset, float, str]):
-        comment_code (Union[None, Unset, int]):
-        conductivity (Union[None, Unset, float, str]):
-        zero_value_resistance (Union[None, Unset, float, str]):
-        zero_value_friction (Union[None, Unset, float, str]):
-        zero_value_pressure (Union[None, Unset, float, str]):
-        temperature (Union[None, Unset, float, str]):
-        qc (Union[None, Unset, float, str]):
-        remarks (Union[None, Unset, str]):
-        tilt (Union[None, Unset, float, str]):
-        u2 (Union[None, Unset, float, str]):
+        depth (float | str): Depth (m). SGF code D.
+        method_data_id (None | Unset | UUID):
+        method_id (None | Unset | UUID):
+        method_type_id (Literal[1] | Unset):  Default: 1.
+        created_at (datetime.datetime | None | Unset):
+        updated_at (datetime.datetime | None | Unset):
+        penetration_rate (float | None | str | Unset):
+        penetration_force (float | None | str | Unset):
+        fs (float | None | str | Unset):
+        comment_code (int | None | Unset):
+        conductivity (float | None | str | Unset):
+        zero_value_resistance (float | None | str | Unset):
+        zero_value_friction (float | None | str | Unset):
+        zero_value_pressure (float | None | str | Unset):
+        temperature (float | None | str | Unset):
+        qc (float | None | str | Unset):
+        remarks (None | str | Unset):
+        tilt (float | None | str | Unset):
+        u2 (float | None | str | Unset):
     """
 
-    depth: Union[float, str]
-    method_data_id: Union[None, UUID, Unset] = UNSET
-    method_id: Union[None, UUID, Unset] = UNSET
-    method_type_id: Union[Literal[1], Unset] = 1
-    created_at: Union[None, Unset, datetime.datetime] = UNSET
-    updated_at: Union[None, Unset, datetime.datetime] = UNSET
-    penetration_rate: Union[None, Unset, float, str] = UNSET
-    penetration_force: Union[None, Unset, float, str] = UNSET
-    fs: Union[None, Unset, float, str] = UNSET
-    comment_code: Union[None, Unset, int] = UNSET
-    conductivity: Union[None, Unset, float, str] = UNSET
-    zero_value_resistance: Union[None, Unset, float, str] = UNSET
-    zero_value_friction: Union[None, Unset, float, str] = UNSET
-    zero_value_pressure: Union[None, Unset, float, str] = UNSET
-    temperature: Union[None, Unset, float, str] = UNSET
-    qc: Union[None, Unset, float, str] = UNSET
-    remarks: Union[None, Unset, str] = UNSET
-    tilt: Union[None, Unset, float, str] = UNSET
-    u2: Union[None, Unset, float, str] = UNSET
+    depth: float | str
+    method_data_id: None | Unset | UUID = UNSET
+    method_id: None | Unset | UUID = UNSET
+    method_type_id: Literal[1] | Unset = 1
+    created_at: datetime.datetime | None | Unset = UNSET
+    updated_at: datetime.datetime | None | Unset = UNSET
+    penetration_rate: float | None | str | Unset = UNSET
+    penetration_force: float | None | str | Unset = UNSET
+    fs: float | None | str | Unset = UNSET
+    comment_code: int | None | Unset = UNSET
+    conductivity: float | None | str | Unset = UNSET
+    zero_value_resistance: float | None | str | Unset = UNSET
+    zero_value_friction: float | None | str | Unset = UNSET
+    zero_value_pressure: float | None | str | Unset = UNSET
+    temperature: float | None | str | Unset = UNSET
+    qc: float | None | str | Unset = UNSET
+    remarks: None | str | Unset = UNSET
+    tilt: float | None | str | Unset = UNSET
+    u2: float | None | str | Unset = UNSET
     additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)
 
     def to_dict(self) -> dict[str, Any]:
-        depth: Union[float, str]
+        depth: float | str
         depth = self.depth
 
-        method_data_id: Union[None, Unset, str]
+        method_data_id: None | str | Unset
         if isinstance(self.method_data_id, Unset):
             method_data_id = UNSET
         elif isinstance(self.method_data_id, UUID):
@@ -69,7 +72,7 @@ class MethodCPTDataCreate:
         else:
             method_data_id = self.method_data_id
 
-        method_id: Union[None, Unset, str]
+        method_id: None | str | Unset
         if isinstance(self.method_id, Unset):
             method_id = UNSET
         elif isinstance(self.method_id, UUID):
@@ -79,7 +82,7 @@ class MethodCPTDataCreate:
 
         method_type_id = self.method_type_id
 
-        created_at: Union[None, Unset, str]
+        created_at: None | str | Unset
         if isinstance(self.created_at, Unset):
             created_at = UNSET
         elif isinstance(self.created_at, datetime.datetime):
@@ -87,7 +90,7 @@ class MethodCPTDataCreate:
         else:
             created_at = self.created_at
 
-        updated_at: Union[None, Unset, str]
+        updated_at: None | str | Unset
         if isinstance(self.updated_at, Unset):
             updated_at = UNSET
         elif isinstance(self.updated_at, datetime.datetime):
@@ -95,79 +98,79 @@ class MethodCPTDataCreate:
         else:
             updated_at = self.updated_at
 
-        penetration_rate: Union[None, Unset, float, str]
+        penetration_rate: float | None | str | Unset
         if isinstance(self.penetration_rate, Unset):
             penetration_rate = UNSET
         else:
             penetration_rate = self.penetration_rate
 
-        penetration_force: Union[None, Unset, float, str]
+        penetration_force: float | None | str | Unset
         if isinstance(self.penetration_force, Unset):
             penetration_force = UNSET
         else:
             penetration_force = self.penetration_force
 
-        fs: Union[None, Unset, float, str]
+        fs: float | None | str | Unset
         if isinstance(self.fs, Unset):
             fs = UNSET
         else:
             fs = self.fs
 
-        comment_code: Union[None, Unset, int]
+        comment_code: int | None | Unset
         if isinstance(self.comment_code, Unset):
             comment_code = UNSET
         else:
             comment_code = self.comment_code
 
-        conductivity: Union[None, Unset, float, str]
+        conductivity: float | None | str | Unset
         if isinstance(self.conductivity, Unset):
             conductivity = UNSET
         else:
             conductivity = self.conductivity
 
-        zero_value_resistance: Union[None, Unset, float, str]
+        zero_value_resistance: float | None | str | Unset
         if isinstance(self.zero_value_resistance, Unset):
             zero_value_resistance = UNSET
         else:
             zero_value_resistance = self.zero_value_resistance
 
-        zero_value_friction: Union[None, Unset, float, str]
+        zero_value_friction: float | None | str | Unset
         if isinstance(self.zero_value_friction, Unset):
             zero_value_friction = UNSET
         else:
             zero_value_friction = self.zero_value_friction
 
-        zero_value_pressure: Union[None, Unset, float, str]
+        zero_value_pressure: float | None | str | Unset
         if isinstance(self.zero_value_pressure, Unset):
             zero_value_pressure = UNSET
         else:
             zero_value_pressure = self.zero_value_pressure
 
-        temperature: Union[None, Unset, float, str]
+        temperature: float | None | str | Unset
         if isinstance(self.temperature, Unset):
             temperature = UNSET
         else:
             temperature = self.temperature
 
-        qc: Union[None, Unset, float, str]
+        qc: float | None | str | Unset
         if isinstance(self.qc, Unset):
             qc = UNSET
         else:
             qc = self.qc
 
-        remarks: Union[None, Unset, str]
+        remarks: None | str | Unset
         if isinstance(self.remarks, Unset):
             remarks = UNSET
         else:
             remarks = self.remarks
 
-        tilt: Union[None, Unset, float, str]
+        tilt: float | None | str | Unset
         if isinstance(self.tilt, Unset):
             tilt = UNSET
         else:
             tilt = self.tilt
 
-        u2: Union[None, Unset, float, str]
+        u2: float | None | str | Unset
         if isinstance(self.u2, Unset):
             u2 = UNSET
         else:
@@ -220,15 +223,15 @@ class MethodCPTDataCreate:
         return field_dict
 
     @classmethod
-    def from_dict(cls: type[T], src_dict: dict[str, Any]) -> T:
-        d = src_dict.copy()
+    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
+        d = dict(src_dict)
 
-        def _parse_depth(data: object) -> Union[float, str]:
-            return cast(Union[float, str], data)
+        def _parse_depth(data: object) -> float | str:
+            return cast(float | str, data)
 
         depth = _parse_depth(d.pop("depth"))
 
-        def _parse_method_data_id(data: object) -> Union[None, UUID, Unset]:
+        def _parse_method_data_id(data: object) -> None | Unset | UUID:
             if data is None:
                 return data
             if isinstance(data, Unset):
@@ -239,13 +242,13 @@ class MethodCPTDataCreate:
                 method_data_id_type_0 = UUID(data)
 
                 return method_data_id_type_0
-            except:  # noqa: E722
+            except (TypeError, ValueError, AttributeError, KeyError):
                 pass
-            return cast(Union[None, UUID, Unset], data)
+            return cast(None | Unset | UUID, data)
 
         method_data_id = _parse_method_data_id(d.pop("method_data_id", UNSET))
 
-        def _parse_method_id(data: object) -> Union[None, UUID, Unset]:
+        def _parse_method_id(data: object) -> None | Unset | UUID:
             if data is None:
                 return data
             if isinstance(data, Unset):
@@ -256,17 +259,17 @@ class MethodCPTDataCreate:
                 method_id_type_0 = UUID(data)
 
                 return method_id_type_0
-            except:  # noqa: E722
+            except (TypeError, ValueError, AttributeError, KeyError):
                 pass
-            return cast(Union[None, UUID, Unset], data)
+            return cast(None | Unset | UUID, data)
 
         method_id = _parse_method_id(d.pop("method_id", UNSET))
 
-        method_type_id = cast(Union[Literal[1], Unset], d.pop("method_type_id", UNSET))
+        method_type_id = cast(Literal[1] | Unset, d.pop("method_type_id", UNSET))
         if method_type_id != 1 and not isinstance(method_type_id, Unset):
             raise ValueError(f"method_type_id must match const 1, got '{method_type_id}'")
 
-        def _parse_created_at(data: object) -> Union[None, Unset, datetime.datetime]:
+        def _parse_created_at(data: object) -> datetime.datetime | None | Unset:
             if data is None:
                 return data
             if isinstance(data, Unset):
@@ -277,13 +280,13 @@ class MethodCPTDataCreate:
                 created_at_type_0 = isoparse(data)
 
                 return created_at_type_0
-            except:  # noqa: E722
+            except (TypeError, ValueError, AttributeError, KeyError):
                 pass
-            return cast(Union[None, Unset, datetime.datetime], data)
+            return cast(datetime.datetime | None | Unset, data)
 
         created_at = _parse_created_at(d.pop("created_at", UNSET))
 
-        def _parse_updated_at(data: object) -> Union[None, Unset, datetime.datetime]:
+        def _parse_updated_at(data: object) -> datetime.datetime | None | Unset:
             if data is None:
                 return data
             if isinstance(data, Unset):
@@ -294,126 +297,126 @@ class MethodCPTDataCreate:
                 updated_at_type_0 = isoparse(data)
 
                 return updated_at_type_0
-            except:  # noqa: E722
+            except (TypeError, ValueError, AttributeError, KeyError):
                 pass
-            return cast(Union[None, Unset, datetime.datetime], data)
+            return cast(datetime.datetime | None | Unset, data)
 
         updated_at = _parse_updated_at(d.pop("updated_at", UNSET))
 
-        def _parse_penetration_rate(data: object) -> Union[None, Unset, float, str]:
+        def _parse_penetration_rate(data: object) -> float | None | str | Unset:
             if data is None:
                 return data
             if isinstance(data, Unset):
                 return data
-            return cast(Union[None, Unset, float, str], data)
+            return cast(float | None | str | Unset, data)
 
         penetration_rate = _parse_penetration_rate(d.pop("penetration_rate", UNSET))
 
-        def _parse_penetration_force(data: object) -> Union[None, Unset, float, str]:
+        def _parse_penetration_force(data: object) -> float | None | str | Unset:
             if data is None:
                 return data
             if isinstance(data, Unset):
                 return data
-            return cast(Union[None, Unset, float, str], data)
+            return cast(float | None | str | Unset, data)
 
         penetration_force = _parse_penetration_force(d.pop("penetration_force", UNSET))
 
-        def _parse_fs(data: object) -> Union[None, Unset, float, str]:
+        def _parse_fs(data: object) -> float | None | str | Unset:
             if data is None:
                 return data
             if isinstance(data, Unset):
                 return data
-            return cast(Union[None, Unset, float, str], data)
+            return cast(float | None | str | Unset, data)
 
         fs = _parse_fs(d.pop("fs", UNSET))
 
-        def _parse_comment_code(data: object) -> Union[None, Unset, int]:
+        def _parse_comment_code(data: object) -> int | None | Unset:
             if data is None:
                 return data
             if isinstance(data, Unset):
                 return data
-            return cast(Union[None, Unset, int], data)
+            return cast(int | None | Unset, data)
 
         comment_code = _parse_comment_code(d.pop("comment_code", UNSET))
 
-        def _parse_conductivity(data: object) -> Union[None, Unset, float, str]:
+        def _parse_conductivity(data: object) -> float | None | str | Unset:
             if data is None:
                 return data
             if isinstance(data, Unset):
                 return data
-            return cast(Union[None, Unset, float, str], data)
+            return cast(float | None | str | Unset, data)
 
         conductivity = _parse_conductivity(d.pop("conductivity", UNSET))
 
-        def _parse_zero_value_resistance(data: object) -> Union[None, Unset, float, str]:
+        def _parse_zero_value_resistance(data: object) -> float | None | str | Unset:
             if data is None:
                 return data
             if isinstance(data, Unset):
                 return data
-            return cast(Union[None, Unset, float, str], data)
+            return cast(float | None | str | Unset, data)
 
         zero_value_resistance = _parse_zero_value_resistance(d.pop("zero_value_resistance", UNSET))
 
-        def _parse_zero_value_friction(data: object) -> Union[None, Unset, float, str]:
+        def _parse_zero_value_friction(data: object) -> float | None | str | Unset:
             if data is None:
                 return data
             if isinstance(data, Unset):
                 return data
-            return cast(Union[None, Unset, float, str], data)
+            return cast(float | None | str | Unset, data)
 
         zero_value_friction = _parse_zero_value_friction(d.pop("zero_value_friction", UNSET))
 
-        def _parse_zero_value_pressure(data: object) -> Union[None, Unset, float, str]:
+        def _parse_zero_value_pressure(data: object) -> float | None | str | Unset:
             if data is None:
                 return data
             if isinstance(data, Unset):
                 return data
-            return cast(Union[None, Unset, float, str], data)
+            return cast(float | None | str | Unset, data)
 
         zero_value_pressure = _parse_zero_value_pressure(d.pop("zero_value_pressure", UNSET))
 
-        def _parse_temperature(data: object) -> Union[None, Unset, float, str]:
+        def _parse_temperature(data: object) -> float | None | str | Unset:
             if data is None:
                 return data
             if isinstance(data, Unset):
                 return data
-            return cast(Union[None, Unset, float, str], data)
+            return cast(float | None | str | Unset, data)
 
         temperature = _parse_temperature(d.pop("temperature", UNSET))
 
-        def _parse_qc(data: object) -> Union[None, Unset, float, str]:
+        def _parse_qc(data: object) -> float | None | str | Unset:
             if data is None:
                 return data
             if isinstance(data, Unset):
                 return data
-            return cast(Union[None, Unset, float, str], data)
+            return cast(float | None | str | Unset, data)
 
         qc = _parse_qc(d.pop("qc", UNSET))
 
-        def _parse_remarks(data: object) -> Union[None, Unset, str]:
+        def _parse_remarks(data: object) -> None | str | Unset:
             if data is None:
                 return data
             if isinstance(data, Unset):
                 return data
-            return cast(Union[None, Unset, str], data)
+            return cast(None | str | Unset, data)
 
         remarks = _parse_remarks(d.pop("remarks", UNSET))
 
-        def _parse_tilt(data: object) -> Union[None, Unset, float, str]:
+        def _parse_tilt(data: object) -> float | None | str | Unset:
             if data is None:
                 return data
             if isinstance(data, Unset):
                 return data
-            return cast(Union[None, Unset, float, str], data)
+            return cast(float | None | str | Unset, data)
 
         tilt = _parse_tilt(d.pop("tilt", UNSET))
 
-        def _parse_u2(data: object) -> Union[None, Unset, float, str]:
+        def _parse_u2(data: object) -> float | None | str | Unset:
             if data is None:
                 return data
             if isinstance(data, Unset):
                 return data
-            return cast(Union[None, Unset, float, str], data)
+            return cast(float | None | str | Unset, data)
 
         u2 = _parse_u2(d.pop("u2", UNSET))
 
