@@ -1,5 +1,8 @@
+from __future__ import annotations
+
 import datetime
-from typing import Any, Literal, TypeVar, Union, cast
+from collections.abc import Mapping
+from typing import Any, Literal, TypeVar, cast
 from uuid import UUID
 
 from attrs import define as _attrs_define
@@ -15,32 +18,32 @@ T = TypeVar("T", bound="MethodDTDataCreate")
 class MethodDTDataCreate:
     """
     Attributes:
-        method_data_id (Union[None, UUID, Unset]):
-        method_id (Union[None, UUID, Unset]):
-        method_type_id (Union[Literal[22], Unset]):  Default: 22.
-        created_at (Union[None, Unset, datetime.datetime]):
-        updated_at (Union[None, Unset, datetime.datetime]):
-        depth (Union[None, Unset, float, str]):
-        time (Union[None, Unset, float, str]):
-        qc (Union[None, Unset, float, str]):
-        u2 (Union[None, Unset, float, str]):
-        remarks (Union[None, Unset, str]):
+        method_data_id (None | Unset | UUID):
+        method_id (None | Unset | UUID):
+        method_type_id (Literal[22] | Unset):  Default: 22.
+        created_at (datetime.datetime | None | Unset):
+        updated_at (datetime.datetime | None | Unset):
+        depth (float | None | str | Unset):
+        time (float | None | str | Unset):
+        qc (float | None | str | Unset):
+        u2 (float | None | str | Unset):
+        remarks (None | str | Unset):
     """
 
-    method_data_id: Union[None, UUID, Unset] = UNSET
-    method_id: Union[None, UUID, Unset] = UNSET
-    method_type_id: Union[Literal[22], Unset] = 22
-    created_at: Union[None, Unset, datetime.datetime] = UNSET
-    updated_at: Union[None, Unset, datetime.datetime] = UNSET
-    depth: Union[None, Unset, float, str] = UNSET
-    time: Union[None, Unset, float, str] = UNSET
-    qc: Union[None, Unset, float, str] = UNSET
-    u2: Union[None, Unset, float, str] = UNSET
-    remarks: Union[None, Unset, str] = UNSET
+    method_data_id: None | Unset | UUID = UNSET
+    method_id: None | Unset | UUID = UNSET
+    method_type_id: Literal[22] | Unset = 22
+    created_at: datetime.datetime | None | Unset = UNSET
+    updated_at: datetime.datetime | None | Unset = UNSET
+    depth: float | None | str | Unset = UNSET
+    time: float | None | str | Unset = UNSET
+    qc: float | None | str | Unset = UNSET
+    u2: float | None | str | Unset = UNSET
+    remarks: None | str | Unset = UNSET
     additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)
 
     def to_dict(self) -> dict[str, Any]:
-        method_data_id: Union[None, Unset, str]
+        method_data_id: None | str | Unset
         if isinstance(self.method_data_id, Unset):
             method_data_id = UNSET
         elif isinstance(self.method_data_id, UUID):
@@ -48,7 +51,7 @@ class MethodDTDataCreate:
         else:
             method_data_id = self.method_data_id
 
-        method_id: Union[None, Unset, str]
+        method_id: None | str | Unset
         if isinstance(self.method_id, Unset):
             method_id = UNSET
         elif isinstance(self.method_id, UUID):
@@ -58,7 +61,7 @@ class MethodDTDataCreate:
 
         method_type_id = self.method_type_id
 
-        created_at: Union[None, Unset, str]
+        created_at: None | str | Unset
         if isinstance(self.created_at, Unset):
             created_at = UNSET
         elif isinstance(self.created_at, datetime.datetime):
@@ -66,7 +69,7 @@ class MethodDTDataCreate:
         else:
             created_at = self.created_at
 
-        updated_at: Union[None, Unset, str]
+        updated_at: None | str | Unset
         if isinstance(self.updated_at, Unset):
             updated_at = UNSET
         elif isinstance(self.updated_at, datetime.datetime):
@@ -74,31 +77,31 @@ class MethodDTDataCreate:
         else:
             updated_at = self.updated_at
 
-        depth: Union[None, Unset, float, str]
+        depth: float | None | str | Unset
         if isinstance(self.depth, Unset):
             depth = UNSET
         else:
             depth = self.depth
 
-        time: Union[None, Unset, float, str]
+        time: float | None | str | Unset
         if isinstance(self.time, Unset):
             time = UNSET
         else:
             time = self.time
 
-        qc: Union[None, Unset, float, str]
+        qc: float | None | str | Unset
         if isinstance(self.qc, Unset):
             qc = UNSET
         else:
             qc = self.qc
 
-        u2: Union[None, Unset, float, str]
+        u2: float | None | str | Unset
         if isinstance(self.u2, Unset):
             u2 = UNSET
         else:
             u2 = self.u2
 
-        remarks: Union[None, Unset, str]
+        remarks: None | str | Unset
         if isinstance(self.remarks, Unset):
             remarks = UNSET
         else:
@@ -131,10 +134,10 @@ class MethodDTDataCreate:
         return field_dict
 
     @classmethod
-    def from_dict(cls: type[T], src_dict: dict[str, Any]) -> T:
-        d = src_dict.copy()
+    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
+        d = dict(src_dict)
 
-        def _parse_method_data_id(data: object) -> Union[None, UUID, Unset]:
+        def _parse_method_data_id(data: object) -> None | Unset | UUID:
             if data is None:
                 return data
             if isinstance(data, Unset):
@@ -145,13 +148,13 @@ class MethodDTDataCreate:
                 method_data_id_type_0 = UUID(data)
 
                 return method_data_id_type_0
-            except:  # noqa: E722
+            except (TypeError, ValueError, AttributeError, KeyError):
                 pass
-            return cast(Union[None, UUID, Unset], data)
+            return cast(None | Unset | UUID, data)
 
         method_data_id = _parse_method_data_id(d.pop("method_data_id", UNSET))
 
-        def _parse_method_id(data: object) -> Union[None, UUID, Unset]:
+        def _parse_method_id(data: object) -> None | Unset | UUID:
             if data is None:
                 return data
             if isinstance(data, Unset):
@@ -162,17 +165,17 @@ class MethodDTDataCreate:
                 method_id_type_0 = UUID(data)
 
                 return method_id_type_0
-            except:  # noqa: E722
+            except (TypeError, ValueError, AttributeError, KeyError):
                 pass
-            return cast(Union[None, UUID, Unset], data)
+            return cast(None | Unset | UUID, data)
 
         method_id = _parse_method_id(d.pop("method_id", UNSET))
 
-        method_type_id = cast(Union[Literal[22], Unset], d.pop("method_type_id", UNSET))
+        method_type_id = cast(Literal[22] | Unset, d.pop("method_type_id", UNSET))
         if method_type_id != 22 and not isinstance(method_type_id, Unset):
             raise ValueError(f"method_type_id must match const 22, got '{method_type_id}'")
 
-        def _parse_created_at(data: object) -> Union[None, Unset, datetime.datetime]:
+        def _parse_created_at(data: object) -> datetime.datetime | None | Unset:
             if data is None:
                 return data
             if isinstance(data, Unset):
@@ -183,13 +186,13 @@ class MethodDTDataCreate:
                 created_at_type_0 = isoparse(data)
 
                 return created_at_type_0
-            except:  # noqa: E722
+            except (TypeError, ValueError, AttributeError, KeyError):
                 pass
-            return cast(Union[None, Unset, datetime.datetime], data)
+            return cast(datetime.datetime | None | Unset, data)
 
         created_at = _parse_created_at(d.pop("created_at", UNSET))
 
-        def _parse_updated_at(data: object) -> Union[None, Unset, datetime.datetime]:
+        def _parse_updated_at(data: object) -> datetime.datetime | None | Unset:
             if data is None:
                 return data
             if isinstance(data, Unset):
@@ -200,54 +203,54 @@ class MethodDTDataCreate:
                 updated_at_type_0 = isoparse(data)
 
                 return updated_at_type_0
-            except:  # noqa: E722
+            except (TypeError, ValueError, AttributeError, KeyError):
                 pass
-            return cast(Union[None, Unset, datetime.datetime], data)
+            return cast(datetime.datetime | None | Unset, data)
 
         updated_at = _parse_updated_at(d.pop("updated_at", UNSET))
 
-        def _parse_depth(data: object) -> Union[None, Unset, float, str]:
+        def _parse_depth(data: object) -> float | None | str | Unset:
             if data is None:
                 return data
             if isinstance(data, Unset):
                 return data
-            return cast(Union[None, Unset, float, str], data)
+            return cast(float | None | str | Unset, data)
 
         depth = _parse_depth(d.pop("depth", UNSET))
 
-        def _parse_time(data: object) -> Union[None, Unset, float, str]:
+        def _parse_time(data: object) -> float | None | str | Unset:
             if data is None:
                 return data
             if isinstance(data, Unset):
                 return data
-            return cast(Union[None, Unset, float, str], data)
+            return cast(float | None | str | Unset, data)
 
         time = _parse_time(d.pop("time", UNSET))
 
-        def _parse_qc(data: object) -> Union[None, Unset, float, str]:
+        def _parse_qc(data: object) -> float | None | str | Unset:
             if data is None:
                 return data
             if isinstance(data, Unset):
                 return data
-            return cast(Union[None, Unset, float, str], data)
+            return cast(float | None | str | Unset, data)
 
         qc = _parse_qc(d.pop("qc", UNSET))
 
-        def _parse_u2(data: object) -> Union[None, Unset, float, str]:
+        def _parse_u2(data: object) -> float | None | str | Unset:
             if data is None:
                 return data
             if isinstance(data, Unset):
                 return data
-            return cast(Union[None, Unset, float, str], data)
+            return cast(float | None | str | Unset, data)
 
         u2 = _parse_u2(d.pop("u2", UNSET))
 
-        def _parse_remarks(data: object) -> Union[None, Unset, str]:
+        def _parse_remarks(data: object) -> None | str | Unset:
             if data is None:
                 return data
             if isinstance(data, Unset):
                 return data
-            return cast(Union[None, Unset, str], data)
+            return cast(None | str | Unset, data)
 
         remarks = _parse_remarks(d.pop("remarks", UNSET))
 
