@@ -448,7 +448,7 @@ class MethodPZ:
                 conducted_at_type_0 = isoparse(data)
 
                 return conducted_at_type_0
-            except:  # noqa: E722
+            except (TypeError, ValueError, AttributeError, KeyError):
                 pass
             return cast(datetime.datetime | None | Unset, data)
 
@@ -463,12 +463,14 @@ class MethodPZ:
 
         conducted_by = _parse_conducted_by(d.pop("conducted_by", UNSET))
 
-        files = []
         _files = d.pop("files", UNSET)
-        for files_item_data in _files or []:
-            files_item = File.from_dict(files_item_data)
+        files: list[File] | Unset = UNSET
+        if _files is not UNSET:
+            files = []
+            for files_item_data in _files:
+                files_item = File.from_dict(files_item_data)
 
-            files.append(files_item)
+                files.append(files_item)
 
         def _parse_self_(data: object) -> None | str | Unset:
             if data is None:
@@ -517,7 +519,7 @@ class MethodPZ:
                 model_id_type_0 = UUID(data)
 
                 return model_id_type_0
-            except:  # noqa: E722
+            except (TypeError, ValueError, AttributeError, KeyError):
                 pass
             return cast(None | Unset | UUID, data)
 
@@ -644,7 +646,7 @@ class MethodPZ:
                 missing_variables_pore_pressure_type_0 = cast(list[str], data)
 
                 return missing_variables_pore_pressure_type_0
-            except:  # noqa: E722
+            except (TypeError, ValueError, AttributeError, KeyError):
                 pass
             return cast(list[str] | None | Unset, data)
 
@@ -663,7 +665,7 @@ class MethodPZ:
                 missing_variables_piezometric_head_type_0 = cast(list[str], data)
 
                 return missing_variables_piezometric_head_type_0
-            except:  # noqa: E722
+            except (TypeError, ValueError, AttributeError, KeyError):
                 pass
             return cast(list[str] | None | Unset, data)
 
@@ -682,7 +684,7 @@ class MethodPZ:
                 missing_variables_piezometric_potential_type_0 = cast(list[str], data)
 
                 return missing_variables_piezometric_potential_type_0
-            except:  # noqa: E722
+            except (TypeError, ValueError, AttributeError, KeyError):
                 pass
             return cast(list[str] | None | Unset, data)
 
