@@ -1,5 +1,8 @@
+from __future__ import annotations
+
 import datetime
-from typing import Any, Literal, TypeVar, Union, cast
+from collections.abc import Mapping
+from typing import Any, Literal, TypeVar, cast
 from uuid import UUID
 
 from attrs import define as _attrs_define
@@ -17,35 +20,35 @@ class MethodPZDataCreate:
     """
     Attributes:
         reading_type (ReadingType):
-        method_data_id (Union[None, UUID, Unset]):
-        method_id (Union[None, UUID, Unset]):
-        method_type_id (Union[Literal[5], Unset]):  Default: 5.
-        created_at (Union[None, Unset, datetime.datetime]):
-        updated_at (Union[None, Unset, datetime.datetime]):
-        date (Union[None, Unset, datetime.datetime]):
-        pore_pressure (Union[None, Unset, float, str]):
-        barometric_pressure (Union[None, Unset, float, str]):
-        temperature (Union[None, Unset, float, str]):
-        remarks (Union[None, Unset, str]):
+        method_data_id (None | Unset | UUID):
+        method_id (None | Unset | UUID):
+        method_type_id (Literal[5] | Unset):  Default: 5.
+        created_at (datetime.datetime | None | Unset):
+        updated_at (datetime.datetime | None | Unset):
+        date (datetime.datetime | None | Unset):
+        pore_pressure (float | None | str | Unset):
+        barometric_pressure (float | None | str | Unset):
+        temperature (float | None | str | Unset):
+        remarks (None | str | Unset):
     """
 
     reading_type: ReadingType
-    method_data_id: Union[None, UUID, Unset] = UNSET
-    method_id: Union[None, UUID, Unset] = UNSET
-    method_type_id: Union[Literal[5], Unset] = 5
-    created_at: Union[None, Unset, datetime.datetime] = UNSET
-    updated_at: Union[None, Unset, datetime.datetime] = UNSET
-    date: Union[None, Unset, datetime.datetime] = UNSET
-    pore_pressure: Union[None, Unset, float, str] = UNSET
-    barometric_pressure: Union[None, Unset, float, str] = UNSET
-    temperature: Union[None, Unset, float, str] = UNSET
-    remarks: Union[None, Unset, str] = UNSET
+    method_data_id: None | Unset | UUID = UNSET
+    method_id: None | Unset | UUID = UNSET
+    method_type_id: Literal[5] | Unset = 5
+    created_at: datetime.datetime | None | Unset = UNSET
+    updated_at: datetime.datetime | None | Unset = UNSET
+    date: datetime.datetime | None | Unset = UNSET
+    pore_pressure: float | None | str | Unset = UNSET
+    barometric_pressure: float | None | str | Unset = UNSET
+    temperature: float | None | str | Unset = UNSET
+    remarks: None | str | Unset = UNSET
     additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)
 
     def to_dict(self) -> dict[str, Any]:
         reading_type = self.reading_type.value
 
-        method_data_id: Union[None, Unset, str]
+        method_data_id: None | str | Unset
         if isinstance(self.method_data_id, Unset):
             method_data_id = UNSET
         elif isinstance(self.method_data_id, UUID):
@@ -53,7 +56,7 @@ class MethodPZDataCreate:
         else:
             method_data_id = self.method_data_id
 
-        method_id: Union[None, Unset, str]
+        method_id: None | str | Unset
         if isinstance(self.method_id, Unset):
             method_id = UNSET
         elif isinstance(self.method_id, UUID):
@@ -63,7 +66,7 @@ class MethodPZDataCreate:
 
         method_type_id = self.method_type_id
 
-        created_at: Union[None, Unset, str]
+        created_at: None | str | Unset
         if isinstance(self.created_at, Unset):
             created_at = UNSET
         elif isinstance(self.created_at, datetime.datetime):
@@ -71,7 +74,7 @@ class MethodPZDataCreate:
         else:
             created_at = self.created_at
 
-        updated_at: Union[None, Unset, str]
+        updated_at: None | str | Unset
         if isinstance(self.updated_at, Unset):
             updated_at = UNSET
         elif isinstance(self.updated_at, datetime.datetime):
@@ -79,7 +82,7 @@ class MethodPZDataCreate:
         else:
             updated_at = self.updated_at
 
-        date: Union[None, Unset, str]
+        date: None | str | Unset
         if isinstance(self.date, Unset):
             date = UNSET
         elif isinstance(self.date, datetime.datetime):
@@ -87,25 +90,25 @@ class MethodPZDataCreate:
         else:
             date = self.date
 
-        pore_pressure: Union[None, Unset, float, str]
+        pore_pressure: float | None | str | Unset
         if isinstance(self.pore_pressure, Unset):
             pore_pressure = UNSET
         else:
             pore_pressure = self.pore_pressure
 
-        barometric_pressure: Union[None, Unset, float, str]
+        barometric_pressure: float | None | str | Unset
         if isinstance(self.barometric_pressure, Unset):
             barometric_pressure = UNSET
         else:
             barometric_pressure = self.barometric_pressure
 
-        temperature: Union[None, Unset, float, str]
+        temperature: float | None | str | Unset
         if isinstance(self.temperature, Unset):
             temperature = UNSET
         else:
             temperature = self.temperature
 
-        remarks: Union[None, Unset, str]
+        remarks: None | str | Unset
         if isinstance(self.remarks, Unset):
             remarks = UNSET
         else:
@@ -142,11 +145,11 @@ class MethodPZDataCreate:
         return field_dict
 
     @classmethod
-    def from_dict(cls: type[T], src_dict: dict[str, Any]) -> T:
-        d = src_dict.copy()
+    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
+        d = dict(src_dict)
         reading_type = ReadingType(d.pop("reading_type"))
 
-        def _parse_method_data_id(data: object) -> Union[None, UUID, Unset]:
+        def _parse_method_data_id(data: object) -> None | Unset | UUID:
             if data is None:
                 return data
             if isinstance(data, Unset):
@@ -157,13 +160,13 @@ class MethodPZDataCreate:
                 method_data_id_type_0 = UUID(data)
 
                 return method_data_id_type_0
-            except:  # noqa: E722
+            except (TypeError, ValueError, AttributeError, KeyError):
                 pass
-            return cast(Union[None, UUID, Unset], data)
+            return cast(None | Unset | UUID, data)
 
         method_data_id = _parse_method_data_id(d.pop("method_data_id", UNSET))
 
-        def _parse_method_id(data: object) -> Union[None, UUID, Unset]:
+        def _parse_method_id(data: object) -> None | Unset | UUID:
             if data is None:
                 return data
             if isinstance(data, Unset):
@@ -174,17 +177,17 @@ class MethodPZDataCreate:
                 method_id_type_0 = UUID(data)
 
                 return method_id_type_0
-            except:  # noqa: E722
+            except (TypeError, ValueError, AttributeError, KeyError):
                 pass
-            return cast(Union[None, UUID, Unset], data)
+            return cast(None | Unset | UUID, data)
 
         method_id = _parse_method_id(d.pop("method_id", UNSET))
 
-        method_type_id = cast(Union[Literal[5], Unset], d.pop("method_type_id", UNSET))
+        method_type_id = cast(Literal[5] | Unset, d.pop("method_type_id", UNSET))
         if method_type_id != 5 and not isinstance(method_type_id, Unset):
             raise ValueError(f"method_type_id must match const 5, got '{method_type_id}'")
 
-        def _parse_created_at(data: object) -> Union[None, Unset, datetime.datetime]:
+        def _parse_created_at(data: object) -> datetime.datetime | None | Unset:
             if data is None:
                 return data
             if isinstance(data, Unset):
@@ -195,13 +198,13 @@ class MethodPZDataCreate:
                 created_at_type_0 = isoparse(data)
 
                 return created_at_type_0
-            except:  # noqa: E722
+            except (TypeError, ValueError, AttributeError, KeyError):
                 pass
-            return cast(Union[None, Unset, datetime.datetime], data)
+            return cast(datetime.datetime | None | Unset, data)
 
         created_at = _parse_created_at(d.pop("created_at", UNSET))
 
-        def _parse_updated_at(data: object) -> Union[None, Unset, datetime.datetime]:
+        def _parse_updated_at(data: object) -> datetime.datetime | None | Unset:
             if data is None:
                 return data
             if isinstance(data, Unset):
@@ -212,13 +215,13 @@ class MethodPZDataCreate:
                 updated_at_type_0 = isoparse(data)
 
                 return updated_at_type_0
-            except:  # noqa: E722
+            except (TypeError, ValueError, AttributeError, KeyError):
                 pass
-            return cast(Union[None, Unset, datetime.datetime], data)
+            return cast(datetime.datetime | None | Unset, data)
 
         updated_at = _parse_updated_at(d.pop("updated_at", UNSET))
 
-        def _parse_date(data: object) -> Union[None, Unset, datetime.datetime]:
+        def _parse_date(data: object) -> datetime.datetime | None | Unset:
             if data is None:
                 return data
             if isinstance(data, Unset):
@@ -229,45 +232,45 @@ class MethodPZDataCreate:
                 date_type_0 = isoparse(data)
 
                 return date_type_0
-            except:  # noqa: E722
+            except (TypeError, ValueError, AttributeError, KeyError):
                 pass
-            return cast(Union[None, Unset, datetime.datetime], data)
+            return cast(datetime.datetime | None | Unset, data)
 
         date = _parse_date(d.pop("date", UNSET))
 
-        def _parse_pore_pressure(data: object) -> Union[None, Unset, float, str]:
+        def _parse_pore_pressure(data: object) -> float | None | str | Unset:
             if data is None:
                 return data
             if isinstance(data, Unset):
                 return data
-            return cast(Union[None, Unset, float, str], data)
+            return cast(float | None | str | Unset, data)
 
         pore_pressure = _parse_pore_pressure(d.pop("pore_pressure", UNSET))
 
-        def _parse_barometric_pressure(data: object) -> Union[None, Unset, float, str]:
+        def _parse_barometric_pressure(data: object) -> float | None | str | Unset:
             if data is None:
                 return data
             if isinstance(data, Unset):
                 return data
-            return cast(Union[None, Unset, float, str], data)
+            return cast(float | None | str | Unset, data)
 
         barometric_pressure = _parse_barometric_pressure(d.pop("barometric_pressure", UNSET))
 
-        def _parse_temperature(data: object) -> Union[None, Unset, float, str]:
+        def _parse_temperature(data: object) -> float | None | str | Unset:
             if data is None:
                 return data
             if isinstance(data, Unset):
                 return data
-            return cast(Union[None, Unset, float, str], data)
+            return cast(float | None | str | Unset, data)
 
         temperature = _parse_temperature(d.pop("temperature", UNSET))
 
-        def _parse_remarks(data: object) -> Union[None, Unset, str]:
+        def _parse_remarks(data: object) -> None | str | Unset:
             if data is None:
                 return data
             if isinstance(data, Unset):
                 return data
-            return cast(Union[None, Unset, str], data)
+            return cast(None | str | Unset, data)
 
         remarks = _parse_remarks(d.pop("remarks", UNSET))
 
