@@ -1,5 +1,8 @@
+from __future__ import annotations
+
 import datetime
-from typing import Any, Literal, TypeVar, Union, cast
+from collections.abc import Mapping
+from typing import Any, Literal, TypeVar, cast
 from uuid import UUID
 
 from attrs import define as _attrs_define
@@ -15,33 +18,33 @@ T = TypeVar("T", bound="MethodRCDDataCreate")
 class MethodRCDDataCreate:
     """
     Attributes:
-        depth (Union[float, str]): Depth (m). SGF code D.
-        method_data_id (Union[None, UUID, Unset]):
-        method_id (Union[None, UUID, Unset]):
-        method_type_id (Union[Literal[8], Unset]):  Default: 8.
-        created_at (Union[None, Unset, datetime.datetime]):
-        updated_at (Union[None, Unset, datetime.datetime]):
-        penetration_rate (Union[None, Unset, float, str]):
-        comment_code (Union[None, Unset, int]):
-        remarks (Union[None, Unset, str]):
+        depth (float | str): Depth (m). SGF code D.
+        method_data_id (None | Unset | UUID):
+        method_id (None | Unset | UUID):
+        method_type_id (Literal[8] | Unset):  Default: 8.
+        created_at (datetime.datetime | None | Unset):
+        updated_at (datetime.datetime | None | Unset):
+        penetration_rate (float | None | str | Unset):
+        comment_code (int | None | Unset):
+        remarks (None | str | Unset):
     """
 
-    depth: Union[float, str]
-    method_data_id: Union[None, UUID, Unset] = UNSET
-    method_id: Union[None, UUID, Unset] = UNSET
-    method_type_id: Union[Literal[8], Unset] = 8
-    created_at: Union[None, Unset, datetime.datetime] = UNSET
-    updated_at: Union[None, Unset, datetime.datetime] = UNSET
-    penetration_rate: Union[None, Unset, float, str] = UNSET
-    comment_code: Union[None, Unset, int] = UNSET
-    remarks: Union[None, Unset, str] = UNSET
+    depth: float | str
+    method_data_id: None | Unset | UUID = UNSET
+    method_id: None | Unset | UUID = UNSET
+    method_type_id: Literal[8] | Unset = 8
+    created_at: datetime.datetime | None | Unset = UNSET
+    updated_at: datetime.datetime | None | Unset = UNSET
+    penetration_rate: float | None | str | Unset = UNSET
+    comment_code: int | None | Unset = UNSET
+    remarks: None | str | Unset = UNSET
     additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)
 
     def to_dict(self) -> dict[str, Any]:
-        depth: Union[float, str]
+        depth: float | str
         depth = self.depth
 
-        method_data_id: Union[None, Unset, str]
+        method_data_id: None | str | Unset
         if isinstance(self.method_data_id, Unset):
             method_data_id = UNSET
         elif isinstance(self.method_data_id, UUID):
@@ -49,7 +52,7 @@ class MethodRCDDataCreate:
         else:
             method_data_id = self.method_data_id
 
-        method_id: Union[None, Unset, str]
+        method_id: None | str | Unset
         if isinstance(self.method_id, Unset):
             method_id = UNSET
         elif isinstance(self.method_id, UUID):
@@ -59,7 +62,7 @@ class MethodRCDDataCreate:
 
         method_type_id = self.method_type_id
 
-        created_at: Union[None, Unset, str]
+        created_at: None | str | Unset
         if isinstance(self.created_at, Unset):
             created_at = UNSET
         elif isinstance(self.created_at, datetime.datetime):
@@ -67,7 +70,7 @@ class MethodRCDDataCreate:
         else:
             created_at = self.created_at
 
-        updated_at: Union[None, Unset, str]
+        updated_at: None | str | Unset
         if isinstance(self.updated_at, Unset):
             updated_at = UNSET
         elif isinstance(self.updated_at, datetime.datetime):
@@ -75,19 +78,19 @@ class MethodRCDDataCreate:
         else:
             updated_at = self.updated_at
 
-        penetration_rate: Union[None, Unset, float, str]
+        penetration_rate: float | None | str | Unset
         if isinstance(self.penetration_rate, Unset):
             penetration_rate = UNSET
         else:
             penetration_rate = self.penetration_rate
 
-        comment_code: Union[None, Unset, int]
+        comment_code: int | None | Unset
         if isinstance(self.comment_code, Unset):
             comment_code = UNSET
         else:
             comment_code = self.comment_code
 
-        remarks: Union[None, Unset, str]
+        remarks: None | str | Unset
         if isinstance(self.remarks, Unset):
             remarks = UNSET
         else:
@@ -120,15 +123,15 @@ class MethodRCDDataCreate:
         return field_dict
 
     @classmethod
-    def from_dict(cls: type[T], src_dict: dict[str, Any]) -> T:
-        d = src_dict.copy()
+    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
+        d = dict(src_dict)
 
-        def _parse_depth(data: object) -> Union[float, str]:
-            return cast(Union[float, str], data)
+        def _parse_depth(data: object) -> float | str:
+            return cast(float | str, data)
 
         depth = _parse_depth(d.pop("depth"))
 
-        def _parse_method_data_id(data: object) -> Union[None, UUID, Unset]:
+        def _parse_method_data_id(data: object) -> None | Unset | UUID:
             if data is None:
                 return data
             if isinstance(data, Unset):
@@ -139,13 +142,13 @@ class MethodRCDDataCreate:
                 method_data_id_type_0 = UUID(data)
 
                 return method_data_id_type_0
-            except:  # noqa: E722
+            except (TypeError, ValueError, AttributeError, KeyError):
                 pass
-            return cast(Union[None, UUID, Unset], data)
+            return cast(None | Unset | UUID, data)
 
         method_data_id = _parse_method_data_id(d.pop("method_data_id", UNSET))
 
-        def _parse_method_id(data: object) -> Union[None, UUID, Unset]:
+        def _parse_method_id(data: object) -> None | Unset | UUID:
             if data is None:
                 return data
             if isinstance(data, Unset):
@@ -156,17 +159,17 @@ class MethodRCDDataCreate:
                 method_id_type_0 = UUID(data)
 
                 return method_id_type_0
-            except:  # noqa: E722
+            except (TypeError, ValueError, AttributeError, KeyError):
                 pass
-            return cast(Union[None, UUID, Unset], data)
+            return cast(None | Unset | UUID, data)
 
         method_id = _parse_method_id(d.pop("method_id", UNSET))
 
-        method_type_id = cast(Union[Literal[8], Unset], d.pop("method_type_id", UNSET))
+        method_type_id = cast(Literal[8] | Unset, d.pop("method_type_id", UNSET))
         if method_type_id != 8 and not isinstance(method_type_id, Unset):
             raise ValueError(f"method_type_id must match const 8, got '{method_type_id}'")
 
-        def _parse_created_at(data: object) -> Union[None, Unset, datetime.datetime]:
+        def _parse_created_at(data: object) -> datetime.datetime | None | Unset:
             if data is None:
                 return data
             if isinstance(data, Unset):
@@ -177,13 +180,13 @@ class MethodRCDDataCreate:
                 created_at_type_0 = isoparse(data)
 
                 return created_at_type_0
-            except:  # noqa: E722
+            except (TypeError, ValueError, AttributeError, KeyError):
                 pass
-            return cast(Union[None, Unset, datetime.datetime], data)
+            return cast(datetime.datetime | None | Unset, data)
 
         created_at = _parse_created_at(d.pop("created_at", UNSET))
 
-        def _parse_updated_at(data: object) -> Union[None, Unset, datetime.datetime]:
+        def _parse_updated_at(data: object) -> datetime.datetime | None | Unset:
             if data is None:
                 return data
             if isinstance(data, Unset):
@@ -194,36 +197,36 @@ class MethodRCDDataCreate:
                 updated_at_type_0 = isoparse(data)
 
                 return updated_at_type_0
-            except:  # noqa: E722
+            except (TypeError, ValueError, AttributeError, KeyError):
                 pass
-            return cast(Union[None, Unset, datetime.datetime], data)
+            return cast(datetime.datetime | None | Unset, data)
 
         updated_at = _parse_updated_at(d.pop("updated_at", UNSET))
 
-        def _parse_penetration_rate(data: object) -> Union[None, Unset, float, str]:
+        def _parse_penetration_rate(data: object) -> float | None | str | Unset:
             if data is None:
                 return data
             if isinstance(data, Unset):
                 return data
-            return cast(Union[None, Unset, float, str], data)
+            return cast(float | None | str | Unset, data)
 
         penetration_rate = _parse_penetration_rate(d.pop("penetration_rate", UNSET))
 
-        def _parse_comment_code(data: object) -> Union[None, Unset, int]:
+        def _parse_comment_code(data: object) -> int | None | Unset:
             if data is None:
                 return data
             if isinstance(data, Unset):
                 return data
-            return cast(Union[None, Unset, int], data)
+            return cast(int | None | Unset, data)
 
         comment_code = _parse_comment_code(d.pop("comment_code", UNSET))
 
-        def _parse_remarks(data: object) -> Union[None, Unset, str]:
+        def _parse_remarks(data: object) -> None | str | Unset:
             if data is None:
                 return data
             if isinstance(data, Unset):
                 return data
-            return cast(Union[None, Unset, str], data)
+            return cast(None | str | Unset, data)
 
         remarks = _parse_remarks(d.pop("remarks", UNSET))
 
