@@ -1,4 +1,7 @@
-from typing import Any, Literal, TypeVar, Union, cast
+from __future__ import annotations
+
+from collections.abc import Mapping
+from typing import Any, Literal, TypeVar, cast
 
 from attrs import define as _attrs_define
 from attrs import field as _attrs_field
@@ -13,26 +16,26 @@ class MethodRPDataUpdate:
     """Method RP data update structure
 
     Attributes:
-        method_type_id (Union[Literal[3], Unset]):  Default: 3.
-        comment_code (Union[None, Unset, int]):
-        remarks (Union[None, Unset, str]):
+        method_type_id (Literal[3] | Unset):  Default: 3.
+        comment_code (int | None | Unset):
+        remarks (None | str | Unset):
     """
 
-    method_type_id: Union[Literal[3], Unset] = 3
-    comment_code: Union[None, Unset, int] = UNSET
-    remarks: Union[None, Unset, str] = UNSET
+    method_type_id: Literal[3] | Unset = 3
+    comment_code: int | None | Unset = UNSET
+    remarks: None | str | Unset = UNSET
     additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)
 
     def to_dict(self) -> dict[str, Any]:
         method_type_id = self.method_type_id
 
-        comment_code: Union[None, Unset, int]
+        comment_code: int | None | Unset
         if isinstance(self.comment_code, Unset):
             comment_code = UNSET
         else:
             comment_code = self.comment_code
 
-        remarks: Union[None, Unset, str]
+        remarks: None | str | Unset
         if isinstance(self.remarks, Unset):
             remarks = UNSET
         else:
@@ -51,27 +54,27 @@ class MethodRPDataUpdate:
         return field_dict
 
     @classmethod
-    def from_dict(cls: type[T], src_dict: dict[str, Any]) -> T:
-        d = src_dict.copy()
-        method_type_id = cast(Union[Literal[3], Unset], d.pop("method_type_id", UNSET))
+    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
+        d = dict(src_dict)
+        method_type_id = cast(Literal[3] | Unset, d.pop("method_type_id", UNSET))
         if method_type_id != 3 and not isinstance(method_type_id, Unset):
             raise ValueError(f"method_type_id must match const 3, got '{method_type_id}'")
 
-        def _parse_comment_code(data: object) -> Union[None, Unset, int]:
+        def _parse_comment_code(data: object) -> int | None | Unset:
             if data is None:
                 return data
             if isinstance(data, Unset):
                 return data
-            return cast(Union[None, Unset, int], data)
+            return cast(int | None | Unset, data)
 
         comment_code = _parse_comment_code(d.pop("comment_code", UNSET))
 
-        def _parse_remarks(data: object) -> Union[None, Unset, str]:
+        def _parse_remarks(data: object) -> None | str | Unset:
             if data is None:
                 return data
             if isinstance(data, Unset):
                 return data
-            return cast(Union[None, Unset, str], data)
+            return cast(None | str | Unset, data)
 
         remarks = _parse_remarks(d.pop("remarks", UNSET))
 
