@@ -1,6 +1,8 @@
+from __future__ import annotations
+
 import datetime
 from collections.abc import Mapping
-from typing import TYPE_CHECKING, Any, Literal, TypeVar, Union, cast
+from typing import TYPE_CHECKING, Any, Literal, TypeVar, cast
 from uuid import UUID
 
 from attrs import define as _attrs_define
@@ -36,24 +38,24 @@ class MethodSRS:
                 )
             created_at (datetime.datetime):
             updated_at (datetime.datetime):
-            remarks (Union[None, Unset, str]):
-            method_type_id (Union[Literal[24], Unset]):  Default: 24.
-            created_by (Union[None, Unset, str]):
-            updated_by (Union[None, Unset, str]):
-            conducted_at (Union[None, Unset, datetime.datetime]):
-            conducted_by (Union[None, Unset, str]):
-            files (Union[Unset, list['File']]):
-            self_ (Union[None, Unset, str]):
-            sounding_class (Union[None, SoundingClass, Unset]):
-            serial_number (Union[None, Unset, str]):
-            calibration_date (Union[None, Unset, datetime.datetime]):
-            conversion_factor (Union[None, Unset, float]):
-            depth_top (Union[None, Unset, float]):
-            depth_base (Union[None, Unset, float]):
-            stopcode (Union[None, Unset, int]):
-            depth_in_soil (Union[None, Unset, float]):
-            depth_in_rock (Union[None, Unset, float]):
-            bedrock_elevation (Union[None, Unset, float]):
+            remarks (None | str | Unset):
+            method_type_id (Literal[24] | Unset):  Default: 24.
+            created_by (None | str | Unset):
+            updated_by (None | str | Unset):
+            conducted_at (datetime.datetime | None | Unset):
+            conducted_by (None | str | Unset):
+            files (list[File] | Unset):
+            self_ (None | str | Unset):
+            sounding_class (None | SoundingClass | Unset):
+            serial_number (None | str | Unset):
+            calibration_date (datetime.datetime | None | Unset):
+            conversion_factor (float | None | Unset):
+            depth_top (float | None | Unset):
+            depth_base (float | None | Unset):
+            stopcode (int | None | Unset):
+            depth_in_soil (float | None | Unset):
+            depth_in_rock (float | None | Unset):
+            bedrock_elevation (float | None | Unset):
     """
 
     method_id: UUID
@@ -62,24 +64,24 @@ class MethodSRS:
     method_status_id: MethodStatusEnum
     created_at: datetime.datetime
     updated_at: datetime.datetime
-    remarks: Union[None, Unset, str] = UNSET
-    method_type_id: Union[Literal[24], Unset] = 24
-    created_by: Union[None, Unset, str] = UNSET
-    updated_by: Union[None, Unset, str] = UNSET
-    conducted_at: Union[None, Unset, datetime.datetime] = UNSET
-    conducted_by: Union[None, Unset, str] = UNSET
-    files: Union[Unset, list["File"]] = UNSET
-    self_: Union[None, Unset, str] = UNSET
-    sounding_class: Union[None, SoundingClass, Unset] = UNSET
-    serial_number: Union[None, Unset, str] = UNSET
-    calibration_date: Union[None, Unset, datetime.datetime] = UNSET
-    conversion_factor: Union[None, Unset, float] = UNSET
-    depth_top: Union[None, Unset, float] = UNSET
-    depth_base: Union[None, Unset, float] = UNSET
-    stopcode: Union[None, Unset, int] = UNSET
-    depth_in_soil: Union[None, Unset, float] = UNSET
-    depth_in_rock: Union[None, Unset, float] = UNSET
-    bedrock_elevation: Union[None, Unset, float] = UNSET
+    remarks: None | str | Unset = UNSET
+    method_type_id: Literal[24] | Unset = 24
+    created_by: None | str | Unset = UNSET
+    updated_by: None | str | Unset = UNSET
+    conducted_at: datetime.datetime | None | Unset = UNSET
+    conducted_by: None | str | Unset = UNSET
+    files: list[File] | Unset = UNSET
+    self_: None | str | Unset = UNSET
+    sounding_class: None | SoundingClass | Unset = UNSET
+    serial_number: None | str | Unset = UNSET
+    calibration_date: datetime.datetime | None | Unset = UNSET
+    conversion_factor: float | None | Unset = UNSET
+    depth_top: float | None | Unset = UNSET
+    depth_base: float | None | Unset = UNSET
+    stopcode: int | None | Unset = UNSET
+    depth_in_soil: float | None | Unset = UNSET
+    depth_in_rock: float | None | Unset = UNSET
+    bedrock_elevation: float | None | Unset = UNSET
     additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)
 
     def to_dict(self) -> dict[str, Any]:
@@ -95,7 +97,7 @@ class MethodSRS:
 
         updated_at = self.updated_at.isoformat()
 
-        remarks: Union[None, Unset, str]
+        remarks: None | str | Unset
         if isinstance(self.remarks, Unset):
             remarks = UNSET
         else:
@@ -103,19 +105,19 @@ class MethodSRS:
 
         method_type_id = self.method_type_id
 
-        created_by: Union[None, Unset, str]
+        created_by: None | str | Unset
         if isinstance(self.created_by, Unset):
             created_by = UNSET
         else:
             created_by = self.created_by
 
-        updated_by: Union[None, Unset, str]
+        updated_by: None | str | Unset
         if isinstance(self.updated_by, Unset):
             updated_by = UNSET
         else:
             updated_by = self.updated_by
 
-        conducted_at: Union[None, Unset, str]
+        conducted_at: None | str | Unset
         if isinstance(self.conducted_at, Unset):
             conducted_at = UNSET
         elif isinstance(self.conducted_at, datetime.datetime):
@@ -123,26 +125,26 @@ class MethodSRS:
         else:
             conducted_at = self.conducted_at
 
-        conducted_by: Union[None, Unset, str]
+        conducted_by: None | str | Unset
         if isinstance(self.conducted_by, Unset):
             conducted_by = UNSET
         else:
             conducted_by = self.conducted_by
 
-        files: Union[Unset, list[dict[str, Any]]] = UNSET
+        files: list[dict[str, Any]] | Unset = UNSET
         if not isinstance(self.files, Unset):
             files = []
             for files_item_data in self.files:
                 files_item = files_item_data.to_dict()
                 files.append(files_item)
 
-        self_: Union[None, Unset, str]
+        self_: None | str | Unset
         if isinstance(self.self_, Unset):
             self_ = UNSET
         else:
             self_ = self.self_
 
-        sounding_class: Union[None, Unset, str]
+        sounding_class: None | str | Unset
         if isinstance(self.sounding_class, Unset):
             sounding_class = UNSET
         elif isinstance(self.sounding_class, SoundingClass):
@@ -150,13 +152,13 @@ class MethodSRS:
         else:
             sounding_class = self.sounding_class
 
-        serial_number: Union[None, Unset, str]
+        serial_number: None | str | Unset
         if isinstance(self.serial_number, Unset):
             serial_number = UNSET
         else:
             serial_number = self.serial_number
 
-        calibration_date: Union[None, Unset, str]
+        calibration_date: None | str | Unset
         if isinstance(self.calibration_date, Unset):
             calibration_date = UNSET
         elif isinstance(self.calibration_date, datetime.datetime):
@@ -164,43 +166,43 @@ class MethodSRS:
         else:
             calibration_date = self.calibration_date
 
-        conversion_factor: Union[None, Unset, float]
+        conversion_factor: float | None | Unset
         if isinstance(self.conversion_factor, Unset):
             conversion_factor = UNSET
         else:
             conversion_factor = self.conversion_factor
 
-        depth_top: Union[None, Unset, float]
+        depth_top: float | None | Unset
         if isinstance(self.depth_top, Unset):
             depth_top = UNSET
         else:
             depth_top = self.depth_top
 
-        depth_base: Union[None, Unset, float]
+        depth_base: float | None | Unset
         if isinstance(self.depth_base, Unset):
             depth_base = UNSET
         else:
             depth_base = self.depth_base
 
-        stopcode: Union[None, Unset, int]
+        stopcode: int | None | Unset
         if isinstance(self.stopcode, Unset):
             stopcode = UNSET
         else:
             stopcode = self.stopcode
 
-        depth_in_soil: Union[None, Unset, float]
+        depth_in_soil: float | None | Unset
         if isinstance(self.depth_in_soil, Unset):
             depth_in_soil = UNSET
         else:
             depth_in_soil = self.depth_in_soil
 
-        depth_in_rock: Union[None, Unset, float]
+        depth_in_rock: float | None | Unset
         if isinstance(self.depth_in_rock, Unset):
             depth_in_rock = UNSET
         else:
             depth_in_rock = self.depth_in_rock
 
-        bedrock_elevation: Union[None, Unset, float]
+        bedrock_elevation: float | None | Unset
         if isinstance(self.bedrock_elevation, Unset):
             bedrock_elevation = UNSET
         else:
@@ -274,38 +276,38 @@ class MethodSRS:
 
         updated_at = isoparse(d.pop("updated_at"))
 
-        def _parse_remarks(data: object) -> Union[None, Unset, str]:
+        def _parse_remarks(data: object) -> None | str | Unset:
             if data is None:
                 return data
             if isinstance(data, Unset):
                 return data
-            return cast(Union[None, Unset, str], data)
+            return cast(None | str | Unset, data)
 
         remarks = _parse_remarks(d.pop("remarks", UNSET))
 
-        method_type_id = cast(Union[Literal[24], Unset], d.pop("method_type_id", UNSET))
+        method_type_id = cast(Literal[24] | Unset, d.pop("method_type_id", UNSET))
         if method_type_id != 24 and not isinstance(method_type_id, Unset):
             raise ValueError(f"method_type_id must match const 24, got '{method_type_id}'")
 
-        def _parse_created_by(data: object) -> Union[None, Unset, str]:
+        def _parse_created_by(data: object) -> None | str | Unset:
             if data is None:
                 return data
             if isinstance(data, Unset):
                 return data
-            return cast(Union[None, Unset, str], data)
+            return cast(None | str | Unset, data)
 
         created_by = _parse_created_by(d.pop("created_by", UNSET))
 
-        def _parse_updated_by(data: object) -> Union[None, Unset, str]:
+        def _parse_updated_by(data: object) -> None | str | Unset:
             if data is None:
                 return data
             if isinstance(data, Unset):
                 return data
-            return cast(Union[None, Unset, str], data)
+            return cast(None | str | Unset, data)
 
         updated_by = _parse_updated_by(d.pop("updated_by", UNSET))
 
-        def _parse_conducted_at(data: object) -> Union[None, Unset, datetime.datetime]:
+        def _parse_conducted_at(data: object) -> datetime.datetime | None | Unset:
             if data is None:
                 return data
             if isinstance(data, Unset):
@@ -316,38 +318,40 @@ class MethodSRS:
                 conducted_at_type_0 = isoparse(data)
 
                 return conducted_at_type_0
-            except:  # noqa: E722
+            except (TypeError, ValueError, AttributeError, KeyError):
                 pass
-            return cast(Union[None, Unset, datetime.datetime], data)
+            return cast(datetime.datetime | None | Unset, data)
 
         conducted_at = _parse_conducted_at(d.pop("conducted_at", UNSET))
 
-        def _parse_conducted_by(data: object) -> Union[None, Unset, str]:
+        def _parse_conducted_by(data: object) -> None | str | Unset:
             if data is None:
                 return data
             if isinstance(data, Unset):
                 return data
-            return cast(Union[None, Unset, str], data)
+            return cast(None | str | Unset, data)
 
         conducted_by = _parse_conducted_by(d.pop("conducted_by", UNSET))
 
-        files = []
         _files = d.pop("files", UNSET)
-        for files_item_data in _files or []:
-            files_item = File.from_dict(files_item_data)
+        files: list[File] | Unset = UNSET
+        if _files is not UNSET:
+            files = []
+            for files_item_data in _files:
+                files_item = File.from_dict(files_item_data)
 
-            files.append(files_item)
+                files.append(files_item)
 
-        def _parse_self_(data: object) -> Union[None, Unset, str]:
+        def _parse_self_(data: object) -> None | str | Unset:
             if data is None:
                 return data
             if isinstance(data, Unset):
                 return data
-            return cast(Union[None, Unset, str], data)
+            return cast(None | str | Unset, data)
 
         self_ = _parse_self_(d.pop("self", UNSET))
 
-        def _parse_sounding_class(data: object) -> Union[None, SoundingClass, Unset]:
+        def _parse_sounding_class(data: object) -> None | SoundingClass | Unset:
             if data is None:
                 return data
             if isinstance(data, Unset):
@@ -358,22 +362,22 @@ class MethodSRS:
                 sounding_class_type_0 = SoundingClass(data)
 
                 return sounding_class_type_0
-            except:  # noqa: E722
+            except (TypeError, ValueError, AttributeError, KeyError):
                 pass
-            return cast(Union[None, SoundingClass, Unset], data)
+            return cast(None | SoundingClass | Unset, data)
 
         sounding_class = _parse_sounding_class(d.pop("sounding_class", UNSET))
 
-        def _parse_serial_number(data: object) -> Union[None, Unset, str]:
+        def _parse_serial_number(data: object) -> None | str | Unset:
             if data is None:
                 return data
             if isinstance(data, Unset):
                 return data
-            return cast(Union[None, Unset, str], data)
+            return cast(None | str | Unset, data)
 
         serial_number = _parse_serial_number(d.pop("serial_number", UNSET))
 
-        def _parse_calibration_date(data: object) -> Union[None, Unset, datetime.datetime]:
+        def _parse_calibration_date(data: object) -> datetime.datetime | None | Unset:
             if data is None:
                 return data
             if isinstance(data, Unset):
@@ -384,72 +388,72 @@ class MethodSRS:
                 calibration_date_type_0 = isoparse(data)
 
                 return calibration_date_type_0
-            except:  # noqa: E722
+            except (TypeError, ValueError, AttributeError, KeyError):
                 pass
-            return cast(Union[None, Unset, datetime.datetime], data)
+            return cast(datetime.datetime | None | Unset, data)
 
         calibration_date = _parse_calibration_date(d.pop("calibration_date", UNSET))
 
-        def _parse_conversion_factor(data: object) -> Union[None, Unset, float]:
+        def _parse_conversion_factor(data: object) -> float | None | Unset:
             if data is None:
                 return data
             if isinstance(data, Unset):
                 return data
-            return cast(Union[None, Unset, float], data)
+            return cast(float | None | Unset, data)
 
         conversion_factor = _parse_conversion_factor(d.pop("conversion_factor", UNSET))
 
-        def _parse_depth_top(data: object) -> Union[None, Unset, float]:
+        def _parse_depth_top(data: object) -> float | None | Unset:
             if data is None:
                 return data
             if isinstance(data, Unset):
                 return data
-            return cast(Union[None, Unset, float], data)
+            return cast(float | None | Unset, data)
 
         depth_top = _parse_depth_top(d.pop("depth_top", UNSET))
 
-        def _parse_depth_base(data: object) -> Union[None, Unset, float]:
+        def _parse_depth_base(data: object) -> float | None | Unset:
             if data is None:
                 return data
             if isinstance(data, Unset):
                 return data
-            return cast(Union[None, Unset, float], data)
+            return cast(float | None | Unset, data)
 
         depth_base = _parse_depth_base(d.pop("depth_base", UNSET))
 
-        def _parse_stopcode(data: object) -> Union[None, Unset, int]:
+        def _parse_stopcode(data: object) -> int | None | Unset:
             if data is None:
                 return data
             if isinstance(data, Unset):
                 return data
-            return cast(Union[None, Unset, int], data)
+            return cast(int | None | Unset, data)
 
         stopcode = _parse_stopcode(d.pop("stopcode", UNSET))
 
-        def _parse_depth_in_soil(data: object) -> Union[None, Unset, float]:
+        def _parse_depth_in_soil(data: object) -> float | None | Unset:
             if data is None:
                 return data
             if isinstance(data, Unset):
                 return data
-            return cast(Union[None, Unset, float], data)
+            return cast(float | None | Unset, data)
 
         depth_in_soil = _parse_depth_in_soil(d.pop("depth_in_soil", UNSET))
 
-        def _parse_depth_in_rock(data: object) -> Union[None, Unset, float]:
+        def _parse_depth_in_rock(data: object) -> float | None | Unset:
             if data is None:
                 return data
             if isinstance(data, Unset):
                 return data
-            return cast(Union[None, Unset, float], data)
+            return cast(float | None | Unset, data)
 
         depth_in_rock = _parse_depth_in_rock(d.pop("depth_in_rock", UNSET))
 
-        def _parse_bedrock_elevation(data: object) -> Union[None, Unset, float]:
+        def _parse_bedrock_elevation(data: object) -> float | None | Unset:
             if data is None:
                 return data
             if isinstance(data, Unset):
                 return data
-            return cast(Union[None, Unset, float], data)
+            return cast(float | None | Unset, data)
 
         bedrock_elevation = _parse_bedrock_elevation(d.pop("bedrock_elevation", UNSET))
 
