@@ -1,5 +1,8 @@
+from __future__ import annotations
+
 import datetime
-from typing import Any, Literal, TypeVar, Union, cast
+from collections.abc import Mapping
+from typing import Any, Literal, TypeVar, cast
 from uuid import UUID
 
 from attrs import define as _attrs_define
@@ -15,39 +18,39 @@ T = TypeVar("T", bound="MethodSVTDataCreate")
 class MethodSVTDataCreate:
     """
     Attributes:
-        depth (Union[float, str]): Depth (m).
-        method_data_id (Union[None, UUID, Unset]):
-        method_id (Union[None, UUID, Unset]):
-        method_type_id (Union[Literal[10], Unset]):  Default: 10.
-        created_at (Union[None, Unset, datetime.datetime]):
-        updated_at (Union[None, Unset, datetime.datetime]):
-        maximum_measurement_torque (Union[None, Unset, float, str]): Maximum measurement torque (Nm).
-        maximum_measurement_torque_remoulded (Union[None, Unset, float, str]): Maximum measurement torque (Nm).
-        shear_strength (Union[None, Unset, float, str]): Shear strength (kPa). SGF code AS.
-        shear_strength_remoulded (Union[None, Unset, float, str]): Shear strength (kPa).
-        sensitivity (Union[None, Unset, float, str]): Sensitivity (unitless). SGF code SV.
-        remarks (Union[None, Unset, str]):
+        depth (float | str): Depth (m).
+        method_data_id (None | Unset | UUID):
+        method_id (None | Unset | UUID):
+        method_type_id (Literal[10] | Unset):  Default: 10.
+        created_at (datetime.datetime | None | Unset):
+        updated_at (datetime.datetime | None | Unset):
+        maximum_measurement_torque (float | None | str | Unset): Maximum measurement torque (Nm).
+        maximum_measurement_torque_remoulded (float | None | str | Unset): Maximum measurement torque (Nm).
+        shear_strength (float | None | str | Unset): Shear strength (kPa). SGF code AS.
+        shear_strength_remoulded (float | None | str | Unset): Shear strength (kPa).
+        sensitivity (float | None | str | Unset): Sensitivity (unitless). SGF code SV.
+        remarks (None | str | Unset):
     """
 
-    depth: Union[float, str]
-    method_data_id: Union[None, UUID, Unset] = UNSET
-    method_id: Union[None, UUID, Unset] = UNSET
-    method_type_id: Union[Literal[10], Unset] = 10
-    created_at: Union[None, Unset, datetime.datetime] = UNSET
-    updated_at: Union[None, Unset, datetime.datetime] = UNSET
-    maximum_measurement_torque: Union[None, Unset, float, str] = UNSET
-    maximum_measurement_torque_remoulded: Union[None, Unset, float, str] = UNSET
-    shear_strength: Union[None, Unset, float, str] = UNSET
-    shear_strength_remoulded: Union[None, Unset, float, str] = UNSET
-    sensitivity: Union[None, Unset, float, str] = UNSET
-    remarks: Union[None, Unset, str] = UNSET
+    depth: float | str
+    method_data_id: None | Unset | UUID = UNSET
+    method_id: None | Unset | UUID = UNSET
+    method_type_id: Literal[10] | Unset = 10
+    created_at: datetime.datetime | None | Unset = UNSET
+    updated_at: datetime.datetime | None | Unset = UNSET
+    maximum_measurement_torque: float | None | str | Unset = UNSET
+    maximum_measurement_torque_remoulded: float | None | str | Unset = UNSET
+    shear_strength: float | None | str | Unset = UNSET
+    shear_strength_remoulded: float | None | str | Unset = UNSET
+    sensitivity: float | None | str | Unset = UNSET
+    remarks: None | str | Unset = UNSET
     additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)
 
     def to_dict(self) -> dict[str, Any]:
-        depth: Union[float, str]
+        depth: float | str
         depth = self.depth
 
-        method_data_id: Union[None, Unset, str]
+        method_data_id: None | str | Unset
         if isinstance(self.method_data_id, Unset):
             method_data_id = UNSET
         elif isinstance(self.method_data_id, UUID):
@@ -55,7 +58,7 @@ class MethodSVTDataCreate:
         else:
             method_data_id = self.method_data_id
 
-        method_id: Union[None, Unset, str]
+        method_id: None | str | Unset
         if isinstance(self.method_id, Unset):
             method_id = UNSET
         elif isinstance(self.method_id, UUID):
@@ -65,7 +68,7 @@ class MethodSVTDataCreate:
 
         method_type_id = self.method_type_id
 
-        created_at: Union[None, Unset, str]
+        created_at: None | str | Unset
         if isinstance(self.created_at, Unset):
             created_at = UNSET
         elif isinstance(self.created_at, datetime.datetime):
@@ -73,7 +76,7 @@ class MethodSVTDataCreate:
         else:
             created_at = self.created_at
 
-        updated_at: Union[None, Unset, str]
+        updated_at: None | str | Unset
         if isinstance(self.updated_at, Unset):
             updated_at = UNSET
         elif isinstance(self.updated_at, datetime.datetime):
@@ -81,37 +84,37 @@ class MethodSVTDataCreate:
         else:
             updated_at = self.updated_at
 
-        maximum_measurement_torque: Union[None, Unset, float, str]
+        maximum_measurement_torque: float | None | str | Unset
         if isinstance(self.maximum_measurement_torque, Unset):
             maximum_measurement_torque = UNSET
         else:
             maximum_measurement_torque = self.maximum_measurement_torque
 
-        maximum_measurement_torque_remoulded: Union[None, Unset, float, str]
+        maximum_measurement_torque_remoulded: float | None | str | Unset
         if isinstance(self.maximum_measurement_torque_remoulded, Unset):
             maximum_measurement_torque_remoulded = UNSET
         else:
             maximum_measurement_torque_remoulded = self.maximum_measurement_torque_remoulded
 
-        shear_strength: Union[None, Unset, float, str]
+        shear_strength: float | None | str | Unset
         if isinstance(self.shear_strength, Unset):
             shear_strength = UNSET
         else:
             shear_strength = self.shear_strength
 
-        shear_strength_remoulded: Union[None, Unset, float, str]
+        shear_strength_remoulded: float | None | str | Unset
         if isinstance(self.shear_strength_remoulded, Unset):
             shear_strength_remoulded = UNSET
         else:
             shear_strength_remoulded = self.shear_strength_remoulded
 
-        sensitivity: Union[None, Unset, float, str]
+        sensitivity: float | None | str | Unset
         if isinstance(self.sensitivity, Unset):
             sensitivity = UNSET
         else:
             sensitivity = self.sensitivity
 
-        remarks: Union[None, Unset, str]
+        remarks: None | str | Unset
         if isinstance(self.remarks, Unset):
             remarks = UNSET
         else:
@@ -150,15 +153,15 @@ class MethodSVTDataCreate:
         return field_dict
 
     @classmethod
-    def from_dict(cls: type[T], src_dict: dict[str, Any]) -> T:
-        d = src_dict.copy()
+    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
+        d = dict(src_dict)
 
-        def _parse_depth(data: object) -> Union[float, str]:
-            return cast(Union[float, str], data)
+        def _parse_depth(data: object) -> float | str:
+            return cast(float | str, data)
 
         depth = _parse_depth(d.pop("depth"))
 
-        def _parse_method_data_id(data: object) -> Union[None, UUID, Unset]:
+        def _parse_method_data_id(data: object) -> None | Unset | UUID:
             if data is None:
                 return data
             if isinstance(data, Unset):
@@ -169,13 +172,13 @@ class MethodSVTDataCreate:
                 method_data_id_type_0 = UUID(data)
 
                 return method_data_id_type_0
-            except:  # noqa: E722
+            except (TypeError, ValueError, AttributeError, KeyError):
                 pass
-            return cast(Union[None, UUID, Unset], data)
+            return cast(None | Unset | UUID, data)
 
         method_data_id = _parse_method_data_id(d.pop("method_data_id", UNSET))
 
-        def _parse_method_id(data: object) -> Union[None, UUID, Unset]:
+        def _parse_method_id(data: object) -> None | Unset | UUID:
             if data is None:
                 return data
             if isinstance(data, Unset):
@@ -186,17 +189,17 @@ class MethodSVTDataCreate:
                 method_id_type_0 = UUID(data)
 
                 return method_id_type_0
-            except:  # noqa: E722
+            except (TypeError, ValueError, AttributeError, KeyError):
                 pass
-            return cast(Union[None, UUID, Unset], data)
+            return cast(None | Unset | UUID, data)
 
         method_id = _parse_method_id(d.pop("method_id", UNSET))
 
-        method_type_id = cast(Union[Literal[10], Unset], d.pop("method_type_id", UNSET))
+        method_type_id = cast(Literal[10] | Unset, d.pop("method_type_id", UNSET))
         if method_type_id != 10 and not isinstance(method_type_id, Unset):
             raise ValueError(f"method_type_id must match const 10, got '{method_type_id}'")
 
-        def _parse_created_at(data: object) -> Union[None, Unset, datetime.datetime]:
+        def _parse_created_at(data: object) -> datetime.datetime | None | Unset:
             if data is None:
                 return data
             if isinstance(data, Unset):
@@ -207,13 +210,13 @@ class MethodSVTDataCreate:
                 created_at_type_0 = isoparse(data)
 
                 return created_at_type_0
-            except:  # noqa: E722
+            except (TypeError, ValueError, AttributeError, KeyError):
                 pass
-            return cast(Union[None, Unset, datetime.datetime], data)
+            return cast(datetime.datetime | None | Unset, data)
 
         created_at = _parse_created_at(d.pop("created_at", UNSET))
 
-        def _parse_updated_at(data: object) -> Union[None, Unset, datetime.datetime]:
+        def _parse_updated_at(data: object) -> datetime.datetime | None | Unset:
             if data is None:
                 return data
             if isinstance(data, Unset):
@@ -224,65 +227,65 @@ class MethodSVTDataCreate:
                 updated_at_type_0 = isoparse(data)
 
                 return updated_at_type_0
-            except:  # noqa: E722
+            except (TypeError, ValueError, AttributeError, KeyError):
                 pass
-            return cast(Union[None, Unset, datetime.datetime], data)
+            return cast(datetime.datetime | None | Unset, data)
 
         updated_at = _parse_updated_at(d.pop("updated_at", UNSET))
 
-        def _parse_maximum_measurement_torque(data: object) -> Union[None, Unset, float, str]:
+        def _parse_maximum_measurement_torque(data: object) -> float | None | str | Unset:
             if data is None:
                 return data
             if isinstance(data, Unset):
                 return data
-            return cast(Union[None, Unset, float, str], data)
+            return cast(float | None | str | Unset, data)
 
         maximum_measurement_torque = _parse_maximum_measurement_torque(d.pop("maximum_measurement_torque", UNSET))
 
-        def _parse_maximum_measurement_torque_remoulded(data: object) -> Union[None, Unset, float, str]:
+        def _parse_maximum_measurement_torque_remoulded(data: object) -> float | None | str | Unset:
             if data is None:
                 return data
             if isinstance(data, Unset):
                 return data
-            return cast(Union[None, Unset, float, str], data)
+            return cast(float | None | str | Unset, data)
 
         maximum_measurement_torque_remoulded = _parse_maximum_measurement_torque_remoulded(
             d.pop("maximum_measurement_torque_remoulded", UNSET)
         )
 
-        def _parse_shear_strength(data: object) -> Union[None, Unset, float, str]:
+        def _parse_shear_strength(data: object) -> float | None | str | Unset:
             if data is None:
                 return data
             if isinstance(data, Unset):
                 return data
-            return cast(Union[None, Unset, float, str], data)
+            return cast(float | None | str | Unset, data)
 
         shear_strength = _parse_shear_strength(d.pop("shear_strength", UNSET))
 
-        def _parse_shear_strength_remoulded(data: object) -> Union[None, Unset, float, str]:
+        def _parse_shear_strength_remoulded(data: object) -> float | None | str | Unset:
             if data is None:
                 return data
             if isinstance(data, Unset):
                 return data
-            return cast(Union[None, Unset, float, str], data)
+            return cast(float | None | str | Unset, data)
 
         shear_strength_remoulded = _parse_shear_strength_remoulded(d.pop("shear_strength_remoulded", UNSET))
 
-        def _parse_sensitivity(data: object) -> Union[None, Unset, float, str]:
+        def _parse_sensitivity(data: object) -> float | None | str | Unset:
             if data is None:
                 return data
             if isinstance(data, Unset):
                 return data
-            return cast(Union[None, Unset, float, str], data)
+            return cast(float | None | str | Unset, data)
 
         sensitivity = _parse_sensitivity(d.pop("sensitivity", UNSET))
 
-        def _parse_remarks(data: object) -> Union[None, Unset, str]:
+        def _parse_remarks(data: object) -> None | str | Unset:
             if data is None:
                 return data
             if isinstance(data, Unset):
                 return data
-            return cast(Union[None, Unset, str], data)
+            return cast(None | str | Unset, data)
 
         remarks = _parse_remarks(d.pop("remarks", UNSET))
 
