@@ -1,5 +1,8 @@
+from __future__ import annotations
+
 import datetime
-from typing import Any, Literal, TypeVar, Union, cast
+from collections.abc import Mapping
+from typing import Any, Literal, TypeVar, cast
 from uuid import UUID
 
 from attrs import define as _attrs_define
@@ -15,49 +18,49 @@ T = TypeVar("T", bound="MethodTOTDataCreate")
 class MethodTOTDataCreate:
     """
     Attributes:
-        depth (Union[float, str]): Depth (m). SGF code D.
-        method_data_id (Union[None, UUID, Unset]):
-        method_id (Union[None, UUID, Unset]):
-        method_type_id (Union[Literal[2], Unset]):  Default: 2.
-        created_at (Union[None, Unset, datetime.datetime]):
-        updated_at (Union[None, Unset, datetime.datetime]):
-        penetration_rate (Union[None, Unset, float, str]):
-        penetration_force (Union[None, Unset, float, str]):
-        engine_pressure (Union[None, Unset, float, str]):
-        comment_code (Union[None, Unset, int]):
-        hammering (Union[None, Unset, bool]):
-        flushing (Union[None, Unset, bool]):
-        flushing_pressure (Union[None, Unset, float, str]): Flushing pressure (MPa). SGF code I.
-        flushing_flow (Union[None, Unset, float, str]): Flushing flow (liter/minute). SGF code J.
-        rotation_rate (Union[None, Unset, float, str]):
-        remarks (Union[None, Unset, str]):
-        increased_rotation_rate (Union[None, Unset, bool]):
+        depth (float | str): Depth (m). SGF code D.
+        method_data_id (None | Unset | UUID):
+        method_id (None | Unset | UUID):
+        method_type_id (Literal[2] | Unset):  Default: 2.
+        created_at (datetime.datetime | None | Unset):
+        updated_at (datetime.datetime | None | Unset):
+        penetration_rate (float | None | str | Unset):
+        penetration_force (float | None | str | Unset):
+        engine_pressure (float | None | str | Unset):
+        comment_code (int | None | Unset):
+        hammering (bool | None | Unset):
+        flushing (bool | None | Unset):
+        flushing_pressure (float | None | str | Unset): Flushing pressure (MPa). SGF code I.
+        flushing_flow (float | None | str | Unset): Flushing flow (liter/minute). SGF code J.
+        rotation_rate (float | None | str | Unset):
+        remarks (None | str | Unset):
+        increased_rotation_rate (bool | None | Unset):
     """
 
-    depth: Union[float, str]
-    method_data_id: Union[None, UUID, Unset] = UNSET
-    method_id: Union[None, UUID, Unset] = UNSET
-    method_type_id: Union[Literal[2], Unset] = 2
-    created_at: Union[None, Unset, datetime.datetime] = UNSET
-    updated_at: Union[None, Unset, datetime.datetime] = UNSET
-    penetration_rate: Union[None, Unset, float, str] = UNSET
-    penetration_force: Union[None, Unset, float, str] = UNSET
-    engine_pressure: Union[None, Unset, float, str] = UNSET
-    comment_code: Union[None, Unset, int] = UNSET
-    hammering: Union[None, Unset, bool] = UNSET
-    flushing: Union[None, Unset, bool] = UNSET
-    flushing_pressure: Union[None, Unset, float, str] = UNSET
-    flushing_flow: Union[None, Unset, float, str] = UNSET
-    rotation_rate: Union[None, Unset, float, str] = UNSET
-    remarks: Union[None, Unset, str] = UNSET
-    increased_rotation_rate: Union[None, Unset, bool] = UNSET
+    depth: float | str
+    method_data_id: None | Unset | UUID = UNSET
+    method_id: None | Unset | UUID = UNSET
+    method_type_id: Literal[2] | Unset = 2
+    created_at: datetime.datetime | None | Unset = UNSET
+    updated_at: datetime.datetime | None | Unset = UNSET
+    penetration_rate: float | None | str | Unset = UNSET
+    penetration_force: float | None | str | Unset = UNSET
+    engine_pressure: float | None | str | Unset = UNSET
+    comment_code: int | None | Unset = UNSET
+    hammering: bool | None | Unset = UNSET
+    flushing: bool | None | Unset = UNSET
+    flushing_pressure: float | None | str | Unset = UNSET
+    flushing_flow: float | None | str | Unset = UNSET
+    rotation_rate: float | None | str | Unset = UNSET
+    remarks: None | str | Unset = UNSET
+    increased_rotation_rate: bool | None | Unset = UNSET
     additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)
 
     def to_dict(self) -> dict[str, Any]:
-        depth: Union[float, str]
+        depth: float | str
         depth = self.depth
 
-        method_data_id: Union[None, Unset, str]
+        method_data_id: None | str | Unset
         if isinstance(self.method_data_id, Unset):
             method_data_id = UNSET
         elif isinstance(self.method_data_id, UUID):
@@ -65,7 +68,7 @@ class MethodTOTDataCreate:
         else:
             method_data_id = self.method_data_id
 
-        method_id: Union[None, Unset, str]
+        method_id: None | str | Unset
         if isinstance(self.method_id, Unset):
             method_id = UNSET
         elif isinstance(self.method_id, UUID):
@@ -75,7 +78,7 @@ class MethodTOTDataCreate:
 
         method_type_id = self.method_type_id
 
-        created_at: Union[None, Unset, str]
+        created_at: None | str | Unset
         if isinstance(self.created_at, Unset):
             created_at = UNSET
         elif isinstance(self.created_at, datetime.datetime):
@@ -83,7 +86,7 @@ class MethodTOTDataCreate:
         else:
             created_at = self.created_at
 
-        updated_at: Union[None, Unset, str]
+        updated_at: None | str | Unset
         if isinstance(self.updated_at, Unset):
             updated_at = UNSET
         elif isinstance(self.updated_at, datetime.datetime):
@@ -91,67 +94,67 @@ class MethodTOTDataCreate:
         else:
             updated_at = self.updated_at
 
-        penetration_rate: Union[None, Unset, float, str]
+        penetration_rate: float | None | str | Unset
         if isinstance(self.penetration_rate, Unset):
             penetration_rate = UNSET
         else:
             penetration_rate = self.penetration_rate
 
-        penetration_force: Union[None, Unset, float, str]
+        penetration_force: float | None | str | Unset
         if isinstance(self.penetration_force, Unset):
             penetration_force = UNSET
         else:
             penetration_force = self.penetration_force
 
-        engine_pressure: Union[None, Unset, float, str]
+        engine_pressure: float | None | str | Unset
         if isinstance(self.engine_pressure, Unset):
             engine_pressure = UNSET
         else:
             engine_pressure = self.engine_pressure
 
-        comment_code: Union[None, Unset, int]
+        comment_code: int | None | Unset
         if isinstance(self.comment_code, Unset):
             comment_code = UNSET
         else:
             comment_code = self.comment_code
 
-        hammering: Union[None, Unset, bool]
+        hammering: bool | None | Unset
         if isinstance(self.hammering, Unset):
             hammering = UNSET
         else:
             hammering = self.hammering
 
-        flushing: Union[None, Unset, bool]
+        flushing: bool | None | Unset
         if isinstance(self.flushing, Unset):
             flushing = UNSET
         else:
             flushing = self.flushing
 
-        flushing_pressure: Union[None, Unset, float, str]
+        flushing_pressure: float | None | str | Unset
         if isinstance(self.flushing_pressure, Unset):
             flushing_pressure = UNSET
         else:
             flushing_pressure = self.flushing_pressure
 
-        flushing_flow: Union[None, Unset, float, str]
+        flushing_flow: float | None | str | Unset
         if isinstance(self.flushing_flow, Unset):
             flushing_flow = UNSET
         else:
             flushing_flow = self.flushing_flow
 
-        rotation_rate: Union[None, Unset, float, str]
+        rotation_rate: float | None | str | Unset
         if isinstance(self.rotation_rate, Unset):
             rotation_rate = UNSET
         else:
             rotation_rate = self.rotation_rate
 
-        remarks: Union[None, Unset, str]
+        remarks: None | str | Unset
         if isinstance(self.remarks, Unset):
             remarks = UNSET
         else:
             remarks = self.remarks
 
-        increased_rotation_rate: Union[None, Unset, bool]
+        increased_rotation_rate: bool | None | Unset
         if isinstance(self.increased_rotation_rate, Unset):
             increased_rotation_rate = UNSET
         else:
@@ -200,15 +203,15 @@ class MethodTOTDataCreate:
         return field_dict
 
     @classmethod
-    def from_dict(cls: type[T], src_dict: dict[str, Any]) -> T:
-        d = src_dict.copy()
+    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
+        d = dict(src_dict)
 
-        def _parse_depth(data: object) -> Union[float, str]:
-            return cast(Union[float, str], data)
+        def _parse_depth(data: object) -> float | str:
+            return cast(float | str, data)
 
         depth = _parse_depth(d.pop("depth"))
 
-        def _parse_method_data_id(data: object) -> Union[None, UUID, Unset]:
+        def _parse_method_data_id(data: object) -> None | Unset | UUID:
             if data is None:
                 return data
             if isinstance(data, Unset):
@@ -219,13 +222,13 @@ class MethodTOTDataCreate:
                 method_data_id_type_0 = UUID(data)
 
                 return method_data_id_type_0
-            except:  # noqa: E722
+            except (TypeError, ValueError, AttributeError, KeyError):
                 pass
-            return cast(Union[None, UUID, Unset], data)
+            return cast(None | Unset | UUID, data)
 
         method_data_id = _parse_method_data_id(d.pop("method_data_id", UNSET))
 
-        def _parse_method_id(data: object) -> Union[None, UUID, Unset]:
+        def _parse_method_id(data: object) -> None | Unset | UUID:
             if data is None:
                 return data
             if isinstance(data, Unset):
@@ -236,17 +239,17 @@ class MethodTOTDataCreate:
                 method_id_type_0 = UUID(data)
 
                 return method_id_type_0
-            except:  # noqa: E722
+            except (TypeError, ValueError, AttributeError, KeyError):
                 pass
-            return cast(Union[None, UUID, Unset], data)
+            return cast(None | Unset | UUID, data)
 
         method_id = _parse_method_id(d.pop("method_id", UNSET))
 
-        method_type_id = cast(Union[Literal[2], Unset], d.pop("method_type_id", UNSET))
+        method_type_id = cast(Literal[2] | Unset, d.pop("method_type_id", UNSET))
         if method_type_id != 2 and not isinstance(method_type_id, Unset):
             raise ValueError(f"method_type_id must match const 2, got '{method_type_id}'")
 
-        def _parse_created_at(data: object) -> Union[None, Unset, datetime.datetime]:
+        def _parse_created_at(data: object) -> datetime.datetime | None | Unset:
             if data is None:
                 return data
             if isinstance(data, Unset):
@@ -257,13 +260,13 @@ class MethodTOTDataCreate:
                 created_at_type_0 = isoparse(data)
 
                 return created_at_type_0
-            except:  # noqa: E722
+            except (TypeError, ValueError, AttributeError, KeyError):
                 pass
-            return cast(Union[None, Unset, datetime.datetime], data)
+            return cast(datetime.datetime | None | Unset, data)
 
         created_at = _parse_created_at(d.pop("created_at", UNSET))
 
-        def _parse_updated_at(data: object) -> Union[None, Unset, datetime.datetime]:
+        def _parse_updated_at(data: object) -> datetime.datetime | None | Unset:
             if data is None:
                 return data
             if isinstance(data, Unset):
@@ -274,108 +277,108 @@ class MethodTOTDataCreate:
                 updated_at_type_0 = isoparse(data)
 
                 return updated_at_type_0
-            except:  # noqa: E722
+            except (TypeError, ValueError, AttributeError, KeyError):
                 pass
-            return cast(Union[None, Unset, datetime.datetime], data)
+            return cast(datetime.datetime | None | Unset, data)
 
         updated_at = _parse_updated_at(d.pop("updated_at", UNSET))
 
-        def _parse_penetration_rate(data: object) -> Union[None, Unset, float, str]:
+        def _parse_penetration_rate(data: object) -> float | None | str | Unset:
             if data is None:
                 return data
             if isinstance(data, Unset):
                 return data
-            return cast(Union[None, Unset, float, str], data)
+            return cast(float | None | str | Unset, data)
 
         penetration_rate = _parse_penetration_rate(d.pop("penetration_rate", UNSET))
 
-        def _parse_penetration_force(data: object) -> Union[None, Unset, float, str]:
+        def _parse_penetration_force(data: object) -> float | None | str | Unset:
             if data is None:
                 return data
             if isinstance(data, Unset):
                 return data
-            return cast(Union[None, Unset, float, str], data)
+            return cast(float | None | str | Unset, data)
 
         penetration_force = _parse_penetration_force(d.pop("penetration_force", UNSET))
 
-        def _parse_engine_pressure(data: object) -> Union[None, Unset, float, str]:
+        def _parse_engine_pressure(data: object) -> float | None | str | Unset:
             if data is None:
                 return data
             if isinstance(data, Unset):
                 return data
-            return cast(Union[None, Unset, float, str], data)
+            return cast(float | None | str | Unset, data)
 
         engine_pressure = _parse_engine_pressure(d.pop("engine_pressure", UNSET))
 
-        def _parse_comment_code(data: object) -> Union[None, Unset, int]:
+        def _parse_comment_code(data: object) -> int | None | Unset:
             if data is None:
                 return data
             if isinstance(data, Unset):
                 return data
-            return cast(Union[None, Unset, int], data)
+            return cast(int | None | Unset, data)
 
         comment_code = _parse_comment_code(d.pop("comment_code", UNSET))
 
-        def _parse_hammering(data: object) -> Union[None, Unset, bool]:
+        def _parse_hammering(data: object) -> bool | None | Unset:
             if data is None:
                 return data
             if isinstance(data, Unset):
                 return data
-            return cast(Union[None, Unset, bool], data)
+            return cast(bool | None | Unset, data)
 
         hammering = _parse_hammering(d.pop("hammering", UNSET))
 
-        def _parse_flushing(data: object) -> Union[None, Unset, bool]:
+        def _parse_flushing(data: object) -> bool | None | Unset:
             if data is None:
                 return data
             if isinstance(data, Unset):
                 return data
-            return cast(Union[None, Unset, bool], data)
+            return cast(bool | None | Unset, data)
 
         flushing = _parse_flushing(d.pop("flushing", UNSET))
 
-        def _parse_flushing_pressure(data: object) -> Union[None, Unset, float, str]:
+        def _parse_flushing_pressure(data: object) -> float | None | str | Unset:
             if data is None:
                 return data
             if isinstance(data, Unset):
                 return data
-            return cast(Union[None, Unset, float, str], data)
+            return cast(float | None | str | Unset, data)
 
         flushing_pressure = _parse_flushing_pressure(d.pop("flushing_pressure", UNSET))
 
-        def _parse_flushing_flow(data: object) -> Union[None, Unset, float, str]:
+        def _parse_flushing_flow(data: object) -> float | None | str | Unset:
             if data is None:
                 return data
             if isinstance(data, Unset):
                 return data
-            return cast(Union[None, Unset, float, str], data)
+            return cast(float | None | str | Unset, data)
 
         flushing_flow = _parse_flushing_flow(d.pop("flushing_flow", UNSET))
 
-        def _parse_rotation_rate(data: object) -> Union[None, Unset, float, str]:
+        def _parse_rotation_rate(data: object) -> float | None | str | Unset:
             if data is None:
                 return data
             if isinstance(data, Unset):
                 return data
-            return cast(Union[None, Unset, float, str], data)
+            return cast(float | None | str | Unset, data)
 
         rotation_rate = _parse_rotation_rate(d.pop("rotation_rate", UNSET))
 
-        def _parse_remarks(data: object) -> Union[None, Unset, str]:
+        def _parse_remarks(data: object) -> None | str | Unset:
             if data is None:
                 return data
             if isinstance(data, Unset):
                 return data
-            return cast(Union[None, Unset, str], data)
+            return cast(None | str | Unset, data)
 
         remarks = _parse_remarks(d.pop("remarks", UNSET))
 
-        def _parse_increased_rotation_rate(data: object) -> Union[None, Unset, bool]:
+        def _parse_increased_rotation_rate(data: object) -> bool | None | Unset:
             if data is None:
                 return data
             if isinstance(data, Unset):
                 return data
-            return cast(Union[None, Unset, bool], data)
+            return cast(bool | None | Unset, data)
 
         increased_rotation_rate = _parse_increased_rotation_rate(d.pop("increased_rotation_rate", UNSET))
 
