@@ -1,5 +1,7 @@
+from __future__ import annotations
+
 from collections.abc import Mapping
-from typing import Any, Literal, TypeVar, Union, cast
+from typing import Any, Literal, TypeVar, cast
 
 from attrs import define as _attrs_define
 from attrs import field as _attrs_field
@@ -13,58 +15,58 @@ T = TypeVar("T", bound="MethodTRDataUpdate")
 class MethodTRDataUpdate:
     """
     Attributes:
-        method_type_id (Union[Literal[16], Unset]):  Default: 16.
-        depth (Union[None, Unset, float, str]): Depth (m). SGF code D.
-        penetration_rate (Union[None, Unset, float, str]): Penetration rate (mm/s)
-        penetration_force (Union[None, Unset, float, str]): Penetration force (kN)
-        rotation_rate (Union[None, Unset, float, str]): Rotation rate (rpm)
-        rod_friction (Union[None, Unset, float, str]): Rod friction (kN)
-        increased_rotation_rate (Union[None, Unset, bool]): Increased rotation rate
+        method_type_id (Literal[16] | Unset):  Default: 16.
+        depth (float | None | str | Unset): Depth (m). SGF code D.
+        penetration_rate (float | None | str | Unset): Penetration rate (mm/s)
+        penetration_force (float | None | str | Unset): Penetration force (kN)
+        rotation_rate (float | None | str | Unset): Rotation rate (rpm)
+        rod_friction (float | None | str | Unset): Rod friction (kN)
+        increased_rotation_rate (bool | None | Unset): Increased rotation rate
     """
 
-    method_type_id: Union[Literal[16], Unset] = 16
-    depth: Union[None, Unset, float, str] = UNSET
-    penetration_rate: Union[None, Unset, float, str] = UNSET
-    penetration_force: Union[None, Unset, float, str] = UNSET
-    rotation_rate: Union[None, Unset, float, str] = UNSET
-    rod_friction: Union[None, Unset, float, str] = UNSET
-    increased_rotation_rate: Union[None, Unset, bool] = UNSET
+    method_type_id: Literal[16] | Unset = 16
+    depth: float | None | str | Unset = UNSET
+    penetration_rate: float | None | str | Unset = UNSET
+    penetration_force: float | None | str | Unset = UNSET
+    rotation_rate: float | None | str | Unset = UNSET
+    rod_friction: float | None | str | Unset = UNSET
+    increased_rotation_rate: bool | None | Unset = UNSET
     additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)
 
     def to_dict(self) -> dict[str, Any]:
         method_type_id = self.method_type_id
 
-        depth: Union[None, Unset, float, str]
+        depth: float | None | str | Unset
         if isinstance(self.depth, Unset):
             depth = UNSET
         else:
             depth = self.depth
 
-        penetration_rate: Union[None, Unset, float, str]
+        penetration_rate: float | None | str | Unset
         if isinstance(self.penetration_rate, Unset):
             penetration_rate = UNSET
         else:
             penetration_rate = self.penetration_rate
 
-        penetration_force: Union[None, Unset, float, str]
+        penetration_force: float | None | str | Unset
         if isinstance(self.penetration_force, Unset):
             penetration_force = UNSET
         else:
             penetration_force = self.penetration_force
 
-        rotation_rate: Union[None, Unset, float, str]
+        rotation_rate: float | None | str | Unset
         if isinstance(self.rotation_rate, Unset):
             rotation_rate = UNSET
         else:
             rotation_rate = self.rotation_rate
 
-        rod_friction: Union[None, Unset, float, str]
+        rod_friction: float | None | str | Unset
         if isinstance(self.rod_friction, Unset):
             rod_friction = UNSET
         else:
             rod_friction = self.rod_friction
 
-        increased_rotation_rate: Union[None, Unset, bool]
+        increased_rotation_rate: bool | None | Unset
         if isinstance(self.increased_rotation_rate, Unset):
             increased_rotation_rate = UNSET
         else:
@@ -93,61 +95,61 @@ class MethodTRDataUpdate:
     @classmethod
     def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
         d = dict(src_dict)
-        method_type_id = cast(Union[Literal[16], Unset], d.pop("method_type_id", UNSET))
+        method_type_id = cast(Literal[16] | Unset, d.pop("method_type_id", UNSET))
         if method_type_id != 16 and not isinstance(method_type_id, Unset):
             raise ValueError(f"method_type_id must match const 16, got '{method_type_id}'")
 
-        def _parse_depth(data: object) -> Union[None, Unset, float, str]:
+        def _parse_depth(data: object) -> float | None | str | Unset:
             if data is None:
                 return data
             if isinstance(data, Unset):
                 return data
-            return cast(Union[None, Unset, float, str], data)
+            return cast(float | None | str | Unset, data)
 
         depth = _parse_depth(d.pop("depth", UNSET))
 
-        def _parse_penetration_rate(data: object) -> Union[None, Unset, float, str]:
+        def _parse_penetration_rate(data: object) -> float | None | str | Unset:
             if data is None:
                 return data
             if isinstance(data, Unset):
                 return data
-            return cast(Union[None, Unset, float, str], data)
+            return cast(float | None | str | Unset, data)
 
         penetration_rate = _parse_penetration_rate(d.pop("penetration_rate", UNSET))
 
-        def _parse_penetration_force(data: object) -> Union[None, Unset, float, str]:
+        def _parse_penetration_force(data: object) -> float | None | str | Unset:
             if data is None:
                 return data
             if isinstance(data, Unset):
                 return data
-            return cast(Union[None, Unset, float, str], data)
+            return cast(float | None | str | Unset, data)
 
         penetration_force = _parse_penetration_force(d.pop("penetration_force", UNSET))
 
-        def _parse_rotation_rate(data: object) -> Union[None, Unset, float, str]:
+        def _parse_rotation_rate(data: object) -> float | None | str | Unset:
             if data is None:
                 return data
             if isinstance(data, Unset):
                 return data
-            return cast(Union[None, Unset, float, str], data)
+            return cast(float | None | str | Unset, data)
 
         rotation_rate = _parse_rotation_rate(d.pop("rotation_rate", UNSET))
 
-        def _parse_rod_friction(data: object) -> Union[None, Unset, float, str]:
+        def _parse_rod_friction(data: object) -> float | None | str | Unset:
             if data is None:
                 return data
             if isinstance(data, Unset):
                 return data
-            return cast(Union[None, Unset, float, str], data)
+            return cast(float | None | str | Unset, data)
 
         rod_friction = _parse_rod_friction(d.pop("rod_friction", UNSET))
 
-        def _parse_increased_rotation_rate(data: object) -> Union[None, Unset, bool]:
+        def _parse_increased_rotation_rate(data: object) -> bool | None | Unset:
             if data is None:
                 return data
             if isinstance(data, Unset):
                 return data
-            return cast(Union[None, Unset, bool], data)
+            return cast(bool | None | Unset, data)
 
         increased_rotation_rate = _parse_increased_rotation_rate(d.pop("increased_rotation_rate", UNSET))
 
