@@ -152,7 +152,7 @@ class MethodWSTUpdate:
                 method_id_type_0 = UUID(data)
 
                 return method_id_type_0
-            except:  # noqa: E722
+            except (TypeError, ValueError, AttributeError, KeyError):
                 pass
             return cast(None | Unset | UUID, data)
 
@@ -187,7 +187,7 @@ class MethodWSTUpdate:
                 method_status_id_type_0 = MethodStatusEnum(data)
 
                 return method_status_id_type_0
-            except:  # noqa: E722
+            except (TypeError, ValueError, AttributeError, KeyError):
                 pass
             return cast(MethodStatusEnum | None | Unset, data)
 
@@ -204,7 +204,7 @@ class MethodWSTUpdate:
                 updated_at_type_0 = isoparse(data)
 
                 return updated_at_type_0
-            except:  # noqa: E722
+            except (TypeError, ValueError, AttributeError, KeyError):
                 pass
             return cast(datetime.datetime | None | Unset, data)
 
@@ -239,7 +239,7 @@ class MethodWSTUpdate:
                 conducted_at_type_0 = isoparse(data)
 
                 return conducted_at_type_0
-            except:  # noqa: E722
+            except (TypeError, ValueError, AttributeError, KeyError):
                 pass
             return cast(datetime.datetime | None | Unset, data)
 
@@ -260,7 +260,7 @@ class MethodWSTUpdate:
                 operation_type_0 = Operation(data)
 
                 return operation_type_0
-            except:  # noqa: E722
+            except (TypeError, ValueError, AttributeError, KeyError):
                 pass
             return cast(None | Operation | Unset, data)
 
