@@ -166,7 +166,7 @@ class OrganizationCreate:
                 organization_id_type_0 = UUID(data)
 
                 return organization_id_type_0
-            except:  # noqa: E722
+            except (TypeError, ValueError, AttributeError, KeyError):
                 pass
             return cast(None | Unset | UUID, data)
 
@@ -219,7 +219,7 @@ class OrganizationCreate:
                 default_role_type_0 = RoleEnum(data)
 
                 return default_role_type_0
-            except:  # noqa: E722
+            except (TypeError, ValueError, AttributeError, KeyError):
                 pass
             return cast(None | RoleEnum | Unset, data)
 
@@ -236,7 +236,7 @@ class OrganizationCreate:
                 created_at_type_0 = isoparse(data)
 
                 return created_at_type_0
-            except:  # noqa: E722
+            except (TypeError, ValueError, AttributeError, KeyError):
                 pass
             return cast(datetime.datetime | None | Unset, data)
 
@@ -253,7 +253,7 @@ class OrganizationCreate:
                 updated_at_type_0 = isoparse(data)
 
                 return updated_at_type_0
-            except:  # noqa: E722
+            except (TypeError, ValueError, AttributeError, KeyError):
                 pass
             return cast(datetime.datetime | None | Unset, data)
 
@@ -270,18 +270,20 @@ class OrganizationCreate:
                 default_standard_id_type_0 = StandardType(data)
 
                 return default_standard_id_type_0
-            except:  # noqa: E722
+            except (TypeError, ValueError, AttributeError, KeyError):
                 pass
             return cast(None | StandardType | Unset, data)
 
         default_standard_id = _parse_default_standard_id(d.pop("default_standard_id", UNSET))
 
-        available_standard_ids = []
         _available_standard_ids = d.pop("available_standard_ids", UNSET)
-        for available_standard_ids_item_data in _available_standard_ids or []:
-            available_standard_ids_item = StandardType(available_standard_ids_item_data)
+        available_standard_ids: list[StandardType] | Unset = UNSET
+        if _available_standard_ids is not UNSET:
+            available_standard_ids = []
+            for available_standard_ids_item_data in _available_standard_ids:
+                available_standard_ids_item = StandardType(available_standard_ids_item_data)
 
-            available_standard_ids.append(available_standard_ids_item)
+                available_standard_ids.append(available_standard_ids_item)
 
         organization_create = cls(
             name=name,
