@@ -1,5 +1,7 @@
+from __future__ import annotations
+
 from collections.abc import Mapping
-from typing import Any, TypeVar, Union, cast
+from typing import Any, TypeVar, cast
 
 from attrs import define as _attrs_define
 from attrs import field as _attrs_field
@@ -11,7 +13,7 @@ T = TypeVar("T", bound="PlotDataStatsPercentiles")
 class PlotDataStatsPercentiles:
     """ """
 
-    additional_properties: dict[str, Union[float, str]] = _attrs_field(init=False, factory=dict)
+    additional_properties: dict[str, float | str] = _attrs_field(init=False, factory=dict)
 
     def to_dict(self) -> dict[str, Any]:
         field_dict: dict[str, Any] = {}
@@ -28,8 +30,8 @@ class PlotDataStatsPercentiles:
         additional_properties = {}
         for prop_name, prop_dict in d.items():
 
-            def _parse_additional_property(data: object) -> Union[float, str]:
-                return cast(Union[float, str], data)
+            def _parse_additional_property(data: object) -> float | str:
+                return cast(float | str, data)
 
             additional_property = _parse_additional_property(prop_dict)
 
@@ -42,10 +44,10 @@ class PlotDataStatsPercentiles:
     def additional_keys(self) -> list[str]:
         return list(self.additional_properties.keys())
 
-    def __getitem__(self, key: str) -> Union[float, str]:
+    def __getitem__(self, key: str) -> float | str:
         return self.additional_properties[key]
 
-    def __setitem__(self, key: str, value: Union[float, str]) -> None:
+    def __setitem__(self, key: str, value: float | str) -> None:
         self.additional_properties[key] = value
 
     def __delitem__(self, key: str) -> None:
