@@ -229,7 +229,7 @@ class ProjectSummary:
                 height_reference_type_0 = HeightReference(data)
 
                 return height_reference_type_0
-            except:  # noqa: E722
+            except (TypeError, ValueError, AttributeError, KeyError):
                 pass
             return cast(HeightReference | None, data)
 
@@ -248,7 +248,7 @@ class ProjectSummary:
                 created_at_type_0 = isoparse(data)
 
                 return created_at_type_0
-            except:  # noqa: E722
+            except (TypeError, ValueError, AttributeError, KeyError):
                 pass
             return cast(datetime.datetime | None | Unset, data)
 
@@ -265,7 +265,7 @@ class ProjectSummary:
                 updated_at_type_0 = isoparse(data)
 
                 return updated_at_type_0
-            except:  # noqa: E722
+            except (TypeError, ValueError, AttributeError, KeyError):
                 pass
             return cast(datetime.datetime | None | Unset, data)
 
@@ -300,7 +300,7 @@ class ProjectSummary:
                 tags_type_0 = cast(list[str], data)
 
                 return tags_type_0
-            except:  # noqa: E722
+            except (TypeError, ValueError, AttributeError, KeyError):
                 pass
             return cast(list[str] | None | Unset, data)
 
@@ -317,7 +317,7 @@ class ProjectSummary:
                 organization_type_0 = OrganizationMin.from_dict(data)
 
                 return organization_type_0
-            except:  # noqa: E722
+            except (TypeError, ValueError, AttributeError, KeyError):
                 pass
             return cast(None | OrganizationMin | Unset, data)
 
@@ -334,7 +334,7 @@ class ProjectSummary:
                 effective_role_type_0 = Role.from_dict(data)
 
                 return effective_role_type_0
-            except:  # noqa: E722
+            except (TypeError, ValueError, AttributeError, KeyError):
                 pass
             return cast(None | Role | Unset, data)
 
@@ -351,7 +351,7 @@ class ProjectSummary:
                 last_updated_type_0 = isoparse(data)
 
                 return last_updated_type_0
-            except:  # noqa: E722
+            except (TypeError, ValueError, AttributeError, KeyError):
                 pass
             return cast(datetime.datetime | None | Unset, data)
 
@@ -359,12 +359,14 @@ class ProjectSummary:
 
         favorite = d.pop("favorite", UNSET)
 
-        locations = []
         _locations = d.pop("locations", UNSET)
-        for locations_item_data in _locations or []:
-            locations_item = LocationSummary.from_dict(locations_item_data)
+        locations: list[LocationSummary] | Unset = UNSET
+        if _locations is not UNSET:
+            locations = []
+            for locations_item_data in _locations:
+                locations_item = LocationSummary.from_dict(locations_item_data)
 
-            locations.append(locations_item)
+                locations.append(locations_item)
 
         project_summary = cls(
             project_id=project_id,
