@@ -1,5 +1,7 @@
+from __future__ import annotations
+
 from collections.abc import Mapping
-from typing import TYPE_CHECKING, Any, TypeVar, Union
+from typing import TYPE_CHECKING, Any, TypeVar
 
 from attrs import define as _attrs_define
 from attrs import field as _attrs_field
@@ -9,6 +11,7 @@ from ..types import UNSET, Unset
 
 if TYPE_CHECKING:
     from ..models.method_type import MethodType
+    from ..models.sampling_technique import SamplingTechnique
 
 
 T = TypeVar("T", bound="Standard")
@@ -22,14 +25,16 @@ class Standard:
         name (str):
         description (str):
         sort_order (int):
-        method_types (Union[Unset, list['MethodType']]):
+        method_types (list[MethodType] | Unset):
+        sampling_techniques (list[SamplingTechnique] | Unset):
     """
 
     standard_id: StandardType
     name: str
     description: str
     sort_order: int
-    method_types: Union[Unset, list["MethodType"]] = UNSET
+    method_types: list[MethodType] | Unset = UNSET
+    sampling_techniques: list[SamplingTechnique] | Unset = UNSET
     additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)
 
     def to_dict(self) -> dict[str, Any]:
@@ -41,13 +46,20 @@ class Standard:
 
         sort_order = self.sort_order
 
-        method_types: Union[Unset, list[dict[str, Any]]] = UNSET
+        method_types: list[dict[str, Any]] | Unset = UNSET
         if not isinstance(self.method_types, Unset):
             method_types = []
             for method_types_item_data in self.method_types:
                 method_types_item = method_types_item_data.to_dict()
                 method_types.append(method_types_item)
 
+        sampling_techniques: list[dict[str, Any]] | Unset = UNSET
+        if not isinstance(self.sampling_techniques, Unset):
+            sampling_techniques = []
+            for sampling_techniques_item_data in self.sampling_techniques:
+                sampling_techniques_item = sampling_techniques_item_data.to_dict()
+                sampling_techniques.append(sampling_techniques_item)
+
         field_dict: dict[str, Any] = {}
         field_dict.update(self.additional_properties)
         field_dict.update(
@@ -60,12 +72,15 @@ class Standard:
         )
         if method_types is not UNSET:
             field_dict["method_types"] = method_types
+        if sampling_techniques is not UNSET:
+            field_dict["sampling_techniques"] = sampling_techniques
 
         return field_dict
 
     @classmethod
     def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
         from ..models.method_type import MethodType
+        from ..models.sampling_technique import SamplingTechnique
 
         d = dict(src_dict)
         standard_id = StandardType(d.pop("standard_id"))
@@ -76,12 +91,23 @@ class Standard:
 
         sort_order = d.pop("sort_order")
 
-        method_types = []
         _method_types = d.pop("method_types", UNSET)
-        for method_types_item_data in _method_types or []:
-            method_types_item = MethodType.from_dict(method_types_item_data)
+        method_types: list[MethodType] | Unset = UNSET
+        if _method_types is not UNSET:
+            method_types = []
+            for method_types_item_data in _method_types:
+                method_types_item = MethodType.from_dict(method_types_item_data)
 
-            method_types.append(method_types_item)
+                method_types.append(method_types_item)
+
+        _sampling_techniques = d.pop("sampling_techniques", UNSET)
+        sampling_techniques: list[SamplingTechnique] | Unset = UNSET
+        if _sampling_techniques is not UNSET:
+            sampling_techniques = []
+            for sampling_techniques_item_data in _sampling_techniques:
+                sampling_techniques_item = SamplingTechnique.from_dict(sampling_techniques_item_data)
+
+                sampling_techniques.append(sampling_techniques_item)
 
         standard = cls(
             standard_id=standard_id,
@@ -89,6 +115,7 @@ class Standard:
             description=description,
             sort_order=sort_order,
             method_types=method_types,
+            sampling_techniques=sampling_techniques,
         )
 
         standard.additional_properties = d
